<%
'============================================================================================
' File name:    verify.asp
' Description:  Contains all functions required for verification of protocol xml.
'============================================================================================
Const FIELD = 1
Const TABLE = 2

Const IMG_INVALID = "../graphics/invalid.gif"
Const IMG_VALID = "../graphics/valid.gif"

'constants for the group identifiers
Const EXAMINATION = "examination_"
Const INVESTIGATION = "investigation_"
Const ADMIN = "admin_"
Const VERIFICATION = "verification_"
Const PROTRESPONSE = "protresponse_"
Const STRUCTADMIN = "structadmin_"
Const FPADMIN = "fpadmin_"
Const READCODEEVENT     =   "readcodeevent"
Const SCREENINGEVENT    =   "screeningevent"
Const PRESCRIBEDDRUGS   =   "prescribeddrug"
Const STR_EDITOR        =   "protxml.html"

Class VerifyProtocolXml
    Public Function ValidateXML(configurationFiles, blnPrintResults, blnViewForm, strOutHTML)
        Dim objFieldQuestions, objTableQuestions, objFieldQuestion, objTableQuestion, objQuestions
        Dim blnValid, blnValidQuestionType, blnValidQuestionID, blnTabResult, blnDupIDResult
        Dim blnFieldsResults, blnTablesResults, blnSchemaMandatory
        Dim strXPath, strHeader, strMsg, strMarker, strQuestionType, strQuestionID
        Dim strImage, strFieldOrTable, strTabResult, strDupIDResult, strInvalidMandIDs
        Dim strFieldsResult, strTablesResult, strTableIDs, strFieldIDs, strErrorIDs
        Dim strMandatoryHeader, strMandatoryXPath, strAppResult, blnMandAppResult
        Dim lngCount
        Dim blnMandatoryResult, blnMandColumnsResult, blnNoTypeAttrResult, blnWarningResults, blnControlNodeResult
        Dim strSchemaResult, strMandColumnsResult, strNoTypeAttrResult, strNoTypeIDs, strInvalidTabIDs, strDuplicateIDs, strWarningResult, strControlNodeResult, strInvalidControlIDs

        strMarker = "~"

        ' Determine what mandatory and recommended fields are present.
        blnValid = True
        If	(Not configurationFiles.BuildMessageXml Is Nothing) And _	
            (Not configurationFiles.ProtocolXml Is Nothing) And _
            (Not configurationFiles.TablesXml Is Nothing) And _ 
            (Not configurationFiles.SyntaxXml Is Nothing) Then
            
            'convert the ids of the questions in the protocol xml to lowercase
            'for processing
            Call ConvertIDsToLowerCase(configurationFiles.ProtocolXml)

            'PROTOCOL LEVEL VERIFICATION
            '1: Verifies any missing labels for tabs
            blnTabResult = getTabInfo(configurationFiles.ProtocolXml, strTabResult, strInvalidTabIDs)

            '2: Verifies any duplicate Question IDs in the protocol
            blnDupIDResult = validateDuplicateIDs(configurationFiles.ProtocolXml, strDupIDResult, strDuplicateIDs)

            '3: Verifies any schema-level mandatory fields or table columns that are missing
            strMandatoryHeader = "NHS Schema Mandatory Fields missing"
            strMandatoryXPath = "/questions/question[@mandatory]"
            blnSchemaMandatory = True
            blnMandatoryResult = ValidateMandatory(configurationFiles.ProtocolXml, configurationFiles.QuestionsXml, strMandatoryHeader, strMandatoryXPath, blnSchemaMandatory, strInvalidMandIDs, strSchemaResult)

            '4: Verifies any application-level mandatory field or table columns that are missing
            strMandatoryHeader = "SCI Gateway Mandatory Fields missing"
            strMandatoryXPath = "/questions/question[@mandatoryInApplication]"
            blnSchemaMandatory = False
            blnMandAppResult = ValidateMandatory(configurationFiles.ProtocolXml, configurationFiles.QuestionsXml, strMandatoryHeader, strMandatoryXPath, blnSchemaMandatory, strInvalidMandIDs, strAppResult)

            '5: Verifies any mandatory columns in tables
            blnMandColumnsResult = validateMandatoryColumns(configurationFiles.ProtocolXml, configurationFiles.QuestionsXml, strMandColumnsResult)

            '6: Verifies any questions with no type attribute
            blnNoTypeAttrResult = ValidateQuestionsWithNoType(configurationFiles.ProtocolXml, strNoTypeAttrResult, strNoTypeIDs)

            '7: Warnings
            blnWarningResults = ValidateWarnings(configurationFiles.ProtocolXml, configurationFiles.BuildMessageXml, strWarningResult)

            '8: Checks for control node and for correct attributes
            blnControlNodeResult = ValidateControlNodes(configurationFiles.ProtocolXml, strControlNodeResult, strInvalidControlIDs)

            'QUESTION LEVEL VERIFICATION
            '1: Checks all the FIELDS defined in the protocol xml for: Type, ID, Text, Attributes, Nodes, Filters
            Set objFieldQuestions = configurationFiles.ProtocolXml.selectNodes("//question[@type!='table' and @type!='dynaTable' and @type!='giDynaTable']")
            blnFieldsResults = ValidateQuestionList(configurationFiles, objFieldQuestions, "Fields", "Id2~Type2~Text1~Attributes1~Childnodes1~Pre-population1~Values1~Dependency1~&nbsp;1", FIELD, strFieldsResult, strFieldIDs)

            '2: Checks all the TABLES defined in the protocol xml for: Type, ID, Text, Attributes, Nodes, Filters
            Set objTableQuestions = configurationFiles.ProtocolXml.selectNodes("//question[@type='table' or @type='dynaTable' or @type='giDynaTable']")			
            blnTablesResults = ValidateQuestionList(configurationFiles, objTableQuestions, "Tables", "Id2~Type2~Attributes1~Childnodes1~Pre-population1~Values1~Dependency1~&nbsp;1", TABLE, strTablesResult, strTableIDs)

            If Not blnDupIDResult Then
	            If Len(strErrorIDs) > 0 Then
	                strErrorIDs = strErrorIDs & "" & strDuplicateIDs
	            Else
    	            strErrorIDs = strDuplicateIDs
	            End If
            End If

            If Not blnControlNodeResult Then
	            If Len(strErrorIDs) > 0 Then
    	            strErrorIDs = strErrorIDs & "" & strInvalidControlIDs
	            Else
    	            strErrorIDs = strInvalidControlIDs
	            End If
            End If

            If Not blnMandatoryResult Then
	            If Len(strErrorIDs) > 0 Then
    	            strErrorIDs = strErrorIDs & "" & strInvalidMandIDs
	            Else
    	            strErrorIDs = strInvalidMandIDs
	            End If
            End If			

            If Not blnTabResult Then
	            If Len(strErrorIDs) > 0 Then
    	            strErrorIDs = strErrorIDs & "" & strInvalidTabIDs
	            Else
    	            strErrorIDs = strInvalidTabIDs
	            End If
            End If

            If Not blnNoTypeAttrResult Then
                If Len(strErrorIDs) > 0 Then
                    strErrorIDs = strErrorIDs & "" & strNoTypeIDs
                Else
                    strErrorIDs = strNoTypeIDs
                End If
            End If

            If Not blnFieldsResults Then
	            If (Len(strErrorIDs) > 0) Then
    	            strErrorIDs = strErrorIDs & "" & strFieldIDs
	            Else
    	            strErrorIDs = strFieldIDs
	            End If
            End If

            If Not blnTablesResults Then				
	            If Len(strErrorIDs) > 0 Then
    	            strErrorIDs = strErrorIDs & "" & strTableIDs			
	            Else
    	            strErrorIDs = strTableIDs			
	            End If
            End If

            lngCount = 1
            strOutHTML = ""

            'PROTOCOL LEVEL VERIFICATION
            If	(Not blnTabResult) Or (Not blnDupIDResult) Or _
                (Not blnMandatoryResult) Or (Not blnMandAppResult) Or _
                (Not blnMandColumnsResult) Or (Not blnNoTypeAttrResult) Or _
                (Not blnWarningResults) Or (Not blnControlNodeResult) Then
                strOutHTML = strOutHTML & "<br/><div class=""header"">" & CStr(lngCount) & ".	Protocol level verification</div><br/>" & vbCrLf
                strOutHTML = strOutHTML & "<hr/>" & vbCrLf

                'Write out any Tab errors
                If (Not blnTabResult) Then 
                    strOutHTML = strOutHTML & strTabResult
                    strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If

                'Write out any questions with duplicate ID attributes
                If (Not blnDupIDResult) Then 
                    strOutHTML = strOutHTML & strDupIDResult
                    strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If

                'Write out any mandatory questions that have not been marked as mandatory
                If (Not blnMandatoryResult) Then
	                strOutHTML = strOutHTML & strSchemaResult
	                strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If

                'Write out any application-level mandatory questions 
                If (Not blnMandAppResult) Then
	                strOutHTML = strOutHTML & strAppResult
	                strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If

                'Write out any questions with missing mandatory columns
                If (Not blnMandColumnsResult) Then
	                strOutHTML = strOutHTML & strMandColumnsResult
	                strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If

                'Write out any invalid control nodes
                If (Not blnControlNodeResult) Then
	                strOutHTML = strOutHTML & strControlNodeResult
	                strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If		

                'Write out any questions with no type specified
                If (Not blnNoTypeAttrResult) Then
	                strOutHTML = strOutHTML & strNoTypeAttrResult
	                strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If						

                'Write out any questions that should be there but are not (warning questions)
                If (Not blnWarningResults) Then
	                strOutHTML = strOutHTML & strWarningResult
	                strOutHTML = strOutHTML & "<br/><hr/><br/>" & vbCrLf
                End If

                lngCount = lngCount + 1
            End If

            'QUESTION LEVEL VERIFICATION		
            If (Not blnFieldsResults) Or (Not blnTablesResults) Then
	            If (lngCount = 1) Then
    	            strOutHTML = strOutHTML & "<br/><div class=""header"">Question level verification</div><br/>" & vbCrLf
	            Else
	                strOutHTML = strOutHTML & "<br/><div class=""header"">" & CStr(lngCount) & ".	Question level verification</div><br/>" & vbCrLf
	            End If
                
	            'Write any field errors
	            If (Not blnFieldsResults) Then
		            strOutHTML = strOutHTML & strFieldsResult 

    	            If (Not blnTablesResults) Then
	                    strOutHTML = strOutHTML & "<br><br>"
		            End If
	            End If
                
	            'Write any table errors
	            If (Not blnTablesResults) Then
    	            strOutHTML = strOutHTML & strTablesResult
	            End If
            End If
            strOutHTML = strOutHTML & "<input id=""fldErrorNumbers"" name=""fldErrorNumbers"" type=""hidden"" value=""" & strErrorIDs & """>"

            If blnPrintResults Then
                Response.Write strOutHTML
            End If
        End If
        blnValid = (blnTabResult And blnDupIDResult And blnFieldsResults And blnTablesResults And blnMandatoryResult And blnMandAppResult And blnMandColumnsResult And blnNoTypeAttrResult And blnControlNodeResult)
        ValidateXML = blnValid
    End Function

    Private Function ValidateControlNodes(protocolXml, strControlNodeResult, strInvalidControlIDs)
    '
    ' Description:  Check if there is a control node, is there a name attribute.  If
    '               this exists check that it is referrer or registrar.
    ' Parameters:   strControlNodeResult - Returns the control nodes errors
    '               strInvalidControlIDs - Returns the invalid control nodes IDs
    ' Returns:      True if control nodes valid, False otherwise
    '	

        Dim strHeader, strMsg, strID, strQuestionMsg
        Dim blnSuccess, blnValid
        Dim objControls, objControl
        Dim lngCount
            	
        blnValid = True
        lngCount = 1	

        Set objControls = protocolXml.selectNodes("//control")

        If Not objControls Is Nothing Then

            blnSuccess = (objControls.Length = 0)

            If Not blnSuccess Then
                strControlNodeResult = ""
                strHeader = "Control Node"
                strMsg = "Control Nodes should be referrer or registrar"

                strControlNodeResult = strControlNodeResult & "<h3>" & strHeader & "</h3>" & vbCrLf
                strQuestionMsg = strMsg

                For Each objControl in objControls
                    If lngCount = 1 then 'only display message for first error
	                    strQuestionMsg = buildMessage(objControl, strQuestionMsg, "~")		
	                    strControlNodeResult = strControlNodeResult & strQuestionMsg & vbCrLf
	                    strControlNodeResult = strControlNodeResult & "<table border=""0"">" & vbCrLf	
	                    strControlNodeResult = strControlNodeResult & "<tr>" & vbCrLf		
                    End IF

                    'Write buttons to jump to Invalid control node, use name as ID				
                    strID = objControl.getAttribute("name")

                    'Check for errors
                    If objControl.getAttribute("name") <> "registrar" Then
                        If objControl.getAttribute("name") <> "referrer" Then
	                        blnvalid = false
                            
	                        strControlNodeResult    =   strControlNodeResult & "<td class=""borderedCell"">"
	                        strControlNodeResult    =   strControlNodeResult & "<input id=""Control" & lngCount & """"
	                        strControlNodeResult    =   strControlNodeResult & " name=""btnXMLControl" & lngCount & """ type=""button"" value="""
	                        'strControlNodeResult   =   strControlNodeResult & objControl.getAttribute("name") & " #" & lngCount & """ "
	                        strControlNodeResult    =   strControlNodeResult & "Control" & " #" & lngCount & """ "
	                        strControlNodeResult    =   strControlNodeResult & "onclick=""vbscript:call OpenXML(True, '" & STR_EDITOR & "', True)"">"
	                        strControlNodeResult    =   strControlNodeResult & "<xml>" & objControl.xml & "</xml>"
	                        strControlNodeResult    =   strControlNodeResult & "</td>" & vbCrLf
	                        If (Len(strInvalidControlIDs) = 0) Then
    	                        strInvalidControlIDs = "Control" & CStr(lngCount)
	                        Else
    	                        strInvalidControlIDs = strInvalidControlIDs & "" & "Control" & CStr(lngCount)
	                        End If
                        End If
                    End If
                    lngCount = lngCount	+ 1
                Next

                If Not blnvalid Then
                    strControlNodeResult = strControlNodeResult & "</tr>" & vbCrLf
	                strControlNodeResult = strControlNodeResult & "</table><br/>" & vbCrLf		
                else
                    strControlNodeResult = ""
                End IF
            End If
        End If

        validateControlNodes = blnValid

    End Function

    Private Function ValidateWarnings(protocolXml, buildMessageXml, strWarningResult)
        Dim strXPath, strID, strWarningQuestions
        Dim objWarningNode, objWarningNodes, objWarning
        Dim blnResult

        strWarningResult = ""
            
        blnResult = True
            	
        strXPath = "//message/messageitem[@warning='true']"
            
        Set objWarningNodes = buildMessageXml.selectNodes(strXPath)
            	
        If Not objWarningNodes Is Nothing Then
            For Each objWarningNode in objWarningNodes
	            strID = objWarningNode.getAttribute("id") & ""
                		
	            'Check if the object is in the protocol xml. if not, warn the protocol author
	            Set objWarning = protocolXml.selectSingleNode("//question[@id='" & strID & "']")
                		
	            If objWarning Is Nothing Then
		            'Cannot be found so need to warn protocol author
		            strWarningQuestions = strWarningQuestions & "<tr><td class=""borderedCell"">" & strID & "&nbsp;<img src=""" & IMG_INVALID & """></td></tr>"
		            blnResult = False
	            End If
            Next
        End If

        If Not blnResult Then
            strWarningResult = ""
            strWarningResult = strWarningResult & "<h3>Warning about questions that should be included</h3>"
            strWarningResult = strWarningResult & "<table border=""1"" cellpadding=""4"">" & vbCrLf 
            strWarningResult = strWarningResult & "<tr><td class=""borderedCell""><b>Id</b></td></tr>" & vbCrLf
            strWarningResult = strWarningResult & strWarningQuestions 
            strWarningResult = strWarningResult & "</table>" & vbCrLf
        End If

        validateWarnings = blnResult
    End Function

    Private Function ValidateQuestionsWithNoType(protocolXml, strNoTypeAttrResult, strErrorIDs)
    '
    ' Description:  Validates questions with no type.	
    ' Parameters:   strNoTypeAttrResult - Returns the question errors
    '               strInvalidControlIDs - Returns the invalid question IDs
    ' Returns:      True if questions with no type are valid, False otherwise
    '
        Dim blnSuccess
        Dim objNodes
        Dim objNode
        Dim strNoTypeRows, strID
        Dim lngCount

        strErrorIDs = ""

        Set objNodes = protocolXml.selectNodes("//question[not(@type)]")

        If Not objNodes Is Nothing Then
            blnSuccess = (objNodes.Length = 0)
            lngCount = 1
            If Not blnSuccess Then
                For Each objNode in objNodes
		            strID = objNode.getAttribute("id") & ""
	                strNoTypeRows = strNoTypeRows & "<tr><td class=""borderedCell"">" & strID & "</td>"
		            strNoTypeRows = strNoTypeRows & "<td class=""borderedCell""><input"
		            strNoTypeRows = strNoTypeRows & " id=""NoType" & CStr(lngCount) & """"
		            strNoTypeRows = strNoTypeRows & " name=""btnXMLNoType" & CStr(lngCount) & """ type=""button"" value=""edit xml"" onclick=""vbscript:call OpenXML(True, '" & STR_EDITOR & "', True)"">"
		            strNoTypeRows = strNoTypeRows & "<xml name=""xmlQuestion"">" & objNode.xml & "</xml></td>"
		            strNoTypeRows = strNoTypeRows & "</tr>" & vbCrLf					
		            If (Len(strErrorIDs) = 0) Then
			            strErrorIDs = "NoType" & CStr(lngCount)
		            Else
			            strErrorIDs = strErrorIDs & "" & "NoType" & CStr(lngCount)
		            End If
		            lngCount = lngCount + 1
	            Next
            End If 
        Else
            blnSuccess = False
        End If

        If Not blnSuccess Then
            strNoTypeAttrResult = ""
            strNoTypeAttrResult = strNoTypeAttrResult & "<h3>Questions with no type attribute specified</h3>"
            strNoTypeAttrResult = strNoTypeAttrResult & "<table border=""1"" cellpadding=""4"">" & vbCrLf 
            strNoTypeAttrResult = strNoTypeAttrResult & "<tr><td class=""borderedCell""><b>Id</b></td></tr>" & vbCrLf
            strNoTypeAttrResult = strNoTypeAttrResult & strNoTypeRows 
            strNoTypeAttrResult = strNoTypeAttrResult & "</table>" & vbCrLf
        End If

        validateQuestionsWithNoType = blnSuccess
    End Function

    Private Function ValidateMandatoryColumns(protocolXml, questionsXML, strResult)
        Dim strXPath, strConfigXPath, strConfigColumnID
        Dim objDynaTables, objDynaTable,objConfigColumns, objDynaTableColumn, objConfigColumn
        Dim strTableID, strMandCols, strDynID
        Dim blnValid, blnIsGroup
        Dim intCount	

        strResult = ""
        blnValid = True

        'Xpath to dynatables in protocol xml		
        strXPath = "//question[@type='dynaTable']"

        'Select all dynatable nodes from the protocol xml
        Set objDynaTables = protocolXml.selectNodes(strXPath)

        If Not objDynaTables Is Nothing Then
            'If there are any dynatables
            intCount = 1
            For Each objDynaTable in objDynaTables
                'Check for each dynatable if it has the mandatory columns
                strTableID = objDynaTable.getAttribute("id") & ""

                'Check to see if it is a group identifier
                blnIsGroup = (Left(strTableID, Len(EXAMINATION)) = EXAMINATION)
                If blnIsGroup Then 
                    strDynID = EXAMINATION
                Else
                    blnIsGroup = (Left(strTableID, Len(INVESTIGATION)) = INVESTIGATION)
                    If blnIsGroup Then
                        strDynID = INVESTIGATION
                    Else
                        blnIsGroup = (Left(strTableID, Len(ADMIN)) = ADMIN)
                        If blnIsGroup Then
                            strDynID = ADMIN
                        Else
                            blnIsGroup = (Left(strTableID, Len(PROTRESPONSE)) = PROTRESPONSE)
                            If blnIsGroup Then
                                strDynID = PREOTRESPONSE
                            Else
                                blnIsGroup = (Left(strTableID, Len(STRUCTADMIN)) = STRUCTADMIN)
                                If blnIsGroup Then
                                    strDynID = STRUCTADMIN
                                Else
                                    blnIsGroup = (Left(strTableID, Len(FPADMIN)) = FPADMIN)
                                    If blnIsGroup Then
                                        strDynID = FPADMIN
                                    End If
                                End If
                            End If
                        End If
                    End If 
                End If

                If blnIsGroup Then
                    strConfigXPath = "//question[@type='tablegroup' and @id='" & strDynID & "']/column[@mandatory]"
                Else
                    'Get the mandatory columns from the configuration table
                    strConfigXPath = "//question[@type='dynatable' and @id='" & strTableID & "']/column[@mandatory]"
                End If

                'Select the mandatory configuration columns for this table						
                Set objConfigColumns = questionsXML.selectNodes(strConfigXPath)

                If Not objConfigColumns Is Nothing Then
                    'Check that the mandatory objConfigTable columns are in the objDynaTable
                    For Each objConfigColumn in objConfigColumns
                        strConfigColumnID = objConfigColumn.getAttribute("id") & ""
                        Set objDynaTableColumn = objDynaTable.selectSingleNode("column[@id='" & strConfigColumnID & "']")

                        If objDynaTableColumn Is Nothing Then
	                        'Mandatory column not found for this table
	                        strMandCols = strMandCols & "<tr><td class=""borderedCell"">" & strTableID & "</td>"
	                        strMandCols = strMandCols & "<td class=""borderedCell"">" & strConfigColumnID & "&nbsp;<img src=""" & IMG_INVALID & """></td>"

	                        'Add button for viewing of the invalid question
	                        strMandCols = strMandCols & "<td class=""borderedCell"">"
	                        strMandCols = strMandCols & "<input id=""bntXMLCol" & intCount & """ name=""btnXMLCol" & intCount & """ type=""button"" value=""edit xml"" onclick=""vbscript:call OpenXML(True, '" & STR_EDITOR & "', True)"">"
	                        strMandCols = strMandCols & "<xml name=""xmlQuestion"">" & objDynaTable.xml & "</xml></td>"
                            
	                        blnValid = False
	                        intCount = intCount + 1
                        End If
                    Next
                End If
            Next

            If Not blnValid Then
                strResult = ""
                strResult = strResult & "<h3>Mandatory columns missing from tables</h3>" & vbCrLf
                strResult = strResult & "<table border=""1"" cellpadding=""4"">" & vbCrLf
                strResult = strResult & "<tr><td class=""borderedCell""><b>Table Id</b></td><td class=""borderedCell""><b>Column Id</b></td></tr>" & vbCrLf
                strResult = strResult & strMandCols & "</table>" & vbCrLf
            End If
        End If

        validateMandatoryColumns = blnValid
    End Function

    Private Function ValidateMandatory(protocolXml, questionsXML, strHeader, strXPath, blnSchemaLevel, strErrorIDs, strSchemaResult)
        Dim strID, strMandRows, strMandatory
        Dim objMandNode, objMandNodes, objQuestion
        Dim blnValid
        Dim intCount

        blnValid = True

        Set objMandNodes = questionsXML.selectNodes(strXPath)

        strMandRows = ""
        If Not objMandNodes Is Nothing Then
            intCount = 1
            For Each objMandNode in objMandNodes
                'Check that each question has been specified in the protocol XML
                strID = objMandNode.getAttribute("id") & ""
                Set objQuestion = protocolXml.selectSingleNode("//question[@id='" & strID & "']")

                If objQuestion Is Nothing Then
                    'The schema mandatory field is not found
                    blnValid = False					
                    strMandRows = strMandRows & "<tr>"
                    strMandRows = strMandRows & "<td class=""borderedCell"">Question not in XML</td>"
                    strMandRows = strMandRows & "<td class=""borderedCell"">" & strID & "</td>"
                    strMandRows = strMandRows & "<td class=""borderedCell""><input type=""button"" value=""edit xml"" onclick=""vbscript:call OpenXML(False, '" & STR_EDITOR & "', True)""></td>"
                    strMandRows = strMandRows & "</tr>" & vbCrLf
                Else
                    'If the mandatory node is there, and the function is testing schema-level mandatory fields,
                    'the function needs to check if the mandatory attribute is there and has been set to true
                    If blnSchemaLevel Then
	                    strMandatory = objQuestion.getAttribute("mandatory") & ""
	                    If Not (strMandatory = "true") Then
		                    blnValid = False
                            
		                    strMandRows = strMandRows & "<tr>"
		                    strMandRows = strMandRows & "<td class=""borderedCell"">Mandatory attribute<br>not set to ""true""</td>"
		                    strMandRows = strMandRows & "<td class=""borderedCell"">" & strID & "</td>"
		                    strMandRows = strMandRows & "<td class=""borderedCell""><input"
		                    strMandRows = strMandRows & " id=""mandSchema" & CStr(intCount) & """"
		                    strMandRows = strMandRows & " name=""btnXMLmandSchema" & CStr(intCount) & """ type=""button"""
		                    strMandRows = strMandRows & " value=""edit xml"" onclick=""vbscript:call OpenXML(True, '" & STR_EDITOR & "', True)"">"
		                    strMandRows = strMandRows & "<xml name=""xmlQuestion"">" & objQuestion.xml & "</xml></td>"							
		                    strMandRows = strMandRows & "</tr>" & vbCrLf
                            
		                    If (Len(strErrorIDs) = 0) Then
                                strErrorIDs = "mandSchema" & CStr(intCount)
		                    Else
                                strErrorIDs = strErrorIDs & "" & "mandSchema" & CStr(intCount)
		                    End If
                            
		                    intCount = intCount + 1
	                    End If
                    End If
                End If
            Next					
        End If

        If Not blnValid Then
            strSchemaResult = ""
            strSchemaResult = strSchemaResult & "<h3>" & strHeader & "</h3>"
            strSchemaResult = strSchemaResult & "<table class=""withborder"" border=""1"" cellpadding=""4"">" & vbCrLf 
            strSchemaResult = strSchemaResult & "<tr><td class=""borderedCell""><b>Error type</b></td><td class=""borderedCell""><b>Id</b></td></tr>" & vbCrLf
            strSchemaResult = strSchemaResult & strMandRows 
            strSchemaResult = strSchemaResult & "</table>" & vbCrLf
        End If

        validateMandatory = blnValid
    End Function

    Private Sub ConvertIDsToLowerCase(protocolXml)
    '
    ' Description:  Converts all question IDs to lowercase for processing purposes
    ' Parameters:   None
    '

        Dim objQuestions
        Dim objQuestion
        Dim objColumns
        Dim objColumn
        Dim strID
        Dim strColumnID

        Set objQuestions = protocolXml.selectNodes("//category/question[@id!='']")
        If Not objQuestions Is Nothing Then
	        For Each objQuestion In objQuestions
		        strID = LCase(objQuestion.getAttribute("id") & "")
		        Call objQuestion.setAttribute("id", strID)
		        Set objColumns = objQuestion.selectNodes("//column")
                
		        For Each objColumn In objColumns
			        strColumnID = LCase(objColumn.getAttribute("id") & "")
			        Call objColumn.setAttribute("id", strColumnID)
		        Next
	        Next
        Else
	        Response.Write("Error: No questions could be selected." & vbCrLf)
        End If
    End Sub

    Private Function GetTabInfo(protocolXml, strResult, strInvalidTabIDs)
    '
    ' Description:  Writes all tabs out and verifies any missing labels
    ' Parameters:   strResult - Returns the tab info errors
    '               strInvalidTabIDs - Returns the invalid tab IDs
    ' Returns:      True if tab info valid, False otherwise
    '	

        Dim objTab, objTabs
        Dim lngCount 
        Dim strTabText
        Dim blnSuccess

        blnSuccess = True

        Set objTabs = protocolXml.selectNodes("//protocol/category")

        lngCount = 1
        strResult = ""
        strResult = strResult & "<h3>Tabs</h3>"
        strResult = strResult & "<table border=""1"" cellpadding=""4"">"

        For Each objTab in objTabs
            strTabText	=	objTab.getAttribute("text") & ""
            If Len(strTabText) = 0 Then
                If blnSuccess Then
                    blnSuccess = False
                End If
                strResult = strResult & "<tr>"
                strResult = strResult & "<td class=""borderedCell""><nobr><b>Tab " & CStr(lngCount) & "</b>"
                strResult = strResult & "</nobr><br/><img src=""" & IMG_INVALID & """/></td>"
                strResult = strResult & "<td class=""borderedCell""><input"
                strResult = strResult & " id=""InvalidTab" & CStr(lngCount) & """"
                strResult = strResult & " name=""btnXMLInvalidTab" & CStr(lngCount) & """ type=""button"" value=""edit xml"" onclick=""vbscript:call OpenXML(True, '" & STR_EDITOR & "', True)"">"
                strResult = strResult & "<xml name=""xmlQuestion"">" & objTab.xml & "</xml></td>"
                strResult = strResult & "</tr>"

                If (Len(strInvalidTabIDs) = 0) Then
                    strInvalidTabIDs = "InvalidTab" & CStr(lngCount)
                Else
                    strInvalidTabIDs = strInvalidTabIDs & "" & "InvalidTab" & CStr(lngCount)
                End If
            End If				

            lngCount = lngCount + 1
        Next

        strResult = strResult & "</table>"

        getTabInfo = blnSuccess
    End Function

    Private Function ValidateDuplicateIDs(protocolXml, strDupIDResult, strDuplicateIDs)
    '
    ' Description:  Checks the protocol xml for questions with duplicate ID attributes
    ' Parameters:   strDupIDResult - Returns the duplicate ID errors
    '               strDuplicateIDs - Returns the invalid question IDs
    ' Returns:      True if no duplicates, False otherwise
    '

        Dim strXPath, strHeader, strMsg, strID, strQuestionMsg
        Dim blnValid, blnHeaderWritten
        Dim objQuestion, objQuestions, objDupQuestion, objDupQuestionList
        Dim lngCount

        'Duplicate ids
        strDupIDResult = ""
        strHeader = "Fields with duplicate ids"
        strMsg = "There is more than one field with the id attribute: <b>~id~</b>"

        Set objQuestions = protocolXml.selectNodes("//question[@id = preceding::question/@id]")	

        If Not objQuestions Is Nothing Then
            blnValid = (objQuestions.Length = 0)
            If Not blnValid Then
                strDupIDResult	=	strDupIDResult & "<h3>" & strHeader & "</h3>" & vbCrLf

                'Write out the identifier and the offending text attribute
                For Each objQuestion In objQuestions
                    strQuestionMsg = strMsg
                    strQuestionMsg = buildMessage(objQuestion, strQuestionMsg, "~")

                    strDupIDResult = strDupIDResult & strQuestionMsg & vbCrLf

                    'Go through all the duplicate ids and write buttons to jump to them
                    strDupIDResult = strDupIDResult & "<table border=""0"" cellpadding=""4"">" & vbCrLf
                    strID = objQuestion.getAttribute("id")
                    lngCount = 1	
                    Set objDupQuestionList = protocolXml.selectNodes("//question[@id='" & strID & "']")
                    strDupIDResult = strDupIDResult & "<tr>" & vbCrLf
                    For Each objDupQuestion in objDupQuestionList
                        strDupIDResult = strDupIDResult & "<td class=""borderedCell"">"
                        strDupIDResult = strDupIDResult & "<input id=""Duplicate" & lngCount & """"
                        strDupIDResult = strDupIDResult & " name=""btnXMLDuplicate" & lngCount & """ type=""button"" value="""
                        strDupIDResult = strDupIDResult & objDupQuestion.getAttribute("id") & " #" & lngCount & """ "
                        strDupIDResult = strDupIDResult & "onclick=""vbscript:call OpenXML(True, '" & STR_EDITOR & "', True)"">"
                        strDupIDResult = strDupIDResult & "<xml>" & objDupQuestion.xml & "</xml>"
                        strDupIDResult = strDupIDResult & "</td>" & vbCrLf

                        If (Len(strDuplicateIDs) = 0) Then
                            strDuplicateIDs = "Duplicate" & CStr(lngCount)
                        Else
                            strDuplicateIDs = strDuplicateIDs & "" & "Duplicate" & CStr(lngCount)
                        End If

                        lngCount = lngCount	+ 1
                    Next
                    strDupIDResult = strDupIDResult & "</tr>" & vbCrLf
                    strDupIDResult = strDupIDResult & "</table><br/>" & vbCrLf
                Next
            End If
        End If

        validateDuplicateIDs = blnValid
    End Function

    Private Function ValidateNodes(syntaxXML, tablesXML, objQuestionNode, blnGroup, strResult)
    '
    ' Description:  Checks child nodes (option, help etc) for questions
    ' Parameters:   
    ' Returns:      
    '

        Dim blnQuestionValid, blnChildNodeValid
        Dim objChildNode
        Dim strChildNodeResult, strGrandChildNodeResult

        blnQuestionValid = displayChildNodeErrors(syntaxXML, tablesXML, objQuestionNode.childNodes, "1", blnGroup, strChildNodeResult)
        blnChildNodeValid = True
        For Each objChildNode in objQuestionNode.childNodes		
            If objChildNode.childNodes.length > 0 Then
                blnChildNodeValid = displayChildNodeErrors(syntaxXML, tablesXML, objChildNode.childNodes, "2", blnGroup, strGrandChildNodeResult)
                If Not blnChildNodeValid Then
                    blnQuestionValid = False
                End If
            End If
	    Next	

        If (Not blnQuestionValid) Or (Not blnChildNodeValid) Then
            'Set up the table for the child nodes
            strResult = strResult & "<table class=""withborder"" border=""1"" width=""100%"" height=""100%"" cellpadding=""4"">" & vbCrLf
            strResult = strResult & "<tr><td class=""borderedCell""><b>Level</b></td><td class=""borderedCell""><b>Node</b></td><td class=""borderedCell""><b>Attributes/<span style='color:red;font-weight:bold;'>Values</b></td></tr>" & vbCrLf
            strResult = strResult & "<tr>" & vbCrLf
            strResult = strResult & strChildNodeResult & vbCrLf
            strResult = strResult & strGrandChildNodeResult & vbCrLf
            strResult = strResult & "</tr>" & vbCrLf
            strResult = strResult & "</table>" & vbCrLf		
        Else
            strResult = strResult & "&nbsp;"
        End If	

        validateNodes = blnQuestionValid
    End Function

    Private Function DisplayChildNodeErrors(syntaxXML, tablesXML, objChildNodes, lngLevel, blnGroup, strResult)
        Dim objChildNode, objValidNode, objChildNodeForAttr
        Dim blnChildNodeInvalid, blnActive, blnValidAttributes, blnQuestionValid, blnValidColumnID
        Dim strValidNodeXPath, strImg, strAttrResult, strQuestionType, strResultColumnType
        Dim lngCount

        blnQuestionValid = True
        lngCount = 1

        'For each childnode, check that it is a valid child node
        For Each objChildNode in objChildNodes
            blnChildNodeInvalid = True
            'Check that it is not a comment or a text node
            If (Not objChildNode.nodeName = "#comment") And (Not objChildNode.nodeName = "#text") Then
                'Validate the child node against the syntax xml
                If LCase(objChildNode.parentNode.nodeName) = "question" Then
                    strValidNodeXPath = "//questions/question[@type='" & objChildNode.parentNode.getAttribute("type") & "']/node[@id='" & objChildNode.nodeName & "']"
                Else
                    strValidNodeXPath = "//nodes/node/node[@id='" & objChildNode.nodeName & "']"	
                End If

                Set objValidNode = syntaxXML.selectSingleNode(strValidNodeXPath)

                'Initialise to invalid image
                strImg = IMG_VALID
                strAttrResult = "&nbsp;"

                'If the child node can be found in the syntax xml
                If Not objValidNode Is Nothing Then
                    'checking a correct childnode
                    blnActive = objValidNode.getAttribute("active") & ""
                    If Len(blnActive) > 0 Then
                        blnActive = CBool(blnActive)
                    Else
                        blnActive = False
                    End If

                    If blnActive Then						
                        'A correct and active childnode: The node is only valid if its attributes are valid
                        blnValidAttributes = validateAttributes(syntaxXML, objChildNode, objChildNode.nodeName, strAttrResult, False)
                        If Not blnValidAttributes Then
                            blnChildNodeInvalid = False
                            blnQuestionValid = False	
                            strImg = IMG_INVALID
                        Else
                            'Column ID check				
                            If (lngLevel = 1) And (LCase(objChildNode.nodeName) = "column") And (Not blnGroup) Then
                                blnValidColumnID = validateColumnID(tablesXML, objChildNode, strResultColumnType)
                                If Not blnValidColumnID Then
                                    blnChildNodeInvalid = False
                                    blnQuestionValid = False
                                    strImg = IMG_INVALID
                                End If
                            End If
                        End If
                    Else
                        strImg = IMG_INVALID
                        blnChildNodeInvalid = False
                        blnQuestionValid = False
                    End If
                Else
                    strImg = IMG_INVALID
                    blnChildNodeInvalid = False
                    blnQuestionValid = False
                End If

                If Not blnChildNodeInvalid Or Not blnValidAttributes Then
                    strResult = strResult & "<td class=""borderedCell"">" & CStr(lngLevel) & "</td>" & vbCrLf
                    strResult = strResult & "<td class=""borderedCell"">" & vbCrLf
                    strResult = strResult & "<table class=""noborder"" border=""0"" cellpadding=""4"">" & vbCrLf
                    strResult = strResult & "<tr>" & vbCrLf
                    strResult = strResult & "<td>" & objChildNode.nodeName 
                    
                    If Not blnValidColumnID Then
                        strResult = strResult & " ID=" & objChildNode.getAttribute("id") & ""
                        
                        If Len(strResultColumnType) > 0 Then
                            strResult = strResult & "<br>Type=" & objChildNode.getAttribute("type") & "(" & strResultColumnType & ")"
                        End If
                    End If
                    
                    strResult = strResult & "</td>" & vbCrLf
                    strResult = strResult & "<td><img src=""" & strImg & """/></td>" & vbCrLf
                    strResult = strResult & "</tr>" & vbCrLf
                    strResult = strResult & "</table>" & vbCrLf
                    strResult = strResult & "</td>" & vbCrLf
                    
                    If Not blnValidAttributes Then
                        strResult = strResult & "<td class=""borderedCell"" valign=""top"">" & strAttrResult & "</td>"  & vbCrLf
                    Else
                        strResult = strResult & "<td class=""borderedCell"">&nbsp;</td>"  & vbCrLf
                    End If
                    
                    strResult = strResult & "</tr>" & vbCrLf
                    lngCount = lngCount + 1
                End If
            End If
        Next
        displayChildNodeErrors = blnQuestionValid
    End Function

    Private Function ValidateQuestionList(configurationFiles, objQuestions, strHeader, strColumns, lngQuestionType, strErrorResult, strIDs)
    '
    ' Description:  Checks all question related verification
    ' Parameters:   
    ' Returns:      
    '

        Dim objQuestion
        Dim blnValidQuestionType, blnValidQuestionID, blnValidAttributes, blnValidNodes, blnValidDependency
        Dim blnValidFilters, blnValidText, blnGroup, blnValid, blnValidPrePopulate, blnValidValues
        Dim strQuestionID, strQuestionType, strImage, strResult, strQuestionRowText
        Dim strQuestionText, strSimpleQuestionType, strQID, strExtra
        Dim lngCount
        Dim blnValidPrePopulateGeneric

        blnValid = True
        strErrorResult = ""
        strResult = ""
        lngCount = 1

        'Determine type of question
        If lngQuestionType = TABLE Then
            strSimpleQuestionType = "table"
        Else
            strSimpleQuestionType = "field"
        End If

        For Each objQuestion in objQuestions
            strResult = ""

            'Get the ID attribute
            strQuestionID = objQuestion.getAttribute("id") & ""

            'Get the type attribute
            strQuestionType = objQuestion.getAttribute("type") & ""

            strQuestionText = objQuestion.getAttribute("text")

            '1:	TYPE attribute check
            If (Len(Trim(strQuestionType)) = 0) Then
                blnValidQuestionType = False
            Else
                blnValidQuestionType = determineQuestionType(configurationFiles.SyntaxXml, strQuestionType)
            End If

            '2:	ID attribute check
            blnValidQuestionID = validateObjectID(configurationFiles.BuildMessageXml, configurationFiles.TablesXml, objQuestion, lngQuestionType, blnGroup)

            strImage = IMG_INVALID
            If blnValidQuestionID Then strImage = IMG_VALID								

            strResult = strResult & "<tr><td class=""borderedCell"">"
            strResult = strResult & "<table class=""withborder"" border=""0"" width=""100%"" height=""100%"" cellpadding=""4"">"
            strResult = strResult & "<tr><td class=""borderedCell""><b>Id</b></td></tr><tr>"
            strResult = strResult & addToValidationResult(strImage, strQuestionID, "id", strQID, strSimpleQuestionType, "")
            strResult = strResult & "</tr></table></td><td class=""borderedCell"">"
            strResult = strResult & "<table class=""withborder"" border=""0"" width=""100%"" cellpadding=""4"">"
            strResult = strResult & "<tr><td class=""borderedCell""><b>Type</b></td><td class=""borderedCell""><b>Text</b></td><td class=""borderedCell""><b>Attributes</b></td></tr>"
            strResult = strResult & "<tr>"

            strImage = IMG_INVALID
            If blnValidQuestionType Then strImage = IMG_VALID
            strResult = strResult & addToValidationResult(strImage, strQuestionType, "type", strQID, strSimpleQuestionType, "")

            blnValidText = True
            If lngQuestionType = FIELD Then
                If blnGroup Then
                    strQuestionText = objQuestion.getAttribute("text")
	                blnValidText = (Len(strQuestionText) <= 98)
	                If Not blnValidText Then
                        strImage = IMG_INVALID
                        strResult = strResult & "<td class=""borderedCell""><table class=""noborder"" cellpadding=""4"">" & vbCrLf
                        strResult = strResult & "<tr><td class=""borderedCell"">" & vbCrLf
                        strResult = strResult & "<table class=""noborder"" cellpadding=""4"">" & vbCrLf
                        strResult = strResult & "<tr>" & vbCrLf
                        strResult = strResult & "<td class=""borderedCell"">Too long</td>" & vbCrLf
                        strResult = strResult & "</tr>" & vbCrLf

                        strResult = strResult & "<tr>" & vbCrLf
                        strResult = strResult & "<td class=""borderedCell"">length: " & Len(strQuestionText) & "</td>" & vbCrLf
                        strResult = strResult & "</tr>" & vbCrLf

                        strResult = strResult & "<tr>" & vbCrLf
                        strResult = strResult & "<td class=""borderedCell"">allowed: 98</td>" & vbCrLf
                        strResult = strResult & "</tr>" & vbCrLf			
                        
                        strResult = strResult & "</table></td>" & vbCrLf
                        strResult = strResult & "<td class=""borderedCell""><img src=""" & strImage & """></td>" & vbCrLf
                        strResult = strResult & "</tr></table>" & vbCrLf
                        strResult = strResult & "</td>" & vbCrLf
                    Else
                        strResult = strResult & "<td class=""borderedCell"">&nbsp;</td>"				
                    End If
                Else
                    strResult = strResult & "<td class=""borderedCell"">&nbsp;</td>"
                End If
            Else
                strResult = strResult & "<td class=""borderedCell"">&nbsp;</td>"
            End If

            strExtra = ""
            strExtra = strExtra & "<input id=""" & strSimpleQuestionType & CStr(lngCount) & """"
            strExtra = strExtra & " name=""btnXML" & strSimpleQuestionType & CStr(lngCount) & """ "
            strExtra = strExtra & " onclick=""vbscript:call OpenXML(True, '" & STR_EDITOR & "', True)"" value=""edit xml"" type=""button"">"
            strExtra = strExtra & "<xml name=""xmlQuestion"">" & objQuestion.xml & "</xml>"

            '3:	Attributes check based on type attribute
            If blnValidQuestionType Then
                '3:	Validate attributes
                strResult = strResult & "<td class=""borderedCell"">"
                blnValidAttributes = validateAttributes(configurationFiles.SyntaxXml, objQuestion, strQuestionType, strResult, True)
                strResult = strResult & "</td></tr></table></td></tr>"

                'Second row for the question
                strResult = strResult & "<tr><td class=""borderedCell"" align=""center"" valign=""middle"">" & strExtra & "</td><td class=""borderedCell"" colspan=""3"">"
                strResult = strResult & "<table class=""withborder"" width=""100%"" cellpadding=""4"">"
                strResult = strResult & "<tr><td class=""borderedCell""><b>Childnodes</b></td><td class=""borderedCell""><b>Pre-population</td>"
                strResult = strResult & "<td class=""borderedCell""><b>Values</b></td><td class=""borderedCell""><b>Dependency</b></td></tr>"

                strResult = strResult & "<tr>"

                '4: Validate nodes
                strResult = strResult & "<td class=""borderedCell"">"
                blnValidNodes = validateNodes(configurationFiles.SyntaxXml, configurationFiles.TablesXml, objQuestion, blnGroup, strResult)
                strResult = strResult & "</td>"				
            Else
                strResult = strResult & "<td class=""borderedCell"">&nbsp;</td><td class=""borderedCell"">&nbsp;</td>"

                'Second row for the question
                strResult = strResult & "</tr><tr style=""background-Color:eee9e9;height:15px""><td class=""borderedCell"" colspan=""6"">&nbsp;</td></tr>"

                strResult = strResult & "<tr><td class=""borderedCell"" align=""center"" valign=""middle"">" & strExtra & "</td><td class=""borderedCell"" colspan=""3"">"
                strResult = strResult & "<table class=""withborder"" width=""100%"" cellpadding=""4"">"
                strResult = strResult & "<tr><td class=""borderedCell""><b>Childnodes</b></td><td class=""borderedCell""><b>Pre-population</td>"
                strResult = strResult & "<td class=""borderedCell""><b>Values</b></td><td class=""borderedCell""><b>Dependency</b></td></tr>"

                strResult = strResult & "<td class=""borderedCell"">&nbsp;</td>"
            End If

            strResult = strResult & "<td class=""borderedCell"">"
            If (blnValidQuestionID) Then
                '5:	Check pre-population object and property				
	            blnValidPrePopulate = validatePrePopulationGPASS(configurationFiles.PrapiXml, configurationFiles.PrePopObjectsXml, objQuestion, blnGroup, lngQuestionType, strResult)				
            Else
                strResult = strResult & "&nbsp;"
            End If

            If (blnValidQuestionID) Then
                '5:	Check pre-population object and property				
                blnValidPrePopulateGeneric = validatePrePopulationGeneric(configurationFiles.PrePopXml, objQuestion, blnGroup, lngQuestionType, strResult)				
            Else
                strResult = strResult & "&nbsp;"
            End If			

            strResult = strResult & "</td>"

            blnValidValues = True
            strResult = strResult & "<td class=""borderedCell"">"			
            If (blnValidQuestionID) And (lngQuestionType = FIELD) Then
                '6: Check the values of a question (only for select and radio groups as they have option nodes with values)
                Select Case strQuestionType
                    Case "radio", "select"
                        blnValidValues = validateValidValues(configurationFiles.QuestionValuesXml, objQuestion, strResult)
                    Case Else
                        strResult = strResult & "&nbsp;"
                End Select
            Else
                strResult = strResult & "&nbsp;"
            End If
            strResult = strResult & "</td>"

            blnValidDependency = True
            strResult = strResult & "<td class=""borderedCell"">"
            If (blnValidQuestionID) And (lngQuestionType = FIELD) Then
                '7: Check if this question is dependent on another question
                blnValidDependency = validateDependency(configurationFiles.ProtocolXml, configurationFiles.QuestionsXml, objQuestion, strResult)				
            Else
                strResult = strResult & "&nbsp;"
            End If
            strResult = strResult & "</td>"

            'Close row
            strResult = strResult & "</tr></table></td>" & vbCrLf
            strResult = strResult & "<tr style=""background-Color:eee9e9;height:15px""><td class=""borderedCell"" colspan=""9""></td></tr>" & vbCrLf

            'If an error occurred in any of the question verification checks,
            'add the row to the Result
            If ((Not blnValidQuestionType) Or (Not blnValidQuestionID) Or _
                (Not blnValidAttributes) Or (Not blnValidNodes) Or _
                (Not blnValidText) Or (Not blnValidPrePopulate)	Or (Not blnValidPrePopulateGeneric) Or (Not blnValidValues) Or _
                (Not blnValidDependency)) Then
                strErrorResult = strErrorResult & strResult

                If strIDs = "" Then
                    strIDs = strIDs & strSimpleQuestionType & CStr(lngCount)
                Else
                    strIDs = strIDs & "" & strSimpleQuestionType & CStr(lngCount)
                End If

                blnValid = False
            End If

            lngCount = lngCount + 1
        Next

        If Not blnValid Then
            strErrorResult = startTable(True, "width=100%") & writeResultHeader(strHeader, 6) & strErrorResult & endTable()
        End If		

        validateQuestionList = blnValid
    End Function

    Private Function ValidateDependency(protocolXml, questionsXML, objQuestion, strResult)
        Dim blnValid
        Dim strID, strDependencyXPath, strDependentOnQuestion, strDependencyHTML
        Dim objDependentQuestion, objDependentOnQuestion

        blnValid = True
        strDependencyHTML = ""
        If Not objQuestion Is Nothing Then
            strID = objQuestion.getAttribute("id") & ""

            If (Len(strID) > 0) Then
                strDependencyXPath = "/questions/question[@id='" & strID & "' and @dependent]"

                Set objDependentQuestion = questionsXML.selectSingleNode(strDependencyXPath)

                If Not objDependentQuestion Is Nothing Then
                    'This is a dependent question
                    strDependentOnQuestion = objDependentQuestion.getAttribute("dependent") & ""

                    If (Len(strDependentOnQuestion) > 0) Then
	                    'Check that the dependent-on question exists in the protocol xml
	                    Set objDependentOnQuestion = protocolXml.selectSingleNode("//question[@id='" & strDependentOnQuestion & "']")

	                    If objDependentOnQuestion Is Nothing Then
    	                    strDependencyHTML = strDependentOnQuestion & "&nbsp;<img src=""" & IMG_INVALID & """>"					
    	                    blnValid = False
	                    Else
    	                    strDependencyHTML = "&nbsp;"
	                    End If
                    End If
                End If
            End If
        End If

        If blnValid Then strDependencyHTML = "&nbsp;"
        strResult = strResult & strDependencyHTML

        validateDependency = blnValid
    End Function

    Private Function ValidateValidValues(questionValuesXML, objQuestion, strResult)
        Dim objQuestionInValuesXML, objItemValue, objOptions, objOption
        Dim strXPath, strValue, strText, strOptionXPath
        Dim strQuestionId, strValidValuesHTML, strValidValuesErrors
        Dim blnValid

        blnValid = True
        
        strQuestionId = objQuestion.getAttribute("id") & ""

        If (Len(strQuestionId) > 0) Then
            'Try to select the question from the validvalues configuration file
            strXPath = "/items/item[@id='" & strQuestionId & "']"
            Set objQuestionInValuesXML = questionValuesXML.selectSingleNode(strXPath)

            If Not objQuestionInValuesXML Is Nothing Then
                'If the question is specified in the validvalues xml file, check if 
                'the options of the question are valid based on this file
                Set objOptions = objQuestion.selectNodes("option")

                If Not objOptions Is Nothing Then
                    'For each option, check that it has the correct values
                    For Each objOption in objOptions
                        'Question's current option
                        strValue = objOption.getAttribute("value") & ""
                        strText = objOption.getAttribute("text") & ""

                        strOptionXPath = "itemvalue[@value='" & strValue & "' and @text='" & strText & "']"

                        Set objItemValue = objQuestionInValuesXML.selectSingleNode(strOptionXPath)

                        If objItemValue Is Nothing Then
                            blnValid = False
	                        strValidValuesErrors = strValidValuesErrors & "<tr><td class=""borderedCell"">text=<nobr>" & strText & "</nobr></td>"
	                        strValidValuesErrors = strValidValuesErrors & "<td class=""borderedCell"">value=" & strValue & "</td>"
	                        strValidValuesErrors = strValidValuesErrors & "<td class=""borderedCell""><img src=""" & IMG_INVALID & """/></td></tr>"
                        End If
                    Next
                End If
            End If
        End If		

        If Not blnValid Then
            strValidValuesHTML = strValidValuesHTML & "<table class=""withborder"" border=""1"" valign=""top"" cellpadding=""4"">" & vbCrLf
            strValidValuesHTML = strValidValuesHTML & strValidValuesErrors
            strValidValuesHTML = strValidValuesHTML & "</table>" & vbCrLf
        Else
            strValidValuesHTML = "&nbsp;"
        End If

        strResult = strResult & strValidValuesHTML

        validateValidValues = blnValid
    End Function

    Private Function ValidateAttributes(syntaxXML, objQuestion, strQuestionType, strResult, blnQuestionLevel)
    '
    ' Description:  Checks attributes for questions
    ' Parameters:   
    ' Returns:      
    '

        Dim objQuestionAttrib
        Dim objSyntaxQuestionAttrib
        Dim objValidAttribList
        Dim objValidAttrib
        Dim strImg
        Dim blnActive
        Dim blnValid
        Dim blnValidAttr
        Dim lngCount
        Dim strAttributesHTML
        Dim blnFound

        blnValid = True
        strAttributesHTML = ""
        strAttributesHTML = strAttributesHTML & "<table class=""noborder"" valign=""top"" cellpadding=""4"">" & vbCrLf
        strAttributesHTML = strAttributesHTML & "<tr>"
        lngCount = 1

        For Each objQuestionAttrib in objQuestion.Attributes
            If objQuestionAttrib.name <> "type" And objQuestionAttrib.name <> "qid" Then
                If blnQuestionLevel Then
                    Set objSyntaxQuestionAttrib = syntaxXML.selectSingleNode("//questions/question[@type='" & strQuestionType & "']/attribute[@id='" & objQuestionAttrib.name & "']")
                    
                    'Check the question attribute is allowed
                    If objSyntaxQuestionAttrib Is Nothing Then
                        strImg = IMG_INVALID
                        blnValidAttr = False
                        blnValid = False
                    Else
                        strImg = IMG_VALID
                        Set objValidAttribList = objSyntaxQuestionAttrib.SelectNodes ("//attributes/attribute[@id='" & objQuestionAttrib.name & "']/value")
                    End If
                Else
                    Set objSyntaxQuestionAttrib = syntaxXML.selectSingleNode("//nodes/node[@id='" & strQuestionType & "']/attribute[@id='" & objQuestionAttrib.name & "']")
                    Set objValidAttribList = objSyntaxQuestionAttrib.SelectNodes("value")
                End If
                
                'If we have a valid attribute, continue checking
                If blnValid Then
                    strImg = IMG_INVALID
                    blnActive = False
                    
                    If Not objSyntaxQuestionAttrib Is Nothing Then
                        blnActive = CBool(objSyntaxQuestionAttrib.getAttribute("active") & "")
                        
                        If blnActive Then
                            'Check that the value of the attributes are contianed in syntax.xml
                            If Not objValidAttribList Is Nothing Then                   
                                blnFound = true
                                For each objValidAttrib in objValidAttribList
                                    'Check if the value is in syntax.xml
                                    If (objValidAttrib.text = objQuestionAttrib.value)  then
    	                                blnFound = True
    	                                Exit For
                                    Else
                                        blnFound = false
                                    End if
                                Next

                                If Not blnFound Then
                                    'Raise error
	                                blnValid = False
	                                strAttributesHTML = strAttributesHTML & "<td class=""borderedCell"">" & objQuestionAttrib.name & " = " & "<span style='color:red;font-weight:bold;'>""" &  objQuestionAttrib.value & """</>" & "</td><td class=""borderedCell""><img src=""" & strImg & """/></td>"
                                End If
                            End If

                            strImg = IMG_VALID	
                            blnValidAttr = True					
                        Else
                            blnValidAttr = False
                            If blnValid Then
                                blnValid = False
                            End If
                        End If
                    Else
                        blnValidAttr = False
                        If blnValid Then
                            blnValid = False
                        End If
                    End If
                End If
                If Not blnValidAttr Then
                    If blnQuestionLevel Then
                        strAttributesHTML = strAttributesHTML & "<td class=""borderedCell"">" & objQuestionAttrib.name & "</td><td class=""borderedCell""><img src=""" & strImg & """/></td>"
                    Else
                        strAttributesHTML = strAttributesHTML & "<td class=""borderedCell"">" & objQuestionAttrib.name & "</td><td class=""borderedCell""><img src=""" & strImg & """/></td>"
                    End If
                End If
                lngCount = lngCount + 1
            End If
        Next
        
        strAttributesHTML = strAttributesHTML & "</tr>" & vbCrLf
        strAttributesHTML = strAttributesHTML & "</table>" & vbCrLf

        If Not blnValid Then
            strResult = strResult & strAttributesHTML
        Else
            If blnQuestionLevel Then
                strResult = strResult & "&nbsp;"
            End If
        End If

        validateAttributes = blnValid
    End Function

    Private Function DetermineQuestionType(syntaxXML, strQuestionType)
    '
    ' Description:  Checks the question's type attribute
    ' Parameters:   strQuestionType - The question type to check
    ' Returns:      
    '

        Dim objQuestionType
        Dim objQuestionTypes
        Dim blnTypeFound
        Dim strValidQuestionType 

        blnTypeFound = False

        Set objQuestionTypes = syntaxXML.selectNodes("//attributes/attribute[@id='type']/*")

        'Check against the configuration file to see if it is a valid type
        For Each objQuestionType In objQuestionTypes
            strValidQuestionType = objQuestionType.getAttribute("id") & ""

            If strQuestionType = strValidQuestionType Then
                blnTypeFound = True
                Exit For
            End If
        Next
        determineQuestionType = blnTypeFound
    End Function

    Private Function AddToValidationResult(strImage, strInfo, strAttribName, strQID, strSimpleQuestionType, strExtra)
    '
    ' Description:  Adds validation results to the verification report
    ' Parameters:   
    ' Returns:      
    '

        Dim strResult

        If Len(strExtra) > 0 Then
            strInfo = strExtra
        End If

        strResult = ""
        strResult = strResult & "<td class=""borderedCell"" id=""" & strSimpleQuestionType & strAttribName & strQID & """>" & strInfo & "&nbsp;"
        strResult = strResult & "<img src=""" & strImage & """"
        strResult = strResult & ">"

        addToValidationResult = strResult
    End Function

    Private Function StartTable(blnBorder, strAddProp)
    '
    ' Description:  Starts an HTML table
    ' Parameters:   
    ' Returns:      
    '

        Dim strBorder
        Dim strTableHeader

        strBorder = ""		
        If blnBorder Then
            strBorder = "border=""1"""
        End If

        strTableHeader = "<table class=""withborder"" " & strBorder & " " & strAddProp & " cellpadding=""4"">" & vbCrLf
        startTable = strTableHeader
    End Function

    Private Function EndTable()		
    '
    ' Description:  Ends an HTML table
    ' Parameters:   None
    ' Returns:      
    '

        endTable = "</table>" & vbCrLf
    End Function

    Private Function WriteResultHeader(strHeaderCaption, lngHeaderSpan)
    '
    ' Description:  Adds headers to the verification report
    ' Parameters:   
    ' Returns:      
    '

        Dim strResult

        strResult = ""
        strResult = strResult & "<tr>"
        strResult = strResult & "<td class=""borderedCell"" colspan=""" & CStr(lngHeaderSpan) & """ style=""font-size:18px""><b>" & strHeaderCaption & "</b></td>"
        strResult = strResult & "</tr>" & vbCrLf

        writeResultHeader = strResult
    End Function

    Private Function BuildMessage(objQuestion, strMsg, strMarker)
        Dim intStartMarker
        Dim intEndMarker
        Dim intMarker
        Dim intLength
        Dim strAttrName
        Dim strAttrValue
        Dim strMsgTemp

        'Go through the string, find the markers
        'and replace them with the attributes
        intStartMarker = 1
        strMsgTemp = strMsg

        Do While intStartMarker > 0
            'Get the start marker
            intStartMarker = InStr(intStartMarker, strMsgTemp, strMarker)
            If intStartMarker > 0 Then
                'Get the end marker 
                intEndMarker = InStr(intStartMarker+1, strMsgTemp, strMarker)

                'Get the length of the marker
                intLength = (intEndMarker-intStartMarker-1)

                'Get the attribute name from the marker
                strAttrName = Mid(strMsgTemp, intStartMarker+1, intLength)
                strMsgTemp = Mid(strMsgTemp, intEndMarker+1, Len(strMsgTemp) - intEndMarker+1)

                If Len(Trim(strAttrName)) > 0 Then
                    'Get the attribute value
                    strAttrValue = objQuestion.getAttribute(strAttrName) & ""
                    strAttrName = strMarker & strAttrName & strMarker

                    strMsg = Replace(strMsg, strAttrName, strAttrValue)					
                End If
            End If
        Loop

        buildMessage = strMsg
    End Function

    Private Function ValidateObjectID(buildMessageXml, tablesXML, objQuestion, lngQuestionType, blnIsGroup)
    '
    ' Description:  Checks that the question ID attribute is valid
    ' Parameters:   
    ' Returns:      
    '

        Dim objCheckQuestion
        Dim strMapperPath
        Dim strID
        Dim blnValid

        'Get the id attribute from the question node
        strID = objQuestion.getAttribute("id") & ""

        'Check to see if it is a group identifier
        blnIsGroup = (Left(strID, Len(EXAMINATION)) = EXAMINATION) Or _
                    (Left(strID, Len(INVESTIGATION)) = INVESTIGATION) Or _
                    (Left(strID, Len(ADMIN)) = ADMIN) Or _
                    (Left(strID, Len(VERIFICATION)) = VERIFICATION) Or _
                    (Left(strID, Len(PROTRESPONSE)) = PROTRESPONSE) Or _
                    (Left(strID, Len(STRUCTADMIN)) = STRUCTADMIN) Or _
                    (Left(strID, Len(FPADMIN)) = FPADMIN)
            			
        'Xpath to check the ID attribute against the build[messagetype].xml file
        strMapperPath = "//message/messageitem[@id='" & strID & "']"

        Select Case lngQuestionType
            Case FIELD
                'Group objects are always processed and do not need to be valid
                If Not blnIsGroup Then					
                    'Query the object mapper xml ( build[messagetype].xml) for validity of the ID attribute
                    Set objCheckQuestion = buildMessageXml.selectSingleNode(strMapperPath)
                    blnValid = (Not objCheckQuestion Is Nothing)
                    If LCase(strID) = "referredtospecialty" Then
                        blnValid = False
                    End If
                Else
                    blnValid = True
                End If
            Case TABLE
                If Not blnIsGroup Then
                    'For group tables, the columns still need to be checked			
	                Set objCheckQuestion = tablesXML.selectSingleNode(strMapperPath)
	                blnValid = (Not objCheckQuestion Is Nothing)
                Else
	                blnValid = True
                End If
        End Select

        validateObjectID = blnValid
    End Function

    Private Function ValidateColumnID(tablesXML, objColumn, strResultColumnType)
        Dim strColumnID, strColumnType, strID, strCheckColumnType, strMapperPath
        Dim objCheckColumn
        Dim blnValid

        strColumnID = objColumn.getAttribute("id") & ""
        strColumnType = objColumn.getAttribute("type") & ""
        strID = objColumn.parentNode.getAttribute("id") & ""

        strMapperPath = "//message/messageitem[@id='" & strID & "']/column[@id='" & strColumnID & "']"

        'Check that the columns in objQuestion are the same as the config file (Tables.xml)
        Set objCheckColumn = tablesXML.selectSingleNode(strMapperPath)

        If Not objCheckColumn Is Nothing Then
            'Check that the type is correct if a type has been specified
            strCheckColumnType = objCheckColumn.getAttribute("type") & ""
            If Len(strColumnType) > 0 Then
                If Not (LCase(strColumnType) = LCase(strCheckColumnType)) Then
                    blnValid = False
                    strResultColumnType = strCheckColumnType
                Else
                    blnValid = True
                End If
            Else
                blnValid = True
            End If
        Else
            blnValid = False
        End If				

        validateColumnId = blnValid	
    End Function

    Private Function ValidatePrePopulationGeneric(prePopXML, objQuestion, blnGroup, lngQuestionType, strResult)
        Dim strID
        Dim strObject
        Dim strProperty
        Dim strValidationResult
        Dim xmlPrePopNode
        Dim blnValid, blnObjectValid
        Dim strXPath, strImg
        Dim objColumns, objColumn, objPrePopColumn
        Dim strColumnProperty

        blnValid = True		

        'Get the ID, object, and property attribute values
        strID = objQuestion.getAttribute("id") & ""
        strObject = objQuestion.getAttribute("object") & ""
        strProperty = objQuestion.getAttribute("property") & ""

        Select Case lngQuestionType
            Case FIELD
                If ((Len(strObject) > 0) And (Len(strProperty))) Then
                    strXPath = "//questions/question[@object='" & strObject & "' and @property='" & strProperty & "']"
                        
                    Set xmlPrePopNode = prePopXML.SelectSingleNode(strXPath)
                        
                    If xmlPrePopNode Is Nothing Then
                        'Could not find the field's prepopulation setup
                        blnValid = False
                        strValidationResult = strValidationResult & "<tr>" & vbCrLf
                        strValidationResult = strValidationResult & "<td class=""borderedCell"">@object=<b>" & strObject & "</b></td>" & vbCrLf
                        strImg = IMG_INVALID
                        strValidationResult = strValidationResult & "<td class=""borderedCell"">@property=<b>" & strProperty & "</b></td>" & vbCrLf
                        strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & strImg & """/></td>" & vbCrLf
                        strValidationResult = strValidationResult & "</tr>" & vbCrLf
                    End If
                End If
            Case TABLE		
                If (Len(strObject) > 0) Then
                    strXPath = "//questions/question[@object='" & strObject & "']"

                    Set xmlPrePopNode = prePopXML.selectSingleNode(strXPath)
                    If Not xmlPrePopNode Is Nothing Then
                        blnObjectValid = True
                    Else
                        blnObjectValid = False
                    End If
                        	
                    If Not blnObjectValid Then
                        blnValid = False
                        strValidationResult = strValidationResult & "<tr>" & vbCrLf
                        strValidationResult = strValidationResult & "<td class=""borderedCell"">" & strObject & "</td>" & vbCrLf
                        strImg = IMG_INVALID
                        If blnObjectValid Then	strImg = IMG_VALID									
                        strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & strImg & """/></td></tr>" & vbCrLf
                    End If
    			
                    If blnObjectValid Then		
                        'Check the property attribute for the columns of the question
                        Set objColumns = objQuestion.selectNodes("column")						

                        For Each objColumn in objColumns
                            'Get the column Property attribute
                            strColumnProperty	=	objColumn.getAttribute("property") & ""

                            If Len(strColumnProperty) > 0 Then
                                'Select the column from the pre-population object
                                Set objPrePopColumn = xmlPrePopNode.selectSingleNode("column[@property='" & strColumnProperty & "']")
                                If objPrePopColumn Is Nothing Then
                                    blnValid = False
                                    'Column not found, so write out the object and property attributes 
                                    strValidationResult = strValidationResult & "<tr>" & vbCrLf
                                    strValidationResult = strValidationResult & "<td class=""borderedCell"">@object=<b>" & strObject & "</b></td>" & vbCrLf
                                    strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & IMG_VALID & """/></td>" & vbCrLf
                                    strValidationResult = strValidationResult & "<td class=""borderedCell"">@property=<b>" & strColumnProperty & "</b></td>" & vbCrLf
                                    strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & IMG_INVALID & """/></td>" & vbCrLf
                                    strValidationResult = strValidationResult & "</tr>" & vbCrLf
                                End If
                            End If
                        Next
                    End If
                End If
        End Select

        If Not blnValid Then
            strResult = strResult & "<table class=""noborder"" cellpadding=""4"">"
            strResult = strResult & strValidationResult
            strResult = strResult & "</table>"
        Else
            strResult = strResult & "&nbsp;"
        End If
        validatePrePopulationGeneric = blnValid	
    End Function

    Private Function ValidatePrePopulationGPASS(prapiXml, PrePopObjectsXml, objQuestion, blnGroup, lngQuestionType, strResult)
        Dim strXPath, strID, strObject, strProperty, strPrePopObject, strPrimCareAPIXPath
        Dim strValidationResult, strPrePopProperty, strImg, strColumnProperty, strColumnID, strPrePopColumnProperty
        Dim objPrePopObject, objPrePopNode, objObject, objProperty, objColumns, objColumn, objPrePopColumn
        Dim objPrePopColumnProperty
        Dim blnObjectValid, blnPropertyValid, blnValid, blnClinEvtPrePop

        blnValid = True		

        'Get the ID, object, and property attribute values
        strID = objQuestion.getAttribute("id") & ""
        strObject = objQuestion.getAttribute("objectOld") & ""
        strProperty = objQuestion.getAttribute("propertyOld") & ""

        blnClinEvtPrePop = (LCase(strObject) = READCODEEVENT) Or _
                            (LCase(strObject) = SCREENINGEVENT) Or _
                            (LCase(strObject) = PRESCRIBEDDRUGS)

        If Not blnClinEvtPrePop Then
            strObject = LCase(strObject)
            strProperty = LCase(strProperty)
        End If

        'Set the path to the pre-population info for static fields
        strXPath = "//messageitem[@id='" & strID & "']"		

        'If the object attribute has been set on the question, pre-population checking should be done
        If (Len(strObject) > 0) Then
            Select Case lngQuestionType
                Case FIELD
                    If blnGroup Then
                        'If we are dealing with a group field
                        strPrimCareAPIXPath = "//attribute[@id='objectOld']/value[@id='" & strObject & "']"
                        Set objObject = prapiXml.selectSingleNode(strPrimCareAPIXPath)
                        blnObjectValid = (Not objObject Is Nothing)
                            					
                        strPrimCareAPIXPath = "//attribute[@id='objectOld']/value[@id='" & strObject & "']/attribute[@id='propertyOld']/value[@id='" & strProperty & "']"
                        Set objProperty = prapiXml.selectSingleNode(strPrimCareAPIXPath)
                        blnPropertyValid = (Not objProperty Is Nothing)
                    Else
                        strPrePopObject = ""
                        strPrePopProperty = ""
                        'If we are dealing with static fields						
                        Set objPrePopObject = PrePopObjectsXml.selectSingleNode(strXPath)
                        If Not objPrePopObject Is Nothing Then
                            If Not blnClinEvtPrePop Then
                                Set objPrePopNode = objPrePopObject.selectSingleNode("prepop[@objectOld='" & strObject & "' and @propertyOld='" & strProperty & "']")
	                            If Not objPrePopNode Is Nothing Then								
		                            strPrePopObject = LCase(objPrePopNode.getAttribute("objectOld") & "")
		                            strPrePopProperty = LCase(objPrePopNode.getAttribute("propertyOld") & "")
	                            End If

                                blnObjectValid = (strObject = strPrePopObject)
	                            blnPropertyValid = (strProperty = strPrePopProperty)
                            Else
	                            blnObjectValid = True
	                            blnPropertyValid = True
                            End If
                        Else
                            blnObjectValid = False
                            blnPropertyValid = False
                        End If
                    End If

                    If ((Not blnObjectValid) Or (Not blnPropertyValid)) Then
                        blnValid = False
                        strValidationResult = strValidationResult & "<tr>" & vbCrLf
                        strValidationResult = strValidationResult & "<td class=""borderedCell"">@objectOld=<b>" & strObject & "</b></td>" & vbCrLf
                        strImg = IMG_INVALID
                        If blnObjectValid Then strImg = IMG_VALID									
                        strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & strImg & """/></td>" & vbCrLf
                        strValidationResult = strValidationResult & "<td class=""borderedCell"">@propertyOld=<b>" & strProperty & "</b></td>" & vbCrLf
                        strImg = IMG_INVALID
                        If blnPropertyValid Then strImg = IMG_VALID								
                        strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & strImg & """/></td>" & vbCrLf
                        strValidationResult = strValidationResult & "</tr>" & vbCrLf
                    End If					
                Case TABLE
                    If Not blnGroup Then
                        'Check the object attribute
                        Set objPrePopObject = PrePopObjectsXml.selectSingleNode(strXPath)
                        If Not objPrePopObject Is Nothing Then
                            strPrePopObject = objPrePopObject.getAttribute("objectOld") & ""
                            blnObjectValid = (strObject = strPrePopObject)
                        Else
                            blnObjectValid		= False
                        End If

                        If Not blnObjectValid Then
                            blnValid = False
                            strValidationResult = strValidationResult & "<tr>" & vbCrLf
                            strValidationResult = strValidationResult & "<td class=""borderedCell"">@objectOld=<b>" & strObject & "</b></td>" & vbCrLf
                            strImg = IMG_INVALID
                            If blnObjectValid Then	strImg = IMG_VALID									
                            strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & strImg & """/></td></tr>" & vbCrLf
                        End If

                        If Not objPrePopObject Is Nothing Then
                            'Check the property attribute for the columns of the question
                            Set objColumns = objQuestion.selectNodes("column")						

                            For Each objColumn in objColumns
                                'Get the column ID attribute
                                strColumnID = LCase(objColumn.getAttribute("id")) & ""

                                'Get the column Property attribute
                                strColumnProperty = LCase(objColumn.getAttribute("propertyOld")) & ""

                                If Len(strColumnProperty) > 0 Then
                                    'Select the column from the pre-population object
                                    Set objPrePopColumn = objPrePopObject.selectSingleNode("column[@id='" & strColumnID & "']")
                                    If Not objPrePopColumn Is Nothing Then
                                        'Found the column in the pre-population configuration
                                        'now check the property is the same on the question's column
                                            
                                        Set objPrePopColumnProperty = objPrePopColumn.selectSingleNode("prepop[@propertyOld='" & strColumnProperty & "']")
                                        If Not objPrePopColumnProperty Is Nothing Then
                                            strPrePopColumnProperty = LCase(objPrePopColumnProperty.getAttribute("propertyOld") & "")
                                            If Not (strColumnProperty = strPrePopColumnProperty) Then
                                                blnValid = False
                                                strImg = IMG_INVALID
                                                If blnObjectValid Then	strImg = IMG_VALID	
                                                'the column property attribute is not the same
                                                'write out the object and property attributes
                                                strValidationResult = strValidationResult & "<tr>" & vbCrLf
                                                strValidationResult = strValidationResult & "<td class=""borderedCell"">@objectOld=<b>" & strObject & "</b></td>" & vbCrLf
                                                strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & strImg & """/></td>" & vbCrLf
                                                strValidationResult = strValidationResult & "<td class=""borderedCell"">@propertyOld=<b>" & objColumn.getAttribute("propertyOld") & "</b></td>" & vbCrLf
                                                strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & IMG_INVALID & """/></td>" & vbCrLf
                                                strValidationResult = strValidationResult & "</tr>" & vbCrLf
                                            End If
                                        Else
                                            strImg = IMG_INVALID
                                            If blnObjectValid Then strImg = IMG_VALID	
                                            blnValid = False
                                            strValidationResult = strValidationResult & "<tr>" & vbCrLf
                                            strValidationResult = strValidationResult & "<td class=""borderedCell"">@objectOld=<b>" & strObject & "</b></td>" & vbCrLf
                                            strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & strImg & """/></td>" & vbCrLf
                                            strValidationResult = strValidationResult & "<td class=""borderedCell"">@propertyOld=<b>" & objColumn.getAttribute("propertyOld") & "</b></td>" & vbCrLf
                                            strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & IMG_INVALID & """/></td>" & vbCrLf
                                            strValidationResult = strValidationResult & "</tr>" & vbCrLf
                                        End If
                                    Else
                                        blnValid = False
                                        'Column not found, so write out the object and property attributes 
                                        strValidationResult = strValidationResult & "<tr>" & vbCrLf
                                        strValidationResult = strValidationResult & "<td class=""borderedCell"">@objectOld=<b>" & strObject & "</b></td>" & vbCrLf
                                        strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & IMG_VALID & """/></td>" & vbCrLf
                                        strValidationResult = strValidationResult & "<td class=""borderedCell"">@propertyOld=<b>" & strColumnProperty & "</b></td>" & vbCrLf
                                        strValidationResult = strValidationResult & "<td class=""borderedCell""><img src=""" & IMG_INVALID & """/></td>" & vbCrLf
                                        strValidationResult = strValidationResult & "</tr>" & vbCrLf
                                    End If
                                End If
                            Next
                        End If
                    End If
            End Select
        End If

        If Not blnValid Then
            strResult = strResult & "<table class=""noborder"" cellpadding=""4"">"
            strResult = strResult & strValidationResult
            strResult = strResult & "</table>"
        Else
            strResult = strResult & "&nbsp;"
        End If
        validatePrePopulationGPASS = blnValid
    End Function
End Class
%>