Option Explicit
'============================================================================================
' File name:    common.vbs
' Description:  Common routines.
'============================================================================================

Sub DebugWrite(strDebugMessage)
'
' Description:  Outputs a debug message.
' Parameters:   strDebugMessage - Message to output
'    
    Dim lngCount    'As Long
    Dim objRow      'As Row
    Dim objCell     'As Cell
    Dim strClass    'As String

    On Error Resume Next
    If Not OBJ_DEBUG_WINDOW Is Nothing Then
        lngCount = OBJ_DEBUG_WINDOW.document.all("debugMsg").rows.length - 1
        strClass = OBJ_DEBUG_WINDOW.document.all("debugMsg").rows(lngCount).className
        Set objRow = OBJ_DEBUG_WINDOW.document.all("debugMsg").insertRow()
        
        If strClass = "listeven" Then
            objRow.className = "listodd"
        Else
            objRow.className = "listeven"
        End If
        
        Set objCell = objRow.InsertCell
        objCell.valign = "top"
        objCell.innerHTML = "<b>" & CStr(lngCount) & "</b>"
        
        If Len(strDebugMessage) > 500 Then
            objRow.InsertCell.innerText = Left(strDebugMessage, 500) & " ..."
        Else
            objRow.InsertCell.innerText = strDebugMessage
        End If
        
        objRow.scrollIntoView
        OBJ_DEBUG_WINDOW.document.all("msg").value = CStr(lngCount)
        OBJ_DEBUG_WINDOW.document.all("msgM").click
        Set objRow = Nothing
        Set objCell = Nothing        
    End If
    On Error Goto 0
    
End Sub

Function GetGpassPatientKey()   'As String
'
' Description:  Retrieves the GPASS patient key, a hidden element 
'               populated by the GPASS Consulting Room Extension
' Parameters:   None
'
    GetGpassPatientKey = ""
    If Not document.all("GpassPatientKey") Is Nothing Then
        GetGpassPatientKey = document.all("GpassPatientKey").value
    End If

End Function

Function GetGpassPatientName()  'As String
'
' Description:  Retrieves the GPASS patient name, a hidden element 
'               populated by the GPASS Consulting Room Extension
' Parameters:   None
'
    GetGpassPatientName = ""
    If Not document.all("GpassPatientName") Is Nothing Then
        GetGpassPatientName = document.all("GpassPatientName").value
    End If

End Function

Function isGPASSUser()
'
' Description:  Checks to see if GPASS is running.
' Parameters:   None
' Returns:      True if running, False otherwise
'
    Dim objActiveApplication

    If Len(GetGpassPatientKey) > 0 Then
        isGpassUser = True
        Exit Function
    End If

    On Error Resume Next

    Err.clear
    
    'Get the user
    Set objActiveApplication = createObject("activeGPASS.gpassApplication")
    
    If err = 0 Then
        isGPASSUser = objActiveApplication.isGPASSUser()
    Else
        isGPASSUser = False
    End If
    
    Set objActiveApplication = Nothing
    
    On Error Goto 0

End Function

Function getType(name)
'
' Description:  Gets the type of an html DOM element
' Parameters:   name - the element to check
' Returns:      The type
'
    On Error Resume Next

    Dim strType

    If name <> "" Then
        err.number = 0

        'Get the type
        strType =  document.all(name).type

        If err.number = 0 Then
            getType = strType
        Else
            err.number = 0
            getType = ""
        End If
    End If
    On Error Goto 0

End Function

Sub HelpText(strHelpText, title)

    If trim(strHelpText) <> "" Then
        strHelpText = Replace(strHelpText,"#NEWLINE_",chr(10))
        call msgBox(strHelpText, "64", title)
    End If

End Sub

Function FormatDate(strDate)
'
' Description:  Formats a date to show the month as an abbreviated word
' Parameters:   strDate - the date to format
' Returns:      The formatted date
'
    Dim varDateSplit
    Dim varDay, varMonth, varYear
    Dim intDay, intMonth, intYear
    Dim strDateOut

    ' Return input if all else fails
    strDateOut = strDate

    If IsDate(strDate) Then
        ' Split on delimiter
        If InStr(1, strDate, "-") > 0 Then
            varDateSplit = Split(strDate, "-")
        ElseIf InStr(1, strDate, "/") > 0 Then
            varDateSplit = Split(strDate, "/")
        ElseIf InStr(1, strDate, "_") > 0 Then
            varDateSplit = Split(strDate, "_")
        End If

        ' Has split OK
        If IsArray(varDateSplit) Then
            ' date has 3 elements
            If LBound(varDateSplit) = 0 And UBound(varDateSplit) = 2 Then
                varDay = varDateSplit(0)
                varMonth = varDateSplit(1)
                varYear = varDateSplit(2)

                ' If the three elements are numeric
                If IsNumeric(varDay) And IsNumeric(varMonth) And IsNumeric(varYear) Then
                    intDay = CInt(varDay)
                    intMonth = CInt(varMonth)
                    intYear = CInt(varYear)

                    ' Format as "31 Jan 01" or "02 May 1998" depending on input
                    ' no guesses made about Y2K
                    strDateOut = _
                    intDay & " " & _
                    MonthName(intMonth, true) & " " & _
                    intYear
                End If
            End If
        End If
    End If

    FormatDate = strDateOut

End Function

Sub UnambiguousDateEntry(objField)
'
' Description:  Will convert a date (string) entry in an input field into an unambiguous string
'               (e.g. 2-3-05 becomes 02-Mar-2005)
' Parameters:   objField - the control containing the value to be formatted (e.g. a text box)
' Returns:      objField - The formatted date
'

    Dim dtDate
    
    If isDate(objField.value) Then
        dtDate = CDate(objField.value)
        objField.value = UnambiguousDate(dtDate)
    End If

End Sub

Function UnambiguousDate(dteDate)
'
' Description:  Formats a date to show abbreviated date part.
' Parameters:   dteDate - date to format
' Returns:      The unambiguous date
'

    Dim strDay      'As String
    Dim strMonth    'As String
    Dim strYear     'As String

    UnambiguousDate = ""

    On Error Resume Next

    If Not IsNull(dteDate) Then
        If IsDate(dteDate) Then
            If Day(dteDate) < 10 Then
                strDay = "0" & CStr(Day(dteDate))
            Else
                strDay = CStr(Day(dteDate))    
            End If    
            strMonth = MonthName(Month(dteDate), True)
            strYear = CStr(Year(dteDate))

            UnambiguousDate = strDay & "-" & strMonth & "-" & strYear
        End If
    End If

    On Error Goto 0

End Function

Sub DateOfBirthUnambiguousDateEntry(objField)
'
' Description:  Will convert a date (string) entry in an input field into an unambiguous string
'               (e.g. 2-3-05 becomes 02-Mar-2005)
'               Same as UnambiguousDateEntry but calls UpdateTitle as this is used when the date field is
'               for patient date of birth to display the patients details in the title bar
' Parameters:   objField - the control containing the value to be formatted (e.g. a text box)
'
    UnambiguousDateEntry(objField)
        
    setTimeout "UpdateTitle()", 0 
End Sub
