'============================================================================================
' File name:        gpassClinician.vbs
' Created:          17-Jun-2002
' Author:           D. Allen-Williams
' Description:      This provides methods for extracting supported Clinician properties used
'                   by protocol definitions.  In particular, it assumes a bolt on to the standard
'                   Clinician object exposed by the NewGpass API.
' Dependencies:     
' Issues:           
'============================================================================================

Option Explicit

Class Clinician

    'Decorated object
    Private m_objProtocolObj       'As ProtocolObject

    'Custom additional properties that we support
    Private m_strGmcCode           'As String
    
    '---------------------------------------------
    Private Sub Class_Initialize()
        Set m_objProtocolObj = New ProtocolObject
    End Sub
    
    '---------------------------------------------
    Private Sub Class_Terminate()
        Set m_objProtocolObj = Nothing
    End Sub
    
    '---------------------------------------------
    Public Sub Use(objBaseObject)
        Call m_objProtocolObj.Use(objBaseObject)
        Call Initialise()
    End Sub
    
    '---------------------------------------------
    Public Sub Initialise()
        'Initialise custom fields (GMC Code)
        m_strGMCCode = ""    'temporarily don't do anything exciting, but should pull using the GetGpIsdInfo service here
    End Sub

    '---------------------------------------------
    Public Function GetProperty(strProperty)    'As Variant

        Dim strValue          'As String
        
        strValue = ""
        Select Case strProperty
        
            'Check for one of our custom properties
            Case "GMCCode"               
                'try and grab GMC code (available from R5.1 API)    
                strValue = m_objProtocolObj.GetProperty(strProperty)
                If Len(strValue) = 0 Then
                    strValue = m_strGmcCode
                End If
            
            'Otherwise, assume it comes from the base object, 
            'overriding errors (hence provide the blank default)
            Case Else
                strValue = m_objProtocolObj.GetProperty(strProperty)
                        
        End Select
        GetProperty = strValue
        
    End Function
    
    '---------------------------------------------
    Public Sub LetProperty(strProperty, varValue)    

        Dim objClinician      'As NewGpass.Patient
        
        Select Case strProperty
        
            'Check for the only properties that currently might be set by the app
            Case "Key"                       
                Set objClinician = g_objGpassApp.GetObject(varValue)
                If Not objClinician Is Nothing Then      
                    Call Use(objClinician)       'initialise our ProtocolObject
                    Set objClinician = Nothing
                End If                
                
            Case "GMCCode"
                m_strGmcCode = CStr(varValue)
    
            'Otherwise, assume it's a property of the base object
            Case Else
                Call m_objProtocolObj.LetProperty(strProperty, varValue)

        End Select
        
    End Sub
    
End Class

