Option Explicit
'============================================================================================
' File name:    gpassProtocolObject.vbs
' Description:  This is the basic interface that Referral population functions in 
'               gpass.vbs presume for extracting information.
'               The class provides basic LetProperty and GetProperty functions to 
'               set and retrieve object properties using a string specifier, as opposed to
'               direct hard-coding of property names
'============================================================================================

'Recognised base object types
Const BASE_NONE         = 0
Const BASE_DICTIONARY   = 1
Const BASE_GPASS        = 2

'Name of Base Object property of protocol object, which exposes the base object
Const BASE_OBJECT       = "BaseObject"

Class ProtocolObject

    'Base NewGpass object we're decorating
    Private m_objBase           'As NewGpass.GpassObject  or Scripting.Dictionary
    Private m_intBaseType       'As Integer

    Private Sub Class_Initialize()
        Set m_objBase = Nothing
        m_intBaseType = BASE_NONE
    End Sub

    Private Sub Class_Terminate()
        Call Cleanup()
    End Sub

    Private Sub Cleanup()
        'Base object type specific cleanup
        Select Case m_intBaseType 
            Case BASE_DICTIONARY
                Call m_objBase.RemoveAll()
            Case Else
                'do nothing
        End Select

        Set m_objBase = Nothing
        m_intBaseType = BASE_NONE
    End Sub

    Public Sub Use(objBaseObject)
        Call Cleanup()
                    
        'Use the new base object
        Set m_objBase = objBaseObject
        If Not m_objBase Is Nothing Then
            Select Case LCase(TypeName(objBaseObject))
                Case "dictionary"
                    m_intBaseType = BASE_DICTIONARY
                Case Else   'Gpass object is the default for now
                    m_intBaseType = BASE_GPASS
            End Select
        End If
    End Sub

    Public Function GetProperty(strProperty)    'As Variant

        'Depending on the type of base object, use a different method to get the property
        Select Case m_intBaseType

            'Standard dictionary Key-Value pair
            Case BASE_DICTIONARY
                GetProperty = CStr(m_objBase.Item(strProperty))        

            'Gpass Open API object
            Case BASE_GPASS

                Select Case (strProperty)
                    'We need to cater for the case when we need the actual base object,
                    'eg to assign it to a property of another Gpass object.  doro Test Track 10681 17.10.02
                    Case BASE_OBJECT
                        Set GetProperty = m_objBase
                    Case Else
                        If VarType(GetGpassProperty(strProperty)) = vbObject Then
                            Set GetProperty = GetGpassProperty(strProperty)
                        Else
                            GetProperty = CStr(GetGpassProperty(strProperty))
                        End If
                End Select

            'Unsupported object type
            Case Else
                GetProperty = ""    'return values as strings by default
        End Select

    End Function

    Private Function GetGpassProperty(strProperty)      'As Variant

        Dim strValue        'As String

        'Return values as strings by default
        strValue = ""

        On Error Resume Next

        'Format & return properties differently, depending on their type
        Select Case Eval("VarType(m_objBase." & strProperty & ")")
            Case vbEmpty, vbNull
                strValue = ""
                
            Case vbDate
                strValue = UnambiguousDate(Eval("m_objBase." & strProperty))
                If CDate(strValue) = CDate(0) Then
                    strValue = ""
                End If

            'For objects, we obviously can't return a string                            
            Case vbObject   
                Execute("Set GetGpassProperty = m_objBase." & strProperty)
                On Error Goto 0
                Exit Function

            'Assume an implicit conversion to string will be appropriate
            Case Else
                strValue = CStr(Eval("m_objBase." & strProperty))
        End Select

        On Error Goto 0
        GetGpassProperty = strValue

    End Function

    Public Sub LetProperty(strProperty, varValue)    

        Select Case m_intBaseType
            Case BASE_DICTIONARY
                m_objBase.Item(strProperty) = varValue
            Case BASE_GPASS
                Call LetGpassProperty(strProperty, varValue)
            Case Else   'BASE_NONE, etc
                'do nothing
        End Select

    End Sub

    Private Sub LetGpassProperty(strProperty, varValue)    

        Dim arrLines
        Dim i, j
        Dim strLine
        Dim strMultiLine

        Select Case Eval("VarType(m_objBase." & strProperty & ")")
            Case vbByte, vbInteger, vbLong, vbSingle, vbDouble, vbDecimal, vbCurrency
                If Len(CStr(varValue)) > 0 Then
                    Call Execute("m_objBase." & strProperty & "=" & CStr(varValue))
                End If
            Case vbObject                        
                Call Execute("Set m_objBase." & strProperty & "= varValue")         
            Case vbBoolean
                If Len(CStr(varValue)) > 0 Then
                    Call Execute("m_objBase." & strProperty & "=" & CStr(CBool(varValue)))
                End If
            Case vbDate
                If Len(CStr(varValue)) > 0 Then
                    'Need to make sure here we get both date and time and FormatDateTime does
                    'not seem to be able to do this
                    Call Execute("m_objBase." & strProperty & "= """ & CStr(varValue) & """")
                End If

            'Otherwise, assume we can treat it like a string
            Case Else   'vbString, etc.
                If Len(CStr(varValue)) > 0 Then
                    If Instr(CStr(varValue), Chr(13) & Chr(10)) > 0 Then

                        arrLines = Split(varValue, Chr(13) & Chr(10))
                        strMultiLine = ""
                        
                        For i=0 to Ubound(arrLines)
                            strLine = arrLines(i)
                            strLine = CStr(strLine)	'for safety

                            If i > 0 Then
                                strMultiLine = strMultiLine & " & Chr(13) & Chr(10) & "
                            End If
                            strMultiLine = strMultiLine & """" & strLine & """"
                        Next

                        Call Execute("m_objBase." & strProperty & "=" & CStr(strMultiLine))
                    Else
                        Call Execute("m_objBase." & strProperty & "=""" & CStr(varValue) & """")
                    End If
                    
                    If Err.Number <> 0 Then
                       MsgBox Err.Description
                    End If
                End If
        End Select
    End Sub

    Public Sub DoMethod(strMethodName)
        Select Case m_intBaseType
            Case BASE_GPASS
                If Len(CStr(strMethodName)) > 0 Then
                    Call Execute("m_objBase." & strMethodName)
                End If
            Case Else   'BASE_NONE, etc
                'do nothing
        End Select
    End Sub

End Class