using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Collections.Generic;

using SCI.Gateway.Web.Controls;
using SCI.Gateway.Utility;
using SCI.Gateway.InterfaceTypes;
using SCI.Gateway.Core.Services;
using SCI.Gateway.Core.BusinessLogic;
using SCI.Gateway.Core.BusinessLogic.Entity;
using SCI.Gateway.Web.Utility;
using SCI.Gateway.Web.WorklistPage;

namespace SCI.Gateway.Web
{
    public class ChangeStatus : GatewayPage
    {
        #region private members

        private static readonly string ClientScriptUris =
            CreateJavaScriptObject.FromPublicStaticMembers(
                typeof(GatewayLocations),
                new string[]
                        {
                            "ChangeStatusUri",
                            "LetterUri",
                            "MessageReplyUri",
                            "ViewMessageUri",
                            "WorklistUri",
                            "GatewayFormName"
                        });

        #endregion

        #region internal members

        internal static readonly string ChangeStatusFlagKeysAsJavaScript = CreateJavaScriptObject.FromPublicStaticMembers(typeof(ChangeStatus.ChangeStatusFlagKeys));

        #endregion

        #region support classes

        private static class ChangeStatusFlagKeys
        {
            public const string MessageIdInput = "MessageIdInput";
            public const string MessageTypeInput = "MessageTypeInput";
            public const string SelectReceiveTabInput = "SelectReceiveTabInput";
            public const string SubmittedInput = "submitted";
            public const string SenderInput = "SenderInput";
            public const string RecipientInput = "RecipientInput";
            public const string InitialValueOfDropDown = "InitialValueOfDropDown";
            public const string InitialValueOfCheckBox = "InitialValueOfCheckBox";

        }

        #endregion

        #region Properties

        public override string PageTitle
        {
            get
            {
                return "Change Status";
            }
        }

        #endregion

        #region GUI

        protected DropDownList statusDropDownList;
        protected CheckBox filedCheckBox;
        protected HtmlInputHidden SenderInput;
        protected HtmlInputHidden RecipientInput;
        protected HtmlInputHidden MessageIdInput;
        protected HtmlInputHidden InitialValueOfDropDown;
        protected HtmlInputHidden InitialValueOfCheckBox;
        
        #endregion

        #region Methods

        protected override void Page_Load(object sender, EventArgs e)
        {
            base.Page_Load(sender, e);
            base.SetJavaScriptFiles("changeStatus.js;WorklistControls.js");
            base.SetVBScriptFiles("scripts","xml.vbs","ChangeStatusScripts");
            ClientScript.RegisterClientScriptBlock(this.GetType(), "GatewayLocations", ClientScriptUris, true);
            ClientScript.RegisterClientScriptBlock(this.GetType(), "ChangeStatusFlagKeys", ChangeStatusFlagKeysAsJavaScript, true);
 
            SetPageDisplay();
        }

        private void SetPageDisplay()
        {
            //Get values posted from Worklist.
            int messageId = Convert.ToInt32(Request.Form[ChangeStatusFlagKeys.MessageIdInput]);
            int messageTypeId = Convert.ToInt32(Request.Form[ChangeStatusFlagKeys.MessageTypeInput]);
            bool isRecipient = Convert.ToBoolean(Request.Form[ChangeStatusFlagKeys.SelectReceiveTabInput]);
            bool isSender = !isRecipient;
            bool isSubmitted = Convert.ToBoolean(Request.Form[ChangeStatusFlagKeys.SubmittedInput]);

            //Store values for use by the client side
            SenderInput.Value = isSender.ToString();
            RecipientInput.Value = isRecipient.ToString();
            MessageIdInput.Value = messageId.ToString();

            DirectoryEntity CurrentEntity = CurrentUser.UserEntity;
            MessageType CurrentMessageType = MessageType.FindById(messageTypeId);
            MessageItem selectedMessage = MessageItem.FindById(messageId);
            string defaultStatus = selectedMessage.Status.Name;

            bool canChangeStatus = (!isSubmitted && isSender) || (isSubmitted && isRecipient);

            if (!canChangeStatus)
            {
                statusDropDownList.Enabled = false;
                ListItem defaultOption = new ListItem();
                defaultOption.Text = defaultStatus;
                defaultOption.Value = selectedMessage.Status.Key.ToString();
                statusDropDownList.Items.Add(defaultOption);
            }
            else
            {

                IList<HealthBoardAreaMessageStatus> statusList = HealthBoardAreaMessageStatus.FindHealthBoardAreaStatusList(CurrentMessageType, CurrentEntity.HealthBoard);

                if (statusList.Count != 0)
                {
                    foreach (HealthBoardAreaMessageStatus healthBoardStatus in statusList)
                    {
                        ListItem option = new ListItem();
                        option.Text = healthBoardStatus.MessageStatus.Name;
                        option.Value = healthBoardStatus.MessageStatus.Key.ToString();

                        if (isSender)
                        {
                            if (!healthBoardStatus.MessageStatus.AfterSubmit)
                            {
                                statusDropDownList.Items.Add(option);
                            }
                        }
                        else
                        {
                            if (healthBoardStatus.MessageStatus.AfterSubmit)
                            {
                                statusDropDownList.Items.Add(option);
                            }
                        }
                    }
                }
                else
                {
                    ListItem option = new ListItem();
                    option.Text = selectedMessage.Status.Name;
                    option.Value = selectedMessage.Status.Key.ToString();
                    statusDropDownList.Items.Add(option);
                }
               

                if (statusDropDownList.Items.FindByText(defaultStatus) == null)
                {
                    ListItem option = new ListItem();
                    option.Text = selectedMessage.Status.Name;
                    option.Value = selectedMessage.Status.Key.ToString();
                    option.Selected = true;
                    statusDropDownList.Items.Add(option);
                }
                else
                {
                    statusDropDownList.Items.FindByText(defaultStatus).Selected = true;
                }
            }

            InitialValueOfDropDown.Value = statusDropDownList.SelectedItem.Value.ToString();
            bool filed = (isSender && selectedMessage.FiledSender) || (isRecipient && selectedMessage.FiledRecipient);

            if (filed)
            {
                filedCheckBox.Checked = true;
            }
            InitialValueOfCheckBox.Value = filedCheckBox.Checked.ToString();
        }

        #endregion


        protected override void OnInit(EventArgs e)
        {
            InitializeComponent();
            base.OnInit(e);
        }

        private void InitializeComponent()
        {
            this.Load += new EventHandler(this.Page_Load);
        }
    }
}
