using System.Web.UI.HtmlControls;

using System.Globalization;
using SCI.Gateway.Core.BusinessLogic;
using SCI.Gateway.Core.BusinessLogic.Entity;
using SCI.Gateway.Core.BusinessLogic.Protocols;
using SCI.Gateway.InterfaceTypes;
using SCI.Gateway.Web;
using SCI.Gateway.Web.Utility;
using SCI.Gateway.Utility;


using System;
using System.Collections.Generic;
using System.Xml;
using System.Web;


namespace SCI.Gateway.Web.Message
{
    public partial class MessageReply : GatewayPage
    {
        #region form elements

        protected HtmlGenericControl body;

        #endregion

        #region private variables

        private string m_message;
        private MessageItem m_requestMessageItem;
        private MessageItem m_responseMessageItem; 
        private int m_originalRequestId;
        private int m_replyMessageTypeId;
        private bool m_responseConstructed;
        private int m_protocolVersionId;
        private string m_protocolName;
        private string m_dataEntryXml;
        private readonly Dictionary<string, string> m_hiddenValues = new Dictionary<string, string>();
        private bool m_messageParked;
        private static readonly string ClientScriptUris =
            CreateJavaScriptObject.FromPublicStaticMembers(
                typeof(GatewayLocations),
                new string[]
                        {
                            "LetterUri",
                            "MessageReplyUri",
                            "ViewMessageUri",
                            "WorklistUri",
                            "GatewayFormName"
                        });

        #endregion

        #region Public Properties

        /// <summary>
        /// Override for page title.
        /// </summary>
        public override string PageTitle
        {
            get { return "Message Reply"; }
        }

        #endregion

        protected new void Page_Load(object sender, EventArgs e)
        {
            base.Page_Load(sender, e);
            base.SetJavaScriptFiles("MessageReply.js;WorklistControls.js");
            ClientScript.RegisterClientScriptBlock(this.GetType(), "GatewayLocations", ClientScriptUris, true);
            ClientScript.RegisterClientScriptBlock(this.GetType(), "WorklistFlagKeys", WorklistPage.Constants.WorklistConstantsAsJavaScript.WorklistFlagKeys, true);
            body.Attributes.Add("onload", "OnLoad();");
            m_message = string.Empty;

            if (Int32.TryParse(Request.Params["originalRequestId"], out m_originalRequestId))
            {
                m_requestMessageItem = MessageItem.FindById(m_originalRequestId);
                m_responseConstructed = CreateResponseFromRequest();
                m_messageParked = ParkMessage();

                if (m_responseMessageItem.MessageType.Key == GatewayConstants.egpfrResponseMessageId)
                {
                    m_requestMessageItem.SetStatus(MessageStatus.StatusDeleted);
                }
               
                int responseMessageTypeId = m_responseMessageItem.MessageType.Key;
                if (m_responseConstructed && m_messageParked)
                {
                    AddMessage("<B>Created reply message OK</B>");
                    SetupLoadFunction();

                    if (responseMessageTypeId != GatewayConstants.egpfrResponseMessageId)
                    {
                        //Set the reply created flag and change status to reply created
                        m_requestMessageItem.IsReplyCreated = true;
                    }
                }
            }

            Response.Write(m_message);
        }

        #region private methods

        private void SetupLoadFunction()
        {
            String scriptString = "<script language=javascript>\r\n";
            scriptString += "function OnLoad()\r\n";
            scriptString += "{\r\n";
            scriptString += "    OnLoadMessageReply(" + m_replyMessageTypeId + ", ";
            scriptString += "\"" + m_responseMessageItem.MessageType.Name + "\", ";
            scriptString += m_responseMessageItem.Key + ", ";
            scriptString += m_responseMessageItem.DestinationEntity.Key + ");\r\n";
            scriptString += "}</script>";

            if (!ClientScript.IsClientScriptBlockRegistered("clientScript"))
                ClientScript.RegisterClientScriptBlock(typeof(MessageReply), "clientScript", scriptString);
        }

        private bool ParkMessage()
        {
            bool messageParked;

            if (m_responseConstructed)
            {
                messageParked = m_responseMessageItem.Park();
            }
            else
            {
                messageParked = false;
            }

            return messageParked;
        }

        private bool CreateResponseFromRequest()
        {
            bool responseCreated = true;
            int requesterPracticeHceID; 
            Int32.TryParse(Request.Params["requesterID"], out requesterPracticeHceID);

            if (!Int32.TryParse(Request.Params["replyMessageTypeId"], out m_replyMessageTypeId))
            {
                AddMessage("<B>Can't process message as don't have reply message type details.</B>");
                responseCreated = false;
            }
            else
            {
                if(!GetLatestProtocol(MessageType.FindById(m_replyMessageTypeId)))
                {
                    AddMessage("<B>Couldn't get the reply protocol detail</B>");
                    responseCreated = false;
                }

                if (responseCreated)
                {
                    ProtocolVersion replyProtocolVersion = (m_protocolVersionId == 0) ? null : ProtocolVersion.FindById(m_protocolVersionId);
                    m_responseMessageItem = new MessageItem(m_sessionContext);
                    m_responseMessageItem.SetDefaultResponseValues(
                                                            m_replyMessageTypeId,
                                                            m_requestMessageItem.SenderEntity,
                                                            replyProtocolVersion,
                                                            requesterPracticeHceID,
                                                            Server.MapPath(GatewayLocations.FolderMessageTypes));
                    m_responseMessageItem.SetPatientDetailsFromRequestMessageItem(m_requestMessageItem);

                    string modifiedRequestMessageXml = AppendRequestMessageIdToMessageXml(
                                                                                m_requestMessageItem.Key,
                                                                                m_requestMessageItem.MessageXml,
                                                                                m_responseMessageItem);
                    if (TransformMessageXmlToDataEntryXml(modifiedRequestMessageXml))
                    {
                        m_responseMessageItem.DataEntryXml = m_dataEntryXml;
                        m_responseMessageItem.ClearMessageXml();
                    
                        AddHiddenFieldsToDataEntryXml(m_responseMessageItem.DataEntryXml, m_replyMessageTypeId,
                                                          m_responseMessageItem.DestinationEntity.Key,
                                                          m_protocolVersionId, m_protocolName);
                    }
                    else
                    {
                        responseCreated = false;
                    }
                }
            }

            return responseCreated;
        }

        private void AddHiddenFieldsToDataEntryXml(string dataEntryXml, int messageTypeId, int providerHceId, int protocolVersionId, string protocolName)
        {
            string thirdPartyPatientKey = "";
            string thirdPartyProgId = "";
            string thirdPartyAppName = "";

            // get the hidden fields, specified in message-parkinfo.xml
            XmlDocument messageParkInfo = new XmlDocument();
            messageParkInfo.Load(Server.MapPath("message-parkinfo.xml"));

            string xpath = "//hiddenfields/hiddenfield";

            XmlNodeList hiddenNodes = messageParkInfo.SelectNodes(xpath);


            // Add all the required hidden value nodes into a dictionary object
            foreach (XmlNode node in hiddenNodes)
            {
                string id = node.Attributes["output"].Value;
                SetDictionaryValue(id, "");
            }

            SetDictionaryValue("providerid", providerHceId.ToString());
            SetDictionaryValue("protocolid", protocolVersionId.ToString());
            SetDictionaryValue("protocolname", protocolName);
            SetDictionaryValue("msgtypeid", messageTypeId.ToString());
            SetDictionaryValue("allowappts", "false");
            SetDictionaryValue("docdata_create_date", DateTime.Now.ToString("yyyy-MM-dd"));
            SetDictionaryValue("docdata_create_time", DateTime.Now.ToString("HH:mm:ss"));


            if (SessionState.isThirdParty)
            {
                thirdPartyPatientKey = SessionState.thirdPartyPatientKey;
                thirdPartyProgId = SessionState.thirdPartyProgId;
                thirdPartyAppName = SessionState.thirdpartyApplicationName;
            }

            SetDictionaryValue("isThirdParty", SessionState.isThirdParty.ToString());
            SetDictionaryValue("ThirdPartyProgId", thirdPartyProgId);
            SetDictionaryValue("ThirdPartyAppName", thirdPartyAppName);
            SetDictionaryValue("patientkey", thirdPartyPatientKey);


            //Create a new xml Node in <ptrobjcts> to contain hidden fields
            XmlDocument newDataEntryXml = new XmlDocument();
            newDataEntryXml.LoadXml(dataEntryXml);

            XmlElement hiddenFields = newDataEntryXml.CreateElement("hdnflds");


            foreach (KeyValuePair<string, string> dictionaryEntry in m_hiddenValues)
            {
                XmlElement hiddenField = newDataEntryXml.CreateElement("hdnfld");
                hiddenField.SetAttribute("id", dictionaryEntry.Key);
                hiddenField.SetAttribute("value", dictionaryEntry.Value);

                hiddenFields.AppendChild(hiddenField);
            }


            //Add the <hdnflds> node  to the <prtobjts> node
            newDataEntryXml.DocumentElement.AppendChild(hiddenFields);

            m_responseMessageItem.DataEntryXml = newDataEntryXml.OuterXml;
        }

        private void SetDictionaryValue(string key, string value)
        {
            if (m_hiddenValues.ContainsKey(key))
            {
                m_hiddenValues[key] = value;
            }
            else
            {
                m_hiddenValues.Add(key, value);
            }
        }

        private bool TransformMessageXmlToDataEntryXml(string messageXml)
        {
            PatientPrePopulationParameters patientPrePopulationParameters = new PatientPrePopulationParameters();
            patientPrePopulationParameters.PatientPrePopulationMode = PatientPrePopulationMode.ReplyFromRequest;
            patientPrePopulationParameters.OriginalMessageType = m_requestMessageItem.MessageType;
            patientPrePopulationParameters.PrePopulationSourceXml = messageXml;
            patientPrePopulationParameters.NewMessageType = m_responseMessageItem.MessageType;
            patientPrePopulationParameters.NewMessageProtocolXml = m_responseMessageItem.ProtocolVersion.Xml;
            patientPrePopulationParameters.NewMessageSchema = m_responseMessageItem.SchemaVersion;

            Patient patient = new Patient(m_sessionContext);
            m_dataEntryXml = patient.CreatePrePopulatedDataEntryXml(patientPrePopulationParameters);

            return !string.IsNullOrEmpty(m_dataEntryXml);
        }

        private bool GetLatestProtocol(MessageType replyMessageType)
        {
            bool retrievedProtocol = false;

            // get the details of the sending entity
            DirectoryEntity sendingEntity = DirectoryEntity.FindById(Convert.ToInt32(m_sessionContext.UserEntityID, CultureInfo.CurrentCulture));
            
            // get the list of active protocols associated with the entity 
            // returned by nearest HCE first then most recent version (by date entered)
            ProtocolVersion replyProtocol = sendingEntity.FindReplyProtocol(replyMessageType);

            if (replyProtocol != null)
            {
                m_protocolName = replyProtocol.Protocol.Name;
                m_protocolVersionId = replyProtocol.Key;
                retrievedProtocol = true;
            }
            else
            {
                retrievedProtocol = false;
            }
            
            return retrievedProtocol;
        }

        private void AddMessage(string message)
        {
	        if (m_message.Length > 0 )
            {
		        m_message = m_message + "<br/>";
            }
            m_message = m_message + message;
        }

        private string AppendRequestMessageIdToMessageXml(int requestMessageItemId, string requestMessageXml, MessageItem responseMessageItem)
        {
            XmlDocument workingMessageXml = new XmlDocument();
            workingMessageXml.LoadXml(requestMessageXml);

            string strXpath = null;
            XmlDocument prePopDoc = new XmlDocument();
            prePopDoc.Load(Server.MapPath(
                                    string.Format("{0}{1}\\Schema-{2}\\PrepopulationFromRequest.xml",
                                        GatewayLocations.FolderMessageTypes,
                                        responseMessageItem.MessageType.Name,
                                        responseMessageItem.SchemaVersion.Version)));
            XmlNode xpathNode = prePopDoc.SelectSingleNode("//question[@property='OriginalRequestId']/xpath");
            if (xpathNode != null)
            {
                strXpath = xpathNode.InnerText;
            }

            if (!string.IsNullOrEmpty(strXpath))
            {
                XmlNamespaceManager nsManager = XmlUtility.CreateNamespaceManagerFromDocumentNamespaces(workingMessageXml);
                XmlNode messageIdNode = workingMessageXml.SelectSingleNode(strXpath, nsManager);
                messageIdNode.InnerXml = requestMessageItemId.ToString();
            }

            return workingMessageXml.InnerXml;
        }

        #endregion

        #region form events

        override protected void OnInit(EventArgs e)
        {
            InitializeComponent();
            base.OnInit(e);
        }

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.Load += new System.EventHandler(this.Page_Load);

        }

        #endregion
    }
}
