<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:adRes="http://www.show.scot.nhs.uk/isd/AdviceResponse" xmlns:gen="http://www.show.scot.nhs.uk/isd/General" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:user="http://www.sci.scot.nhs.uk" exclude-result-prefixes="user msxsl">
	<xsl:output method="html"/>
	<msxsl:script language="javascript" implements-prefix="user"><![CDATA[
			
			function FormatLineBreaks(strValue)
			{
				var strText = escape(strValue);
				strText = ReplaceAll(strText, "%0D%0A", "<br/>");
				
				return unescape(strText);
			}
			
			function ReplaceAll(strValue, strSearchValue, strReplacementValue)
			{
				var strText = strValue;
				while (strText.indexOf(strSearchValue) > -1)
				{
					strText = strText.replace(strSearchValue, strReplacementValue);
				}
				return strText;
			}
			
		]]></msxsl:script>
	<xsl:variable name="default_blank" select="'-'"/>
	<xsl:template match="adRes:AdviceResponseDocument">
		<style>
			body {
				font-family: Tahoma, Arial, Helvetica, sans-serif;
				font-size: 11px;
				margin-top : 15px;
				margin-left : 15px;
				background-color: white;
			}
			
			p {
				margin-bottom : 2px;
				margin-top : 2px;
			}
			
			h1 {
				font-size: 16 px;
				font-weight: bold;
				color : black;
				margin-bottom : 4px;
				margin-top : 4px;
				font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
			}
			
			h2 {
				font-size: 14 px;
				margin-bottom : 3px;
				margin-top : 3px;
				font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
				font-weight: normal;
			}
			
			h3 {
				font-size: 10px ;
				font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
				margin-bottom : 2px;
				margin-top : 2px;
				font-weight : bold;
			}
			
			h4 {
				font-size: 11 px ;
				font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
				margin-bottom : 2px;
				margin-top : 8px;
				text-indent : 32px;
				font-weight : normal;
				text-decoration : underline;
			}
			
			h5 {
				font-size: 11 px ;
				font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
				margin-bottom : 2px;
				margin-top : 8px;
				text-indent : 48px;
				font-weight : normal;
			}
			
			h6 {
				font-size: 10 px ;
				font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
				margin-bottom : 2px;
				margin-top : 8px;
				text-indent : 60px;
				font-weight : bold;
			}
			
			break {
				page-break-before : always;
			}
			
			a {
				text-decoration: underline;
				color: Navy;
			}
			
			a:hover {
				text-decoration: none;
				color : Red;
			}
			
			table {
				font-size: 11 px ;
			}
			
			.hashed {
				background-color: lightgrey;
				font-weight:bold;
			}
			
			.essential {
				font-weight:bold;
				color:red;
			}
			
			.urgency {
				font-size:20 px;
				color:navy;
			}
			
			.sensitivity{
				font-size:20 px;
				color:navy;
			}
			
			.barcode
			{
				font-family: SCIBC;
				font-size:20 px;
			}
			
			.barcodeText
			{
				font-family: Tahoma, Arial, Helvetica, sans-serif;
				font-size: 9px;
			}
		</style>
		<xsl:apply-templates select="adRes:MessageData"/>
	</xsl:template>
	<xsl:template match="adRes:MessageData">
		<xsl:if test="../adRes:DocumentData/gen:UniqueCarePathwayNumber">
			<center>
				<div class="barcode">
					*<xsl:value-of select="../adRes:DocumentData/gen:UniqueCarePathwayNumber"/>*
				</div>
				<div class="barcodeText">
					Unique Care Pathway Number: <xsl:value-of select="../adRes:DocumentData/gen:UniqueCarePathwayNumber"/>
				</div>
			</center>
		</xsl:if>
		<table width="100%">
			<tbody>
				<tr>
					<td>
						<h1>Advice Response</h1>
					</td>
					<td align="right">
						<xsl:call-template name="formatDate">
							<xsl:with-param name="d">
								<xsl:value-of select="../adRes:DocumentData/gen:DocumentAttestationDate"/>
							</xsl:with-param>
						</xsl:call-template>
						<xsl:text> </xsl:text>
						<xsl:value-of select="../adRes:DocumentData/gen:DocumentAttestationTime"/>
					</td>
				</tr>
			</tbody>
		</table>
		<table width="100%" border="1">
			<thead>
				<tr>
					<th>ADVICE REQUESTED FROM</th>
					<th>ADVICE REQUESTED BY</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td>
						<xsl:apply-templates select="adRes:AdviceSentBy"/>
					</td>
					<td>
						<xsl:apply-templates select="adRes:AdviceRequestedBy"/>
					</td>
				</tr>
			</tbody>
		</table>
		<div>
			<xsl:apply-templates select="adRes:AdviceRequestedDetails/adRes:AdviceRequested"/>
		</div>
		<div>
			<xsl:apply-templates select="adRes:AdviceGivenDetails/adRes:AdviceGiven"/>
		</div>
		<div>
			<xsl:apply-templates select="adRes:PatientDemographics"/>
		</div>
		<div>
			<p>Current and recent medication:-</p>
			<table width="100%" border="0">
				<thead>
					<tr>
						<th align="left">Drug Name</th>
						<th align="left">BNF</th>
						<th align="left">Formulation</th>
						<th align="left">Dosage</th>
						<th align="left">Frequency</th>
						<th align="left">Started</th>
						<th align="left">Last Issued</th>
					</tr>
				</thead>
				<tbody>
					<xsl:apply-templates select="adRes:CurrentMedication/adRes:CurrentMedicationInstance"/>
					<xsl:apply-templates select="adRes:RecentMedication/adRes:RecentMedicationInstance"/>
				</tbody>
			</table>
		</div>
		<div>
			<table width="100%" border="1">
				<colgroup>
					<col width="10%"/>
					<col/>
				</colgroup>
				<tbody>
					<tr>
						<th>Consent to share</th>
						<td>
							<xsl:call-template name="formatYorN">
								<xsl:with-param name="value" select="/adRes:AdviceResponseDocument/adRes:DocumentData/gen:ConsentToShare"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<th>Sensitivity</th>
						<td>
							<xsl:call-template name="formatSensitivity">
								<xsl:with-param name="value" select="/adRes:AdviceResponseDocument/adRes:DocumentData/gen:Sensitivity"/>
							</xsl:call-template>
						</td>
					</tr>
				</tbody>
			</table>
		</div>
	</xsl:template>
	<xsl:template match="adRes:AdviceSentBy">
		<xsl:param name="forename" select="gen:HcpName/gen:StructuredName/gen:GivenName"/>
		<xsl:param name="surname" select="gen:HcpName/gen:StructuredName/gen:FamilyName"/>
		<xsl:param name="formattedname">
			<xsl:value-of select="$forename"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="$surname"/>
		</xsl:param>
		<table border="0">
			<xsl:value-of select="$formattedname"/>
			<br/>
			<xsl:value-of select="gen:HcpSpecialty/gen:SpecialtyName"/>
			<br/>
			<xsl:value-of select="gen:EmployingOrganisation/gen:OrganisationName"/>
			<br/>
			<xsl:for-each select="gen:EmployingOrganisation/gen:OrganisationAddress/gen:StructuredAddress/gen:AddressLine">
				<xsl:value-of select="."/>
				<br/>
			</xsl:for-each>
		</table>
	</xsl:template>
	<xsl:template match="adRes:AdviceRequestedBy">
		<table border="0">
			<xsl:choose>
				<xsl:when test="gen:HcpName/gen:StructuredName/gen:GivenName">
					<xsl:value-of select="gen:HcpName/gen:StructuredName/gen:GivenName"/>
					<xsl:value-of select="gen:HcpName/gen:StructuredName/gen:FamilyName"/>
				</xsl:when>
				<xsl:when test="gen:HcpName/gen:UnstructuredName">
					<xsl:value-of select="gen:HcpName/gen:UnstructuredName"/>
				</xsl:when>
			</xsl:choose>
			<br/>
			<xsl:value-of select="gen:EmployingOrganisation/gen:OrganisationName"/>
			<br/>
			<xsl:if test="normalize-space(gen:EmployingOrganisation/gen:OrganisationAddress/gen:StructuredAddress/gen:AddressLine[not('')])">
				<xsl:for-each select="gen:EmployingOrganisation/gen:OrganisationAddress/gen:StructuredAddress/gen:AddressLine">
					<xsl:value-of select="."/>
					<br/>
				</xsl:for-each>
			</xsl:if>
			<br/>
			<xsl:value-of select="gen:EmployingOrganisation/gen:OrganisationTelecom/gen:UnstructuredTelecom[../gen:TelecomType='Voice']"/>
		</table>
	</xsl:template>
	<xsl:template match="adRes:AdviceRequestedDetails/adRes:AdviceRequested">
		<table border="1" width="100%">
			<tbody style="border-width:0;border-style:none;">
				<tr>
					<th>ADVICE REQUIRED:-</th>
				</tr>
				<tr>
					<td>
						<xsl:value-of select="."/>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>
	<xsl:template match="adRes:AdviceGivenDetails/adRes:AdviceGiven">
		<table border="1" width="100%">
			<tbody style="border-width:0;border-style:none;">
				<tr>
					<th>ADVICE GIVEN:-</th>
				</tr>
				<tr>
					<td>
						<xsl:value-of select="."/>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>
	<xsl:template match="adRes:PatientDemographics">
		<table width="100%" border="0">
			<tr>
				<th>PATIENT DETAILS:-</th>
			</tr>
			<tr>
				<th>
					<table>
						<tbody>
							<tr>
								<th>Forename</th>
								<td>
									<xsl:if test="normalize-space(gen:PatientName/gen:StructuredName[../gen:NameType='Current Name']/gen:GivenName[not('')]) ">
										<xsl:call-template name="format_text">
											<xsl:with-param name="text">
												<xsl:value-of select="gen:PatientName/gen:StructuredName[../gen:NameType='Current Name']/gen:GivenName"/>
											</xsl:with-param>
										</xsl:call-template>
									</xsl:if>
								</td>
							</tr>
							<tr>
								<th>Surname</th>
								<td>
									<xsl:call-template name="format_text">
										<xsl:with-param name="text">
											<xsl:value-of select="gen:PatientName/gen:StructuredName[../gen:NameType='Current Name']/gen:FamilyName"/>
										</xsl:with-param>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<th>Middlename(s)</th>
								<td>
									<xsl:call-template name="format_text">
										<xsl:with-param name="text">
											<xsl:for-each select="gen:PatientName/gen:UnstructuredName[../gen:NameType='Middle Name']">
												<xsl:text/>
												<xsl:value-of select="."/>
											</xsl:for-each>
										</xsl:with-param>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<th>Previous Surname</th>
								<td>
									<xsl:call-template name="format_text">
										<xsl:with-param name="text">
											<xsl:value-of select="gen:PatientName/gen:UnstructuredName[../gen:NameType='Previous Surname']"/>
										</xsl:with-param>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<th>Sex</th>
								<td>
									<xsl:value-of select="gen:Sex"/>
								</td>
							</tr>
							<tr>
								<th>Date of Birth</th>
								<td>
									<xsl:call-template name="formatDate">
										<xsl:with-param name="d" select="gen:DateOfBirth"/>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<xsl:if test="normalize-space(gen:PatientId[gen:IdScheme='NHS Number']/gen:IdValue[not('')])">
									<th>NHS #</th>
									<td>
										<xsl:value-of select="gen:PatientId[gen:IdScheme='NHS Number']/gen:IdValue"/>
									</td>
								</xsl:if>
							</tr>
						</tbody>
					</table>
				</th>
				<td>
					<table>
						<tbody>
							<tr>
								<xsl:choose>
									<xsl:when test="gen:PatientAddress/gen:UnstructuredAddress">
										<p>
											<xsl:call-template name="format_text">
												<xsl:with-param name="text">
													<xsl:value-of select="gen:UnstructuredAddress"/>
												</xsl:with-param>
											</xsl:call-template>
										</p>
									</xsl:when>
									<xsl:otherwise>
										<p>
											<xsl:value-of select="gen:PatientAddress/gen:StructuredAddress/gen:PropertyNumber"/>
										</p>
										<xsl:for-each select="gen:PatientAddress/gen:StructuredAddress/gen:AddressLine">
											<p>
												<xsl:value-of select="."/>
											</p>
										</xsl:for-each>
									</xsl:otherwise>
								</xsl:choose>
							</tr>
						</tbody>
					</table>
				</td>
			</tr>
		</table>
	</xsl:template>
	<xsl:template match="adRes:CurrentMedicationInstance | adRes:RecentMedicationInstance">
		<tr>
			<td align="left">
				<xsl:value-of select="gen:DrugName/gen:DrugCode/gen:DrugIdentifier"/>
			</td>
			<td align="left">
				<xsl:value-of select="gen:DrugName/gen:DrugCode/gen:DrugCodeValue"/>
			</td>
			<td align="left">
				<xsl:value-of select="gen:DrugName/gen:DrugCode/gen:Formulation"/>
			</td>
			<td align="left">
				<xsl:value-of select="gen:StructuredDosage/gen:DoseDescription"/>
			</td>
			<td align="left">
				<xsl:value-of select="gen:StructuredDosage/gen:Frequency"/>
			</td>
			<td align="left">
				<xsl:call-template name="formatDate">
					<xsl:with-param name="d" select="gen:StructuredDosage/gen:MedicationStartDate"/>
				</xsl:call-template>
			</td>
			<td align="left">
				<xsl:call-template name="formatDate">
					<xsl:with-param name="d" select="gen:StructuredDosage/gen:LastPrescribedDate"/>
				</xsl:call-template>
			</td>
		</tr>
	</xsl:template>
	<xsl:template name="format_text">
		<xsl:param name="text"/>
		<xsl:param name="date"/>
		<xsl:param name="datetime"/>
		<xsl:param name="default" select="$default_blank"/>
		<xsl:choose>
			<xsl:when test="normalize-space($text)">
				<xsl:value-of disable-output-escaping="yes" select="user:FormatLineBreaks(string($text))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$default"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="formatDate">
		<xsl:param name="d"/>
		<xsl:choose>
			<xsl:when test="$d">
				<xsl:value-of select="substring($d,9,2)"/>
				<xsl:text>/</xsl:text>
				<xsl:value-of select="substring($d,6,2)"/>
				<xsl:text>/</xsl:text>
				<xsl:value-of select="substring($d,1,4)"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- Format Y or N -->
	<xsl:template name="formatYorN">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="$value='Y'">Yes</xsl:when>
			<xsl:when test="$value='N'">No</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="displayValue">
					<xsl:with-param name="value" select="$value"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Format sensitivity -->
	<xsl:template name="formatSensitivity">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="$value='HS'">Highly Sensitive</xsl:when>
			<xsl:when test="$value='S'">Sensitive</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="displayValue">
					<xsl:with-param name="value" select="$value"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- check for empty value and put a character if no value -->
	<xsl:template name="displayValue">
		<xsl:param name="value"/>
		<xsl:param name="formatLineBreaks"/>
		<xsl:variable name="defaultBlank" select="'-'"/>
		<xsl:choose>
			<xsl:when test="string-length($value) &lt; 1">
				<xsl:value-of select="$defaultBlank"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$formatLineBreaks = 'true'">
						<xsl:value-of disable-output-escaping="yes" select="user:FormatLineBreaks(string($value))"/>
						<!--<xsl:value-of select="user:alertMe()"/>-->
						<!--<xsl:value-of select="$value"/>-->
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$value"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
