<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/xhtml" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sup="http://www.show.scot.nhs.uk/isd/Supplementary" xmlns:gen="http://www.show.scot.nhs.uk/isd/General" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:user="http://www.sci.scot.nhs.uk" exclude-result-prefixes="user msxsl">
	<xsl:output method="html"/>
	<msxsl:script language="javascript" implements-prefix="user">
		<![CDATA[
			
			function FormatLineBreaks(strValue)
			{
				var strText = escape(strValue);
				strText = ReplaceAll(strText, "%0D%0A", "<br/>");
				
				return unescape(strText);
			}
			
			function ReplaceAll(strValue, strSearchValue, strReplacementValue)
			{
				var strText = strValue;
				while (strText.indexOf(strSearchValue) > -1)
				{
					strText = strText.replace(strSearchValue, strReplacementValue);
				}
				return strText;
			}
			
		]]>
	</msxsl:script>
	<xsl:template match="/*">
		<html>
			<head>
				<style type="text/css">
					body
					{
						font-family: Tahoma, Arial, Helvetica, sans-serif;
						font-size: 11px;
						margin-top : 15px;
						margin-left : 15px;
						background-color: white;
					}
					
					p
					{
						margin-bottom : 2px;
						margin-top : 2px;
					}
					
					h1
					{
						font-size: 16 px;
						font-weight: bold;
						color : black;
						margin-bottom : 4px;
						margin-top : 4px;
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
					}
					
					h2
					{
						font-size: 14 px;
						margin-bottom : 3px;
						margin-top : 3px;
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
						font-weight: bold;
					}
					
					table
					{
						font-size: 11 px ;
					}
					
					.bottomBorder
					{
						border-bottom: black thin solid
					}
					
					.outsideBorder
					{
					    border: solid 1px black;
					}
					
					.itemTitle
					{
						white-space:nowrap;
						vertical-align:top;
					}
					
					.barcode
					{
						font-family: SCIBC;
						font-size:20 px;
					}
					
					.barcodeText
					{
						font-family: Tahoma, Arial, Helvetica, sans-serif;
						font-size: 9px;
					}
				</style>
			</head>
			<body>
				<xsl:if test="sup:DocumentData/gen:UniqueCarePathwayNumber">
					<center>
						<div class="barcode">
							*<xsl:value-of select="sup:DocumentData/gen:UniqueCarePathwayNumber"/>*
						</div>
						<div class="barcodeText">
							Unique Care Pathway Number: <xsl:value-of select="sup:DocumentData/gen:UniqueCarePathwayNumber"/>
						</div>		
					</center>
				</xsl:if>
				<table class="bottomBorder" width="100%">
					<tbody>
						<tr>
							<td>
								<h1>Supplementary Message</h1>
							</td>
							<td align="right">
								<xsl:call-template name="formatDate">
									<xsl:with-param name="d" select="/sup:SupplementaryDocument/sup:DocumentData/gen:DocumentAttestationDate"/>
								</xsl:call-template>
								&#160;
								<xsl:value-of select="/sup:SupplementaryDocument/sup:DocumentData/gen:DocumentAttestationTime"/>
							</td>
						</tr>
					</tbody>
				</table>
				<br/>
				<table class="outsideBorder" width="100%">
					<colgroup>
						<col width="50%"/>
						<col/>
					</colgroup>
					<tbody>
						<tr>
							<td colspan="2">
								<h2>Supplementary Message</h2>
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<table width="100%">
									<colgroup>
										<col width="10%"/>
										<col/>
									</colgroup>
									<tbody>
										<tr>
											<td class="itemTitle">Consent to share</td>
											<td class="outsideBorder">
												<xsl:call-template name="formatYorN">
													<xsl:with-param name="value" select="/sup:SupplementaryDocument/sup:DocumentData/gen:ConsentToShare"/>
												</xsl:call-template>
											</td>
										</tr>
										<tr>
											<td class="itemTitle">Sensitivity</td>
											<td class="outsideBorder">
												<xsl:call-template name="formatSensitivity">
													<xsl:with-param name="value" select="/sup:SupplementaryDocument/sup:DocumentData/gen:Sensitivity"/>
												</xsl:call-template>
											</td>
										</tr>
										<tr>
											<td class="itemTitle">Urgency</td>
											<td class="outsideBorder">
												<xsl:call-template name="formatSensitivity">
													<xsl:with-param name="value" select="/sup:SupplementaryDocument/sup:MessageData/sup:UrgencyValue"/>
												</xsl:call-template>
											</td>
										</tr>
									</tbody>
								</table>
							</td>
						</tr>
						<tr>
							<td valign="top">
								<xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:Sender">
									<xsl:with-param name="headerTitle">
										From:
									</xsl:with-param>
								</xsl:apply-templates>
							</td>
							<td valign="top">
								<xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:Destination">
									<xsl:with-param name="headerTitle">
										To:
									</xsl:with-param>
								</xsl:apply-templates>
							</td>
						</tr>
					</tbody>
				</table>
				<br/>
				<table class="outsideBorder" width="100%">
					<colgroup>
						<col width="50%"/>
						<col/>
					</colgroup>
					<tbody>
						<tr>
							<td colspan="2">
								<h2>Original <xsl:value-of select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:OriginalMessage/sup:GatewayMessageTypeName"/> Message</h2>
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<table width="100%">
									<colgroup>
										<col width="10%"/>
										<col/>
									</colgroup>
									<tbody>
										<tr>
											<td class="itemTitle">Gateway Message Type</td>
											<td class="outsideBorder">
												<xsl:call-template name="displayValue">
													<xsl:with-param name="value" select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:OriginalMessage/sup:GatewayMessageTypeName"/>
												</xsl:call-template>
											</td>
										</tr>
										<tr>
											<td class="itemTitle">Sent</td>
											<td class="outsideBorder">
												<xsl:call-template name="formatDate">
													<xsl:with-param name="d" select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:OriginalMessage/sup:DateSent"/>
												</xsl:call-template>&#160;
												<xsl:value-of select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:OriginalMessage/sup:TimeSent"/>
											</td>
										</tr>
									</tbody>
								</table>
							</td>
						</tr>
						<tr>
							<td valign="top">
								<xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:OriginalMessage/sup:Sender">
									<xsl:with-param name="headerTitle">
										From:
									</xsl:with-param>
								</xsl:apply-templates>
							</td>
							<td valign="top">
								<xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientAdministration/sup:OriginalMessage/sup:Destination">
									<xsl:with-param name="headerTitle">
										To:
									</xsl:with-param>
								</xsl:apply-templates>
							</td>
						</tr>
					</tbody>
				</table>
				<br/>
				<table class="outsideBorder" width="100%">
					<colgroup>
						<col width="50%"/>
						<col/>
					</colgroup>
					<tbody>
						<tr>
							<td colspan="2">
								<h2>Patient</h2>
							</td>
						</tr>
						<tr>
							<td>
								<xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics"/>
							</td>
						</tr>
					</tbody>
				</table>
				<br/>
				<table class="outsideBorder" width="100%">
					<tbody>
						<tr>
							<td>
								<h2>Supplementary Message Detail</h2>
							</td>
						</tr>
						<tr>
							<td class="outsideBorder" style="height: 120px; vertical-align: top;">
								<xsl:call-template name="displayValue">
									<xsl:with-param name="value" select="/sup:SupplementaryDocument/sup:MessageData/sup:Details"/>
									<xsl:with-param name="formatLineBreaks" select="'true'"/>
								</xsl:call-template>
							</td>
						</tr>
					</tbody>
				</table>
				<br/>
			</body>
		</html>
	</xsl:template>
	<!-- check for empty value and put a character if no value -->
	<xsl:template name="displayValue">
		<xsl:param name="value"/>
		<xsl:param name="formatLineBreaks"/>
		<xsl:variable name="defaultBlank" select="'-'"/>
		<xsl:choose>
			<xsl:when test="string-length($value) &lt; 1">
				<xsl:value-of select="$defaultBlank"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$formatLineBreaks = 'true'">
						<xsl:value-of disable-output-escaping="yes" select="user:FormatLineBreaks(string($value))"/>
						<!--<xsl:value-of select="user:alertMe()"/>-->
						<!--<xsl:value-of select="$value"/>-->
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$value"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Format the sex -->
	<xsl:template name="formatSex">
		<xsl:param name="sex"/>
		<xsl:choose>
			<xsl:when test="$sex='F'">Female</xsl:when>
			<xsl:when test="$sex='M'">Male</xsl:when>
			<xsl:otherwise>Not specified</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Format Y or N -->
	<xsl:template name="formatYorN">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="$value='Y'">Yes</xsl:when>
			<xsl:when test="$value='N'">No</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="displayValue">
					<xsl:with-param name="value" select="$value"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Format sensitivity -->
	<xsl:template name="formatSensitivity">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="$value='HS'">Highly Sensitive</xsl:when>
			<xsl:when test="$value='S'">Sensitive</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="displayValue">
					<xsl:with-param name="value" select="$value"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- format the date -->
	<xsl:template name="formatDate">
		<xsl:param name="d"/>
		<xsl:choose>
			<xsl:when test="$d">
				<xsl:value-of select="substring($d,9,2)"/>
				<xsl:text>/</xsl:text>
				<xsl:value-of select="substring($d,6,2)"/>
				<xsl:text>/</xsl:text>
				<xsl:value-of select="substring($d,1,4)"/>
			</xsl:when>
			<xsl:otherwise>
				&#160;
			  </xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="sup:Sender | sup:Destination">
		<xsl:param name="headerTitle"/>
		<xsl:call-template name="DisplayHcpDetailType">
			<xsl:with-param name="headerTitle" select="$headerTitle"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="gen:HcpName">
		<xsl:call-template name="ExtractPersonalNameType"/>
	</xsl:template>
	<xsl:template match="gen:HcpSpecialty">
		<xsl:call-template name="ExtractSpecialtyType"/>
	</xsl:template>
	<xsl:template match="gen:OrganisationAddress | gen:PatientAddress">
		<xsl:call-template name="ExtractAddressType"/>
	</xsl:template>
	<xsl:template match="gen:OrganisationTelecom">
		<xsl:call-template name="ExtractTelecomType"/>
	</xsl:template>
	<xsl:template match="sup:PatientDemographics">
		<xsl:call-template name="DisplayPatientDemographics"/>
	</xsl:template>
	<xsl:template name="DisplayHcpDetailType">
		<xsl:param name="headerTitle"/>
		<table width="100%">
			<colgroup>
				<col width="5%" style=""/>
				<col/>
			</colgroup>
			<tbody>
				<tr>
					<td colspan="2" style="font-weight:bold;">
						<xsl:value-of select="$headerTitle"/>
					</td>
				</tr>
				<xsl:if test="gen:HcpId[gen:IdScheme='GmcCode']">
					<tr>
						<td class="itemTitle">GMC code</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:HcpId[gen:IdScheme='GmcCode']/gen:IdValue">
									<xsl:apply-templates select="gen:HcpId[gen:IdScheme='GmcCode']/gen:IdValue"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="gen:HcpId[gen:IdScheme='GpCode']">
					<tr>
						<td class="itemTitle">GP code</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:HcpId[gen:IdScheme='GpCode']/gen:IdValue">
									<xsl:apply-templates select="gen:HcpId[gen:IdScheme='GpCode']/gen:IdValue"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>				
				</xsl:if>
				<xsl:if test="gen:HcpName">
					<tr>
						<td class="itemTitle">HCP Name</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:HcpName">
									<xsl:apply-templates select="gen:HcpName"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="gen:HcpSpecialty">
					<tr>
						<td class="itemTitle">HCP Specialty</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:HcpSpecialty">
									<xsl:apply-templates select="gen:HcpSpecialty"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="gen:EmployingOrganisation/gen:OrganisationId[gen:IdScheme='PracticeID']/gen:IdValue">
					<tr>
						<td class="itemTitle">Practice Id</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:EmployingOrganisation/gen:OrganisationId[gen:IdScheme='PracticeID']/gen:IdValue">
									<xsl:value-of select="gen:EmployingOrganisation/gen:OrganisationId[gen:IdScheme='PracticeID']/gen:IdValue"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="gen:EmployingOrganisation/gen:OrganisationId[gen:IdScheme='ProviderID']/gen:IdValue">
					<tr>
						<td class="itemTitle">Provider Id</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:EmployingOrganisation/gen:OrganisationId[gen:IdScheme='ProviderID']/gen:IdValue">
									<xsl:value-of select="gen:EmployingOrganisation/gen:OrganisationId[gen:IdScheme='ProviderID']/gen:IdValue"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="gen:EmployingOrganisation/gen:OrganisationId/gen:IdSource">
					<tr>
						<td class="itemTitle">Organisation Source</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:EmployingOrganisation/gen:OrganisationId/gen:IdSource">
									<xsl:value-of select="gen:EmployingOrganisation/gen:OrganisationId/gen:IdSource"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:if>
				<tr>
					<td class="itemTitle">Organisation Name</td>
					<td class="outsideBorder">
						<xsl:choose>
							<xsl:when test="gen:EmployingOrganisation/gen:OrganisationName">
								<xsl:apply-templates select="gen:EmployingOrganisation/gen:OrganisationName"/>
							</xsl:when>
							<xsl:otherwise>-</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				<tr>
					<td class="itemTitle">Address</td>
					<td class="outsideBorder">
						<xsl:choose>
							<xsl:when test="gen:EmployingOrganisation/gen:OrganisationAddress">
								<xsl:apply-templates select="gen:EmployingOrganisation/gen:OrganisationAddress"/>
							</xsl:when>
							<xsl:otherwise>-</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				<tr>
					<td class="itemTitle">Telephone</td>
					<td class="outsideBorder">
						<xsl:choose>
							<xsl:when test="gen:EmployingOrganisation/gen:OrganisationTelecom[gen:TelecomType='Voice']">
								<xsl:apply-templates select="gen:EmployingOrganisation/gen:OrganisationTelecom[gen:TelecomType='Voice']"/>
							</xsl:when>
							<xsl:otherwise>-</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				<xsl:if test="gen:EmployingOrganisation/gen:OrganisationTelecom[gen:TelecomType='Facsimile']">
					<tr>
						<td class="itemTitle">Fax</td>
						<td class="outsideBorder">
							<xsl:choose>
								<xsl:when test="gen:EmployingOrganisation/gen:OrganisationTelecom[gen:TelecomType='Facsimile']">
									<xsl:apply-templates select="gen:EmployingOrganisation/gen:OrganisationTelecom[gen:TelecomType='Facsimile']"/>
								</xsl:when>
								<xsl:otherwise>-</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:if>
			</tbody>
		</table>
	</xsl:template>
	<xsl:template name="DisplayPatientDemographics">
		<table width="100%">
			<tbody style="vertical-align:top">
				<tr>
					<td valign="top">
						<table width="100%">
							<colgroup>
								<col width="20%"/>
								<col/>
							</colgroup>
							<tbody>
								<tr>
									<td class="itemTitle">Title</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientName/gen:StructuredName/gen:Title"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">Forename</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientName/gen:StructuredName/gen:GivenName"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">Surname</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientName/gen:StructuredName/gen:FamilyName"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">Birth Surname</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientName[gen:NameType='Birth Surname']/gen:UnstructuredName"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">Previous Surname</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientName[gen:NameType='Previous Surname']/gen:UnstructuredName"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">NHS #</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientId[gen:IdScheme='NHS Number']/gen:IdValue"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">DOB</td>
									<td class="outsideBorder">
										<xsl:call-template name="formatDate">
											<xsl:with-param name="d" select="gen:DateOfBirth"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">Sex</td>
									<td class="outsideBorder">
										<xsl:call-template name="formatSex">
											<xsl:with-param name="sex" select="gen:Sex"/>
										</xsl:call-template>
									</td>
								</tr>
							</tbody>
						</table>
					</td>
					<td valign="top">
						<table width="100%">
							<colgroup>
								<col width="20%"/>
								<col/>
							</colgroup>
							<tbody>
								<tr>
									<td class="itemTitle">Address</td>
									<td class="outsideBorder">
										<xsl:for-each select="gen:PatientAddress/gen:StructuredAddress/gen:AddressLine">
											<xsl:value-of select="."/>
											<br/>
										</xsl:for-each>
										<xsl:value-of select="gen:PatientAddress/gen:PostCode"/>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">Home Telephone</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientTelecom[gen:TelecomType='Voice'][gen:TelecomMode='Home']/gen:UnstructuredTelecom"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">Mobile Telephone</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientTelecom[gen:TelecomType='Voice'][gen:TelecomMode='Mobile']/gen:UnstructuredTelecom"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td class="itemTitle">E-mail</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:PatientTelecom[gen:TelecomType='E-mail']/gen:UnstructuredTelecom"/>
										</xsl:call-template>
									</td>
								</tr>
								<tr>
									<td>Marital Status</td>
									<td class="outsideBorder">
										<xsl:call-template name="displayValue">
											<xsl:with-param name="value" select="gen:MaritalStatus"/>
										</xsl:call-template>
									</td>
								</tr>
							</tbody>
						</table>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>
	<xsl:template name="ExtractPersonalNameType">
		<xsl:choose>
			<xsl:when test="gen:StructuredName">
				<xsl:if test="gen:StructuredName/gen:Title">
					<xsl:value-of select="gen:StructuredName/gen:Title"/><![CDATA[ ]]></xsl:if>
				<xsl:value-of select="gen:StructuredName/gen:GivenName"/><![CDATA[ ]]><xsl:if test="gen:StructuredName/gen:MiddleName">
					<xsl:value-of select="gen:StructuredName/gen:MiddleName"/><![CDATA[ ]]></xsl:if>
				<xsl:value-of select="gen:StructuredName/gen:FamilyName"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="gen:UnstructuredName"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ExtractSpecialtyType">
		<xsl:value-of select="gen:SpecialtyName"/>
		<xsl:if test="gen:SpecialtyCode"><![CDATA[ (]]><xsl:value-of select="gen:SpecialtyCode"/><![CDATA[)]]></xsl:if>
	</xsl:template>
	<xsl:template name="ExtractAddressType">
		<xsl:choose>
			<xsl:when test="gen:UnstructuredAddress">
				<xsl:value-of select="gen:UnstructuredAddress"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="gen:StructuredAddress/gen:AddressLine">
					<p>
						<xsl:value-of select="."/>
					</p>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
		<p>
			<xsl:value-of select="gen:PostCode"/>
		</p>
	</xsl:template>
	<xsl:template name="ExtractTelecomType">
		<xsl:choose>
			<xsl:when test="gen:StructuredTelecom">
				<xsl:if test="gen:StructuredTelecom/gen:TelecomCountry">
					<xsl:value-of select="gen:StructuredTelecom/gen:TelecomCountry"/><![CDATA[, ]]></xsl:if>
				<xsl:value-of select="gen:StructuredTelecom/gen:TelecomArea"/><![CDATA[ ]]><xsl:value-of select="gen:StructuredTelecom/gen:TelecomNo"/><![CDATA[ ]]><xsl:if test="gen:StructuredTelecom/gen:TelecomExt">
					<xsl:value-of select="gen:StructuredTelecom/gen:TelecomExt"/><![CDATA[ ]]>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="gen:UnstructuredTelecom"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
