<?xml version="1.0" encoding="UTF-8"?>
<!--This stylesheet contains templates to extract data from general schema elements to prepopulation schema elements.
- Its purpose is to promote re-use between message types for a single generla schema
- It is not a standalone file, but is imported by the BuildPrepopulationSource files-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gen="http://www.show.scot.nhs.uk/isd/General">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<xsl:template match="gen:PatientId" mode="ExtractPatientDemographics">	
		<xsl:if test="gen:IdScheme='CHI'">
			<!--Ignore partial CHI numbers which are valid within the referral schema-->
			<xsl:if test="string-length(gen:IdValue) = 10">
				<xsl:element name="CHI" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="gen:IdValue"/>
				</xsl:element>
			</xsl:if>
		</xsl:if>
		<xsl:if test="gen:IdScheme='HCN'">
			<!--Ignore partial HCN numbers which are valid within the referral schema-->
			<xsl:if test="string-length(gen:IdValue) = 10">
				<xsl:element name="CHI" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:IdValue"/>
				</xsl:element>
			</xsl:if>
		</xsl:if>
		<xsl:if test="gen:IdScheme='NHS Number'">
			<!--Ignore partial HCN numbers which are valid within the referral schema-->
			<xsl:if test="string-length(gen:IdValue) = 10">
				<xsl:element name="CHI" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:IdValue"/>
				</xsl:element>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="gen:DateOfBirth" mode="ExtractPatientDemographics">	
			<xsl:element name="DateOfBirth" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="."/>
			</xsl:element>
	</xsl:template>
	<xsl:template name="ExtractPatientNameFromPatientDemographicsType">
		<xsl:choose>
			<xsl:when test="gen:PatientName/gen:NameType[.='Current Name']">
				<xsl:if test="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:Title">
					<xsl:element name="Title" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:Title"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:GivenName">
					<xsl:element name="Forename" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:GivenName"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:MiddleName">
					<xsl:element name="Middlename" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:MiddleName"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:FamilyName">
					<xsl:element name="Surname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:NameType[.='Current Name']/../gen:StructuredName/gen:FamilyName"/>
					</xsl:element>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="gen:PatientName/gen:StructuredName[1]/gen:Title">
					<xsl:element name="Title" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:StructuredName[1]/gen:Title"/>
					</xsl:element>
				</xsl:if>		
				<xsl:if test="gen:PatientName/gen:StructuredName[1]/gen:GivenName">
					<xsl:element name="Forename" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:StructuredName[1]/gen:GivenName"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="gen:PatientName/gen:StructuredName[1]/gen:MiddleName">
					<xsl:element name="Middlename" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:StructuredName[1]/gen:MiddleName"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="gen:PatientName/gen:StructuredName[1]/gen:FamilyName">
					<xsl:element name="Surname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PatientName/gen:StructuredName[1]/gen:FamilyName"/>
					</xsl:element>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:for-each select="gen:PatientName/gen:NameType[.='Birth Surname']">		
			<xsl:if test="../gen:UnstructuredName">
				<xsl:element name="BirthSurname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="../gen:UnstructuredName"/>
				</xsl:element>
			</xsl:if>
		</xsl:for-each>
		<xsl:for-each select="gen:PatientName/gen:NameType[.='Previous Surname']">
			<xsl:if test="../gen:UnstructuredName">
				<xsl:element name="PreviousSurname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="../gen:UnstructuredName"/>
				</xsl:element>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>	
	<xsl:template match="gen:Sex" mode="ExtractPatientDemographics">
		<xsl:element name="Sex" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>	
	<xsl:template match="gen:MaritalStatus" mode="ExtractPatientDemographics">
		<xsl:element name="MaritalStatus" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>	
	<xsl:template match="gen:PatientAddress" mode="ExtractPatientDemographics">
		<xsl:element name="Address" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<!--There can be 1-4 of these-->
			<xsl:for-each select="gen:StructuredAddress/gen:AddressLine">
				<xsl:element name="AddressLine" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="."/>
				</xsl:element>
			</xsl:for-each>
			<xsl:if test="gen:PostCode">
				<xsl:element name="PostCode" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="gen:PostCode"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientTelecom" mode="ExtractPatientDemographics">
		<xsl:if test="gen:TelecomType='Voice'">
			<xsl:if test="gen:TelecomMode='Home'">
				<xsl:element name="PhoneNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:if test="gen:UnstructuredTelecom">
						<xsl:value-of select="gen:UnstructuredTelecom"/>
					</xsl:if>
					<xsl:if test="gen:StructuredTelecom/gen:TelecomNo">
						<xsl:value-of select="gen:StructuredTelecom/gen:TelecomNo"/>
					</xsl:if>
				</xsl:element>
			</xsl:if>
			<xsl:if test="not(../gen:PatientTelecom[gen:TelecomMode='Home']) and not(gen:TelecomMode)">
				<xsl:element name="PhoneNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:if test="gen:UnstructuredTelecom">
						<xsl:value-of select="gen:UnstructuredTelecom"/>
					</xsl:if>
					<xsl:if test="gen:StructuredTelecom/gen:TelecomNo">
						<xsl:value-of select="gen:StructuredTelecom/gen:TelecomNo"/>
					</xsl:if>
				</xsl:element>
			</xsl:if>
			<xsl:if test="gen:TelecomMode='Mobile'">
				<xsl:element name="MobileNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:if test="gen:UnstructuredTelecom">
						<xsl:value-of select="gen:UnstructuredTelecom"/>
					</xsl:if>
					<xsl:if test="gen:StructuredTelecom/gen:TelecomNo">
						<xsl:value-of select="gen:StructuredTelecom/gen:TelecomNo"/>
					</xsl:if>
				</xsl:element>
			</xsl:if>
		</xsl:if>
		<xsl:if test="gen:TelecomType='E-mail'">
			<xsl:element name="EmailAddress" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:UnstructuredTelecom"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template name="ExtractPatientRegistrationFromPatientDemographicsType">
		<xsl:if test="gen:HealthBoardOfResidence | gen:RegisteredGp/gen:EmployingOrganisation | gen:RegisteredGp/gen:HcpId">
			<xsl:element name="PatientRegistration" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:apply-templates select="gen:HealthBoardOfResidence" mode="ExtractPatientRegistrationFromPatientDemographics"/>
				<xsl:if test="gen:RegisteredGp/gen:EmployingOrganisation">
					<xsl:element name="RegisteredPractice" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:apply-templates select="gen:RegisteredGp/gen:EmployingOrganisation" mode="ExtractPatientRegistrationFromPatientDemographics"/>
						<xsl:apply-templates select="gen:RegisteredGp/gen:EmployingOrganisation/gen:OrganisationAddress" mode="ExtractPatientRegistrationFromPatientDemographics"/>
						<xsl:apply-templates select="gen:RegisteredGp/gen:EmployingOrganisation/gen:OrganisationTelecom" mode="ExtractPatientRegistrationFromPatientDemographics"/>	
					</xsl:element>
				</xsl:if>
				<xsl:if test="gen:RegisteredGp/gen:HcpId">
					<xsl:element name="RegisteredGP" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:apply-templates select="gen:RegisteredGp/gen:HcpId" mode="ExtractPatientRegistrationFromPatientDemographics"/>
						<xsl:apply-templates select="gen:RegisteredGp/gen:HcpName" mode="ExtractPatientRegistrationFromPatientDemographics"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="gen:HealthBoardOfResidence" mode="ExtractPatientRegistrationFromPatientDemographics">
		<xsl:if test="string-length(gen:HealthBoardCipher) = 1">
			<xsl:element name="HealthBoardCipher" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:HealthBoardCipher"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="gen:RegisteredGp/gen:EmployingOrganisation" mode="ExtractPatientRegistrationFromPatientDemographics">
		<xsl:if test="gen:OrganisationId/gen:IdScheme='PracticeID'">
			<xsl:element name="PracticeCode" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:OrganisationId/gen:IdValue"/>			
			</xsl:element>
		</xsl:if>
		<xsl:if test="gen:OrganisationName">
			<xsl:element name="Name" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:OrganisationName"/>			
			</xsl:element>
		</xsl:if>		
	</xsl:template>	
	<xsl:template match="gen:RegisteredGp/gen:EmployingOrganisation/gen:OrganisationAddress" mode="ExtractPatientRegistrationFromPatientDemographics">
		<xsl:if test="gen:AddressType='Practice Address'">
			<xsl:element name="Address" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<!--There can be 1-4 of these-->
				<xsl:for-each select="gen:StructuredAddress/gen:AddressLine">
					<xsl:element name="AddressLine" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="."/>
					</xsl:element>
				</xsl:for-each>
				<xsl:if test="gen:PostCode">
					<xsl:element name="PostCode" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:PostCode"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="gen:RegisteredGp/gen:EmployingOrganisation/gen:OrganisationTelecom" mode="ExtractPatientRegistrationFromPatientDemographics">	
		<xsl:if test="gen:TelecomType='Voice'">
			<xsl:element name="PhoneNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="gen:UnstructuredTelecom">
					<xsl:value-of select="gen:UnstructuredTelecom"/>
				</xsl:if>
				<xsl:if test="gen:StructuredTelecom/gen:TelecomNo">
					<xsl:value-of select="gen:StructuredTelecom/gen:TelecomNo"/>
				</xsl:if>
			</xsl:element>		
		</xsl:if>
		<xsl:if test="gen:TelecomType='Facsimile'">
			<xsl:element name="Fax" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="gen:UnstructuredTelecom">
					<xsl:value-of select="gen:UnstructuredTelecom"/>
				</xsl:if>
				<xsl:if test="gen:StructuredTelecom/gen:TelecomNo">
					<xsl:value-of select="gen:StructuredTelecom/gen:TelecomNo"/>
				</xsl:if>
			</xsl:element>
		</xsl:if>
		<xsl:if test="gen:TelecomType='E-mail'">
			<xsl:element name="Email" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:UnstructuredTelecom"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>	
	<xsl:template match="gen:RegisteredGp/gen:HcpId" mode="ExtractPatientRegistrationFromPatientDemographics">
		<!--Gateway uses GmcCode but the referral schema also allows GMC which may come via inbound interface-->
		<xsl:if test="gen:IdScheme='GmcCode' or gen:IdScheme='GMC'">
			<xsl:element name="GMCNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:IdValue"/>
			</xsl:element>
		</xsl:if>
		<xsl:if test="gen:IdScheme='GpCode'">
			<xsl:choose>
				<!--The schema allows 5 characters, but if the GpCode has come from GPASS it will be 6 characters therefore-->
				<!--we need to remove the prefix-->
				<xsl:when test="string-length(gen:IdValue) &gt; 5">
					<xsl:element name="GPCode" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="substring(gen:IdValue,2)"/>
					</xsl:element>	
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="GPCode" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:IdValue"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	<xsl:template match="gen:RegisteredGp/gen:HcpName" mode="ExtractPatientRegistrationFromPatientDemographics">
		<xsl:if test="gen:StructuredName">
			<xsl:if test="gen:StructuredName/gen:Title">
				<xsl:element name="Title" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="gen:StructuredName/gen:Title"/>
				</xsl:element>
			</xsl:if>
			<xsl:element name="Forename" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:StructuredName/gen:GivenName"/>
			</xsl:element>
			<xsl:element name="Surname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="gen:StructuredName/gen:FamilyName"/>
			</xsl:element>
		</xsl:if>
		<xsl:if test="gen:UnstructuredName">
			<!--It doesn't really matter if these are not split up correctly as they are all joined back together into an-->
			<!--UnstructuredName within prepopulation.xml-->
			<xsl:choose>
				<xsl:when test="contains(gen:UnstructuredName, ' ')">
					<xsl:element name="Title" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="substring-before(gen:UnstructuredName, ' ')"/>
					</xsl:element>
					<xsl:variable name="strSearch" select="substring-after(gen:UnstructuredName, ' ')"/>
					<xsl:choose>
						<xsl:when test="contains($strSearch, ' ')">
							<xsl:element name="Forename" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
								<xsl:value-of select="substring-before($strSearch, ' ')"/>
							</xsl:element>						
							<xsl:element name="Surname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
								<xsl:value-of select="substring-after($strSearch, ' ')"/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="Surname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
								<xsl:value-of select="$strSearch"/>
							</xsl:element>
						</xsl:otherwise>					
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="Surname" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="gen:UnstructuredName"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>

	<xsl:template match="gen:LifestyleRisk" mode="ExtractPatientClinicalInformationLifestyleRiskFromLifestyleRiskType">
		<xsl:if test="gen:ReligiousObservance">
			<xsl:element name="ReligiousObservance" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<!--This will only select the first ReligiousObservance from the referral xml, third-party-interface-1.4.xsd only allows one anyway-->
				<xsl:value-of select="gen:ReligiousObservance"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>