<?xml version="1.0" encoding="UTF-8"?>
<!--This stylesheet takes discharge xml and converts it into prepopulation souce xml based-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:idd="http://www.show.scot.nhs.uk/isd/Discharge" xmlns:gen="http://www.show.scot.nhs.uk/isd/General" xmlns:sup="http://www.show.scot.nhs.uk/isd/Supplementary">
	<xsl:output method="xml"  encoding="UTF-8" indent="yes"/>
	<xsl:include href="../../PrePopulationExtractionTemplates/General-2.8.xslt"/>
	<xsl:include href="../../PrePopulationExtractionTemplates/Supplementary_General-2.8.xslt"/>
	<xsl:template match="/idd:DischargeDocument">
		<xsl:element name="PrePopulationDocument" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:attribute name="SchemaVersion">1.2</xsl:attribute>
			<xsl:apply-templates select="idd:MessageDataIdd/idd:PatientDemographics" mode="ExtractPatientDemographics"/>
			<xsl:call-template name="ExtractPatientBackgroundInfromation"/>
			<xsl:apply-templates select="idd:MessageDataIdd/idd:PatientDemographics" mode="ExtractPatientRegistrationFromPatientDemographicsType"/>
			<xsl:call-template name="ExtractPatientClinicalInformation"/>
			<xsl:apply-templates select="idd:MessageDataIdd/idd:PatientAdministrationIdd" mode="ExtractOriginalMessageXml"/>
		</xsl:element>	
	</xsl:template>
	<xsl:template match="idd:MessageDataIdd/idd:PatientDemographics" mode="ExtractPatientDemographics">
		<xsl:element name="PatientDemographics" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="gen:PatientId" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:DateOfBirth" mode="ExtractPatientDemographics"/>
			<xsl:call-template name="ExtractPatientNameFromPatientDemographicsType"/>
			<xsl:apply-templates select="gen:Sex" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:MaritalStatus" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:PatientAddress" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:PatientTelecom" mode="ExtractPatientDemographics"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ExtractPatientBackgroundInfromation">
		<xsl:element name="PatientBackgroundInformation" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
	</xsl:template>
	<xsl:template match="idd:MessageDataIdd/idd:PatientDemographics" mode="ExtractPatientRegistrationFromPatientDemographicsType">
		<xsl:call-template name="ExtractPatientRegistrationFromPatientDemographicsType"/>
	</xsl:template>
	<xsl:template name="ExtractPatientClinicalInformation">
		<xsl:element name="PatientClinicalInformation" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:element name="Medication" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="Conditions" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="Procedures" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="FamilyConditions" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="Alerts" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:element name="Allergies" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
				<xsl:element name="Intolerances" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
				<xsl:element name="LifeStyleRisks" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:apply-templates select="idd:MessageDataIdd/idd:ClinicalDataIdd/idd:Alerts/gen:LifestyleRisk" mode="ExtractPatientClinicalInformationLifestyleRiskFromLifestyleRiskType"/>						
				</xsl:element>
				<xsl:element name="RiskToOthers" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			</xsl:element>
			<xsl:element name="PatientMeasurements" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
		</xsl:element>		
	</xsl:template>
	<xsl:template match="idd:MessageDataIdd/idd:PatientAdministrationIdd" mode="ExtractOriginalMessageXml">
		<xsl:element name="OriginalMessageXml" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:element name="Sender" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="idd:AdmissionData">
					<xsl:apply-templates select="idd:AdmissionData" mode="ExtractOriginalMessageXml"/>
				</xsl:if>
			</xsl:element>
			<xsl:element name="Destination" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="idd:Referrer/idd:ReferringGp">
					<xsl:apply-templates select="idd:Referrer/idd:ReferringGp" mode="ExtractOriginalMessageXml"/>
				</xsl:if>
				<xsl:if test="idd:Referrer/idd:ReferringParty">
					<xsl:apply-templates select="idd:Referrer/idd:ReferringParty" mode="ExtractOriginalMessageXml"/>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template match="idd:AdmissionData" mode="ExtractOriginalMessageXml">
		<xsl:call-template name="sup:ExtractDischargeAdministrationDataType"/>
	</xsl:template>
	<xsl:template match="idd:Referrer/idd:ReferringGp" mode="ExtractOriginalMessageXml">
		<xsl:call-template name="sup:ExtractGeneralHcpDetailType"/>
	</xsl:template>
	<xsl:template match="idd:Referrer/idd:ReferringParty" mode="ExtractOriginalMessageXml">
		<xsl:call-template name="sup:ReferralPartyExtractContactDetails"/>
	</xsl:template>
	<xsl:template match="idd:ReferringHcp">
		<xsl:call-template name="sup:ExtractGeneralHcpAbbreviatedType"/>
	</xsl:template>
	<xsl:template match="idd:Hospital">
		<xsl:call-template name="sup:ExtractGeneralOrganisationType"/>
	</xsl:template>
	<xsl:template match="idd:AdmittingSpecialty">
		<xsl:call-template name="sup:ExtractGeneralSpecialtyType"/>
		</xsl:template>
	<xsl:template match="idd:HcpReferredTo">
		<xsl:call-template name="sup:ExtractGeneralHcpAbbreviatedType"/>
	</xsl:template>
	<xsl:template match="idd:AdmittingHcp">
		<xsl:call-template name="sup:ExtractGeneralHcpAbbreviatedType"/>
	</xsl:template>

	<xsl:template name="sup:ExtractDischargeAdministrationDataType">
		<xsl:if test="idd:HcpReferredTo">
			<xsl:apply-templates select="idd:HcpReferredTo"/>
		</xsl:if>
		<xsl:if test="not(idd:HcpReferredTo)">
			<xsl:if test="idd:AdmittingHcp">
				<xsl:apply-templates select="idd:AdmittingHcp"/>
			</xsl:if>
		</xsl:if>
		<xsl:apply-templates select="idd:Hospital"/>
		<xsl:if test="not(idd:HcpReferredTo/gen:HcpSpecialty) and not(idd:AdmittingHcp/gen:HcpSpecialty) and idd:AdmittingSpecialty">
			<xsl:apply-templates select="idd:AdmittingSpecialty"/>
		</xsl:if>
	</xsl:template>
	<xsl:template name="sup:ReferralPartyExtractContactDetails">
		<xsl:if test="idd:ReferringHcp">
			<xsl:apply-templates select="idd:ReferringHcp"/>
		</xsl:if>
		<xsl:apply-templates select="idd:ReferringOrg"/>
	</xsl:template>
</xsl:stylesheet>
