<?xml version="1.0" encoding="UTF-8"?>
<!--This stylesheet takes referral xml and converts it into prepopulation souce xml-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:pbr="http://www.show.scot.nhs.uk/isd/PBR" xmlns:ref="http://www.show.scot.nhs.uk/isd/Referral" xmlns:gen="http://www.show.scot.nhs.uk/isd/General" xmlns:sup="http://www.show.scot.nhs.uk/isd/Supplementary">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<xsl:include href="../../PrePopulationExtractionTemplates/General-2.10.xslt"/>
	<xsl:include href="../../PrePopulationExtractionTemplates/Supplementary_General-2.10.xslt"/>
	<xsl:template match="/ref:ReferralDocument">
		<xsl:element name="PrePopulationDocument" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:attribute name="SchemaVersion">1.3</xsl:attribute>
			<xsl:apply-templates select="ref:MessageDataRef/ref:PatientDemographics" mode="ExtractPatientDemographics"/>
			<xsl:call-template name="ExtractPatientBackgroundInfromation"/>
			<xsl:apply-templates select="ref:MessageDataRef/ref:PatientDemographics" mode="ExtractPatientRegistrationFromPatientDemographicsType"/>
			<xsl:call-template name="ExtractPatientClinicalInformation"/>
			<xsl:apply-templates select="ref:MessageDataRef/ref:PatientAdministrationRef" mode="ExtractOriginalMessageXml"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="ref:MessageDataRef/ref:PatientDemographics" mode="ExtractPatientDemographics">
		<xsl:element name="PatientDemographics" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="gen:PatientId" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:DateOfBirth" mode="ExtractPatientDemographics"/>
			<xsl:call-template name="ExtractPatientNameFromPatientDemographicsType"/>
			<xsl:apply-templates select="gen:Sex" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:MaritalStatus" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:PatientAddress" mode="ExtractPatientDemographics"/>
			<xsl:apply-templates select="gen:PatientTelecom" mode="ExtractPatientDemographics"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ExtractPatientBackgroundInfromation">
		<xsl:element name="PatientBackgroundInformation" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
	</xsl:template>
	<xsl:template match="ref:MessageDataRef/ref:PatientDemographics" mode="ExtractPatientRegistrationFromPatientDemographicsType">
		<xsl:call-template name="ExtractPatientRegistrationFromPatientDemographicsType"/>
	</xsl:template>
	<xsl:template name="ExtractPatientClinicalInformation">
		<xsl:element name="PatientClinicalInformation" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:element name="Medication" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="Conditions" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="Procedures" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="FamilyConditions" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			<xsl:element name="Alerts" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:element name="Allergies" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
				<xsl:element name="Intolerances" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
				<xsl:element name="LifeStyleRisks" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:apply-templates select="ref:MessageDataRef/ref:ClinicalDataRef/ref:Alerts/gen:LifestyleRisk" mode="ExtractPatientClinicalInformationLifestyleRiskFromLifestyleRiskType"/>						
				</xsl:element>
				<xsl:element name="RiskToOthers" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
			</xsl:element>
			<xsl:element name="PatientMeasurements" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource"/>
		</xsl:element>		
	</xsl:template>
	<xsl:template match="ref:MessageDataRef/ref:PatientAdministrationRef" mode="ExtractOriginalMessageXml">
		<xsl:element name="OriginalMessageXml" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:element name="Sender" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="ref:Referrer">
					<xsl:choose>
						<xsl:when test="ref:Referrer/ref:ReferringGP">
							<xsl:apply-templates select="ref:Referrer/ref:ReferringGP" mode="ExtractOriginalMessageXml"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select="ref:Referrer/ref:ReferringParty" mode="ExtractOriginalMessageXml"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:element>
			<xsl:element name="Destination" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="ref:ReferralTo">
					<xsl:apply-templates select="ref:ReferralTo" mode="ExtractOriginalMessageXml"/>
				</xsl:if>
			</xsl:element>
			<xsl:element name="UrgencyValue" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="ref:ReferralUrgencyValue"/>
			</xsl:element>
		</xsl:element>
		<xsl:element name="DocumentData" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="/ref:ReferralDocument/ref:DocumentData/gen:UniqueCarePathwayNumber" mode="ExtractOriginalMessageXml"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="/ref:ReferralDocument/ref:DocumentData/gen:UniqueCarePathwayNumber" mode="ExtractOriginalMessageXml">
		<xsl:if test="string-length(.)=13">
			<xsl:element name="UniqueCarePathwayNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ref:Referrer/ref:ReferringGP" mode="ExtractOriginalMessageXml">
		<xsl:call-template name="sup:ExtractGeneralHcpDetailType"/>
	</xsl:template>
	<xsl:template match="ref:Referrer/ref:ReferringParty" mode="ExtractOriginalMessageXml">
		<xsl:call-template name="sup:ReferralPartyExtractContactDetails"/>
	</xsl:template>
	<xsl:template match="ref:ReferralTo" mode="ExtractOriginalMessageXml">
		<xsl:call-template name="sup:ExtractReferralToType"/>
	</xsl:template>
	<!-- Referral Supplementary templates  - START-->
	<xsl:template name="sup:ReferralPartyExtractContactDetails">
		<xsl:if test="ref:ReferringHcp">
			<xsl:apply-templates select="ref:ReferringHcp"/>
		</xsl:if>
		<xsl:apply-templates select="ref:ReferringOrg"/>
	</xsl:template>
	<xsl:template name="sup:ExtractReferralToType">
		<xsl:apply-templates select="ref:HcpReferredTo"/>
		<xsl:apply-templates select="ref:Hospital"/>
		<xsl:apply-templates select="ref:ReferredToSpecialty"/>
	</xsl:template>
		<xsl:template match="ref:ReferringHcp">
		<xsl:call-template name="sup:ExtractGeneralHcpAbbreviatedType"/>
	</xsl:template>
	<xsl:template match="ref:ReferringOrg">
		<xsl:call-template name="sup:ExtractGeneralOrganisationType"/>
	</xsl:template>
	<xsl:template match="ref:HcpReferredTo">
		<xsl:apply-templates select="gen:HcpId"/>
		<xsl:apply-templates select="gen:HcpName"/>
	</xsl:template>
	<xsl:template match="ref:Hospital">
		<xsl:call-template name="sup:ExtractGeneralOrganisationType"/>
	</xsl:template>
	<xsl:template match="ref:ReferredToSpecialty">
		<xsl:call-template name="sup:ExtractGeneralSpecialtyType"/>
	</xsl:template>
	<!-- Referral Supplementary templates  - END -->
</xsl:stylesheet>
