<?xml version="1.0" encoding="UTF-8"?>
<!-- =========================================================
 File:			referrerTestForm.xslt
 Description:	XSLT stylesheet to display a user test page for Sender Detail Maintenance. 
				Be careful of creating white space within the code.
========================================================= -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:user="mailto:dorothee.huck@gpass.co.uk" exclude-result-prefixes="user msxsl">
	<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes"/>
	<!-- Paths to utilities and graphics used -->
	<xsl:variable name="helpicon" select="'../graphics/help.gif'"/>
	<xsl:variable name="spacer" select="'../graphics/hidden.gif'"/>
	<xsl:variable name="dateicon" select="'../graphics/date.gif'"/>
	<xsl:variable name="spellicon" select="'../graphics/spell.gif'"/>
	<xsl:variable name="deleteicon" select="'../graphics/delete.gif'"/>
	<xsl:variable name="calendar" select="'../utility/popcjs.htm'"/>
	<xsl:variable name="newmsg" select="'false'"/>
	<xsl:variable name="enablespellcheck" select="'false'"/>
	<xsl:variable name="showgpquestions" select="'false'"/>
	<!-- =========================================================
	 Name:			Protocol
	 Description:	The protocol definition. Look for category elements.
	 ========================================================= -->
	<xsl:template match="protocol">
		<!-- Referral data-entry form placeholder -->
		<form name="formRef" method="post">
			<!-- Transform category elements -->
			<xsl:apply-templates select="./category" mode="page"/>
		</form>
	</xsl:template>
	<!-- =========================================================
	 Name:			\protocol\category
	 Description:	Categories within the protocol. The category represents the highest level of division within the protocol definition. For page categories
					output tab flags, and then recurse down, outputting a heading, then free text, questions, and sub-categories. 
	 ========================================================= -->
	<!-- Output tabs for page level categories =========================== -->
	<xsl:template match="category" mode="tab">
		<td>
			<img src="{$spacer}" width="1"/>
		</td>
		<xsl:element name="td">
			<xsl:attribute name="class">tab</xsl:attribute>
			<xsl:attribute name="id">tab_<xsl:value-of select="position()"/></xsl:attribute>
			<xsl:attribute name="nowrap">true</xsl:attribute>
			<xsl:attribute name="onclick">goTab(<xsl:value-of select="position()"/>)</xsl:attribute>
			<!-- Highlight the first tab -->
			<xsl:if test="position()=1">
				<xsl:attribute name="style">color:white;background-color:#000066;</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="@text"/>
		</xsl:element>
	</xsl:template>
	<!-- Output elements for page level categories ======================== -->
	<xsl:template match="category" mode="page">
		<xsl:element name="div">
			<!-- Apply standard category processing -->
			<xsl:apply-templates select=".">
				<xsl:with-param name="level" select="1"/>
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>
	<!-- Process normal category elements ==================================== -->
	<xsl:template match="category">
		<xsl:param name="level" select="3"/>
		<!-- Select the heading to output based on the level -->
		<xsl:choose>
			<xsl:when test="$level &gt;= 3">
				<!-- anything lower than 3 defaults to <h3> -->
				<xsl:element name="h3">
					<xsl:value-of select="@text"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="h{$level}">
					<xsl:value-of select="@text"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
		<!-- Apply templates for elements found within categories -->
		<xsl:apply-templates select="./freeText"/>
		<xsl:apply-templates select="./control"/>
		<xsl:apply-templates select="./question"/>
		<xsl:apply-templates select="./category">
			<xsl:with-param name="level" select="$level + 1"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- =========================================================
	 Name:			Free text templates
	 Description:	Header & footer is displayed and space is set for the 
					main form division. The datepicker division is set up. 
	 ========================================================= -->
	<xsl:template match="* | @* | text()">
		<xsl:copy>
			<xsl:apply-templates select="* | @* | text()"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="freeText">
		<xsl:apply-templates select="*"/>
	</xsl:template>
	<!-- =========================================================
	Name: GenericQuestion
	Description: used for generic questions
	============================================================ -->
	<xsl:template name="genericQuestion">
		<xsl:call-template name="stdquestion">
			<xsl:with-param name="caption" select="@text"/>
			<xsl:with-param name="help" select="help"/>
			<xsl:with-param name="mandatory" select="@mandatory"/>
			<xsl:with-param name="spellCheck" select="@spellCheck"/>
			<xsl:with-param name="hidden">
				<xsl:choose>
					<!-- Outputs a multi-line text box -->
					<xsl:when test="@type='hidden'">
						<xsl:value-of select="'true'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@hidden"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="id" select="@id"/>
			<xsl:with-param name="userinput">
				<xsl:choose>
					<!-- Outputs a multi-line text box -->
					<xsl:when test="@type='textArea'">
						<xsl:element name="textArea">
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<xsl:attribute name="rows">6</xsl:attribute>
							<xsl:if test="@onkeydown != ''">
								<xsl:attribute name="onkeydown"><xsl:value-of select="@onkeydown"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="@readonly = 'true'">
								<xsl:attribute name="readonly">true</xsl:attribute>
							</xsl:if>
							<xsl:if test="normalize-space(@mandatory) = 'true'">
								<xsl:attribute name="class">mandText</xsl:attribute>
								<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
							</xsl:if>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/>
						</xsl:element>
						<xsl:for-each select="./button">
							<xsl:call-template name="btnTemplate">
								<xsl:with-param name="id" select="@id"/>
								<xsl:with-param name="name" select="@name"/>
								<xsl:with-param name="onclick" select="@onclick"/>
								<xsl:with-param name="imgsrc" select="@src"/>
								<xsl:with-param name="value" select="@value"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:when>
					<!-- Outputs a text box -->
					<xsl:when test="@type='text'">
						<xsl:element name="input">
							<xsl:attribute name="type"><xsl:value-of select="@type"/></xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<!-- the document title needs to be updated to reflect any changes to the patient surname -->
							<xsl:if test="@id = 'patient_surname'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<!-- the document title needs to be updated to reflect any changes to the patient forname -->
							<xsl:if test="@id = 'patient_forename'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<!-- the document title needs to be updated to reflect any changes to the patient chi -->
							<xsl:if test="@id = 'chi'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<xsl:if test="@width != ''">
								<xsl:attribute name="style">width:<xsl:value-of select="@width"/>px</xsl:attribute>
							</xsl:if>
							<xsl:if test="@onkeydown != ''">
								<xsl:attribute name="onkeydown"><xsl:value-of select="@onkeydown"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="normalize-space(@mandatory) = 'true'">
								<xsl:attribute name="class">mandText</xsl:attribute>
								<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="@readonly = 'true'">
								<xsl:attribute name="readonly">true</xsl:attribute>
							</xsl:if>
							<xsl:if test="@maxlength != ''">
								<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
							</xsl:if>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/></xsl:attribute>
						</xsl:element>
						<xsl:for-each select="./button">
							<xsl:call-template name="btnTemplate">
								<xsl:with-param name="id" select="@id"/>
								<xsl:with-param name="name" select="@name"/>
								<xsl:with-param name="onclick" select="@onclick"/>
								<xsl:with-param name="imgsrc" select="@src"/>
								<xsl:with-param name="value" select="@value"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="@type='hidden'">
						<xsl:element name="input">
							<xsl:attribute name="type">hidden</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/></xsl:attribute>
						</xsl:element>
					</xsl:when>
					<!-- Outputs a check box, using the standard question format. -->
					<xsl:when test="@type='check'">
						<xsl:element name="input">
							<xsl:attribute name="type">checkbox</xsl:attribute>
							<xsl:attribute name="style">width:16px</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<xsl:if test="@readonly = 'true'">
								<xsl:attribute name="readonly">true</xsl:attribute>
							</xsl:if>
							<xsl:if test="@hidden ='true'">
								<xsl:attribute name="style">display:none</xsl:attribute>
							</xsl:if>
							<xsl:if test="normalize-space(@mandatory) = 'true'">
								<xsl:attribute name="class">mandText</xsl:attribute>
								<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
							</xsl:if>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = 'true'">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
						</xsl:element>
					</xsl:when>
					<xsl:when test="@type='date' or @type='time'">
						<xsl:call-template name="dateinput">
							<xsl:with-param name="id" select="@id"/>
							<xsl:with-param name="userName" select="@userName"/>
							<xsl:with-param name="mandatory" select="@mandatory"/>
							<xsl:with-param name="isCell" select="'false'"/>
							<xsl:with-param name="readonly" select="@readonly"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='radio'">
						<table cellspacing="0" width="100%">
							<xsl:for-each select="option">
								<tr>
									<td align="left" width="16">
										<xsl:element name="input">
											<xsl:attribute name="type">radio</xsl:attribute>
											<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/></xsl:attribute>
											<xsl:attribute name="id"><xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="position()"/></xsl:attribute>
											<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
											<xsl:if test="@hidden ='true'">
												<xsl:attribute name="style">display:none</xsl:attribute>
											</xsl:if>
											<xsl:if test="parent::node()/attribute::onclick !=''">
												<xsl:attribute name="onclick"><xsl:value-of select="parent::node()/attribute::onclick"/></xsl:attribute>
											</xsl:if>
											<xsl:if test="@readonly = 'true'">
												<xsl:attribute name="readonly">true</xsl:attribute>
											</xsl:if>
											<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
											<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
											<xsl:variable name="toconvert">
												<xsl:value-of select="parent::node()/attribute::id"/>
											</xsl:variable>
											<xsl:variable name="protvalue">
												<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
											</xsl:variable>
											<xsl:choose>
												<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$protvalue]) &gt; 0">
													<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = @value">
														<xsl:attribute name="checked">true</xsl:attribute>
													</xsl:if>
												</xsl:when>
												<xsl:otherwise>
													<xsl:if test="@isDefault ='true'">
														<xsl:attribute name="checked">true</xsl:attribute>
													</xsl:if>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:if test="parent::node()/attribute::mandatory = 'true'">
												<xsl:attribute name="class">mandText</xsl:attribute>
												<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
											</xsl:if>
										</xsl:element>
									</td>
									<td width="*">&#160;&#160;<xsl:value-of select="@text"/>
									</td>
								</tr>
							</xsl:for-each>
						</table>
					</xsl:when>
					<xsl:when test="@type='select'">
						<table cellspacing="0">
							<tr>
								<td>
									<xsl:element name="select">
										<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
										<xsl:if test="normalize-space(@mandatory) = 'true'">
											<xsl:attribute name="class">mandText</xsl:attribute>
											<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
										</xsl:if>
										<xsl:if test="@hidden ='true'">
											<xsl:attribute name="style">display:none</xsl:attribute>
										</xsl:if>
										<xsl:for-each select="option">
											<xsl:element name="option">
												<xsl:attribute name="id"><xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="position()"/></xsl:attribute>
												<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
												<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
												<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
												<xsl:variable name="toconvert">
													<xsl:value-of select="parent::node()/attribute::id"/>
												</xsl:variable>
												<xsl:variable name="protvalue">
													<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
												</xsl:variable>
												<xsl:choose>
													<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$protvalue]) &gt; 0">
														<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = @value">
															<xsl:attribute name="selected">true</xsl:attribute>
														</xsl:if>
													</xsl:when>
													<xsl:otherwise>
														<xsl:if test="normalize-space(@isDefault)">
															<xsl:attribute name="selected">true</xsl:attribute>
														</xsl:if>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:value-of select="@text"/>
											</xsl:element>
										</xsl:for-each>
									</xsl:element>
								</td>
							</tr>
						</table>
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="readonly" select="@readonly"/>
		</xsl:call-template>
	</xsl:template>
	<!-- =========================================================
	 Name:			stdquestion
	 Description:	Outputs a standard question, with a caption, 
					input section and help text.
	 ========================================================= -->
	<xsl:template name="stdquestion">
		<xsl:param name="caption"/>
		<xsl:param name="help"/>
		<xsl:param name="mandatory"/>
		<xsl:param name="spellCheck"/>
		<xsl:param name="hidden"/>
		<xsl:param name="id"/>
		<xsl:param name="userinput"/>
		<xsl:param name="readonly"/>
		<table width="100%" cellspacing="0">
			<tr>
				<xsl:if test="normalize-space($caption)">
					<xsl:element name="td">
						<xsl:attribute name="class">question</xsl:attribute>
						<xsl:attribute name="id"><xsl:value-of select="$id"/>_caption</xsl:attribute>
						<xsl:if test="$hidden = 'true'">
							<xsl:attribute name="style">display:none</xsl:attribute>
						</xsl:if>
						<xsl:value-of select="$caption"/>
						<xsl:if test="normalize-space($mandatory) = 'true'">
							<xsl:text/>
							<b>*</b>
						</xsl:if>
					</xsl:element>
				</xsl:if>
				<td width="*" nowrap="true">
					<xsl:copy-of select="$userinput"/>
				</td>
				<td class="help">
					<xsl:if test="normalize-space($help)">
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
							<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpText(string($caption), string(normalize-space($help)))"/></xsl:attribute>
							<xsl:attribute name="class">hand</xsl:attribute>
							<xsl:attribute name="title">Click here for help</xsl:attribute>
							<xsl:if test="$hidden = 'true'">
								<xsl:attribute name="style">display:none</xsl:attribute>
							</xsl:if>
						</xsl:element>
					</xsl:if>
					<xsl:element name="input">
						<xsl:attribute name="type">hidden</xsl:attribute>
						<xsl:attribute name="name"><xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
					</xsl:element>
					<xsl:choose>
						<xsl:when test="$readonly = 'true'">
							<!-- Do not allow spell check on readonly text and textArea fields, even when prepopulation fails and fields are enabled -->
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="$enablespellcheck = 'true'">
								<xsl:if test="$spellCheck = 'true'">
									<img name="{$id}_img" onClick="SpellCheck({$id});" src="{$spellicon}" class="hand"/>
								</xsl:if>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!-- =========================================================
	 Name:			dateinput
	 Description:	Outputs our standard date input field.
	 ========================================================= -->
	<xsl:template name="dateinput">
		<xsl:param name="id"/>
		<xsl:param name="mandatory"/>
		<xsl:param name="userName"/>
		<xsl:param name="tableid"/>
		<xsl:param name="rowid"/>
		<xsl:param name="columnid"/>
		<xsl:param name="isCell"/>
		<xsl:param name="readonly"/>
		<!-- Output input field -->
		<xsl:element name="input">
			<xsl:attribute name="type">text</xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="$id"/></xsl:attribute>
			<xsl:choose>
				<!-- If we are dealing with a patient DOB then we will need to format the date 
					 and update the document title to reflect the change -->
				<xsl:when test="@id = 'patient_dob'">
					<xsl:attribute name="onblur">DateOfBirthUnambiguousDateEntry(this);</xsl:attribute> 
				</xsl:when>
				<!-- All other dates only have to be formatted -->
				<xsl:otherwise>
					<xsl:attribute name="onblur">UnambiguousDateEntry(this);</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
			<xsl:when test="normalize-space($mandatory) = 'true'">
					<xsl:attribute name="class">mandDate</xsl:attribute>
					<xsl:attribute name="text"><xsl:value-of select="$userName"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">normalDate</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
			<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
			<xsl:variable name="toconvert">
				<xsl:value-of select="$id"/>
			</xsl:variable>
			<xsl:variable name="fldid">
				<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$isCell = 'true'">
					<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$fldid]/attribute::value"/></xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="$readonly = 'true'">
				<xsl:attribute name="readonly">true</xsl:attribute>
			</xsl:if>
		</xsl:element>
		<!-- Spacer -->
		<xsl:text/>
		<!-- Output datepicker button -->
		<xsl:choose>
			<xsl:when test="$readonly = 'true'">
				<!-- Do not display any image -->
			</xsl:when>
			<xsl:otherwise>
				<img name="{$id}_img" onClick="ShowCalendar({$id}, {$id});" src="{$dateicon}" class="hand"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- =========================================================
	 Name:			category\question[@type='textArea'  or @type='text' or @type='hidden' or @type='check' or @type='date' or @type='radio' or @type='select' or type='time']
	 Description:	writes input controls based on the type of questions in the protocol
	 ========================================================= -->
	<xsl:template match="question[@type='textArea'  or @type='text' or @type='hidden' or @type='check' or @type='date' or @type='radio' or @type='select' or @type='time']">
		<xsl:choose>
			<xsl:when test=" (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and ($showgpquestions = 'true')">
				<xsl:call-template name="genericQuestion"/>
			</xsl:when>
			<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and  ($showgpquestions = 'false')">
				<xsl:call-template name="genericQuestion"/>
			</xsl:when>
			<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and  ($showgpquestions = 'false')">
				<xsl:call-template name="genericQuestion"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- =========================================================
	 Name:			category\question[type='table']
	 Description:	Displays, populates and gives a unique ID to questions
					that are output as rows of a table.
	 ========================================================= -->
	<xsl:template match="question[@type='table']">
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="tableid">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<div>
		<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name"><xsl:value-of select="@id"/>_rowCount</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="count(row)"/></xsl:attribute>
			</xsl:element>
	<table cellspacing="0" width="100%" id="{@id}">
				<!-- Output columns - the first is the heading caption -->
				<th>
					<font class="tableCaption">
						<xsl:value-of select="@text"/>
					</font>
				</th>
				<xsl:for-each select="column">
					<xsl:element name="th">
						<xsl:attribute name="valign">bottom</xsl:attribute>
						<xsl:value-of select="@text"/>
						<xsl:element name="input">
							<xsl:attribute name="type">hidden</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/>___<xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
						</xsl:element>
					</xsl:element>
					<xsl:element name="th">
						<xsl:choose>
							<xsl:when test="@spellCheck = 'true'">
								<xsl:if test="$enablespellcheck = 'true'">
									<xsl:element name="img">
										<xsl:attribute name="src"><xsl:value-of select="$spellicon"/></xsl:attribute>
										<xsl:attribute name="class">hand</xsl:attribute>
										<xsl:attribute name="align">right</xsl:attribute>
										<xsl:attribute name="onClick">SpellCheckColumn("<xsl:value-of select="$tableid"/>", "<xsl:value-of select="@id"/>")</xsl:attribute>
									</xsl:element>
								</xsl:if>
							</xsl:when>
						</xsl:choose>
					</xsl:element>
				</xsl:for-each>
				<th>
			<xsl:element name="input">
						<xsl:attribute name="type">hidden</xsl:attribute>
						<xsl:attribute name="name"><xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
					</xsl:element>
				</th>
				<xsl:for-each select="row">
					<xsl:variable name="row_num">
						<xsl:value-of select="position()"/>
					</xsl:variable>
					<xsl:variable name="row_id">
						<xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="$row_num"/>
					</xsl:variable>
					<tr>
						<td class="question">
							<xsl:value-of select="@text"/>
							<xsl:element name="input">
								<xsl:attribute name="type">hidden</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$row_id"/>_hiddenName</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
							</xsl:element>
						</td>
						<xsl:for-each select="parent::node()/child::column">
							<xsl:variable name="cell_id">
								<xsl:value-of select="parent::node()/attribute::id"/>___<xsl:value-of select="@id"/>_<xsl:value-of select="$row_num"/>
							</xsl:variable>
							<xsl:choose>
								<!-- Output a date cell -->
								<xsl:when test="normalize-space(@type)='date'">
									<td nowrap="true" width="113">
										<xsl:call-template name="dateinput">
											<xsl:with-param name="id" select="$cell_id"/>
											<xsl:with-param name="tableid" select="$tableid"/>
											<xsl:with-param name="rowid" select="$row_num"/>
											<xsl:with-param name="columnid" select="@id"/>
											<xsl:with-param name="isCell" select="'true'"/>
											<xsl:with-param name="readonly" select="@readonly"/>
										</xsl:call-template>
									</td>
								</xsl:when>
								<!-- Output a select cell -->
								<xsl:when test="@type='select'">
									<td width="0">
										<xsl:element name="select">
											<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
											<xsl:for-each select="option">
												<xsl:element name="option">
													<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
													<xsl:variable name="columnid" select="parent::node()/@id"/>
													<xsl:choose>
														<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]) &gt; 0">
															<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]/attribute::value = @value">
																<xsl:attribute name="selected">true</xsl:attribute>
															</xsl:if>
														</xsl:when>
														<xsl:otherwise>
															<xsl:if test="normalize-space(@isDefault)">
																<xsl:attribute name="selected">true</xsl:attribute>
															</xsl:if>
														</xsl:otherwise>
													</xsl:choose>
													<xsl:value-of select="@text"/>
												</xsl:element>
											</xsl:for-each>
										</xsl:element>
									</td>
								</xsl:when>
								<!-- Output a standard text cell -->
								<xsl:otherwise>
									<td width="*" colspan="2">
										<!-- colspan to fit spell check icon -->
										<xsl:element name="input">
											<xsl:attribute name="type">text</xsl:attribute>
											<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
											<xsl:variable name="columnid" select="@id"/>
											<xsl:if test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]) &gt; 0">
												<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
											</xsl:if>
											<xsl:if test="@maxlength != ''">
												<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
											</xsl:if>
											<xsl:if test="normalize-space(@mandatory) = 'true'">
												<xsl:attribute name="class">mandText</xsl:attribute>
												<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
											</xsl:if>
										</xsl:element>
									</td>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<td class="help">
							<xsl:if test="normalize-space(@help)">
								<xsl:element name="img">
									<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
									<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpText(string(@text), string(normalize-space(@help)))"/></xsl:attribute>
									<xsl:attribute name="class">hand</xsl:attribute>
									<xsl:attribute name="title">Click here for help</xsl:attribute>
								</xsl:element>
							</xsl:if>
						</td>
					</tr>
				</xsl:for-each>
				<!-- row -->
			</table>
		</div>
	</xsl:template>
	<!-- =========================================================
	 Name:			category\question[type='dynaTable']
	 Description:	Displays, populates and gives a unique ID to questions
					that are output as a dynamic table.
	 ========================================================= -->
	<xsl:template match="question[@type='dynaTable' or @type='giDynaTable']">
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="tableid">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<p>
			<table width="98%" cellspacing="0">
				<!-- <tr height="5"><td colspan="3"></td></tr> -->
				<tr>
					<td width="*" align="left">
						<font class="tableCaption">
							<xsl:value-of select="@text"/>
						</font>
					</td>
					<xsl:element name="td">
						<xsl:attribute name="align">center</xsl:attribute>
						<xsl:attribute name="class">buttonup</xsl:attribute>
						<xsl:attribute name="style">width:80;display:none;</xsl:attribute>
						<xsl:attribute name="onClick">ShowHideDeletedRows("<xsl:value-of select="@id"/>")</xsl:attribute>
						<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
						<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
						<xsl:attribute name="title">Click here to hide deleted rows</xsl:attribute>
						<xsl:attribute name="id">showHideDeleted_<xsl:value-of select="@id"/></xsl:attribute>Hide Deleted Rows</xsl:element>
					<xsl:element name="td">
						<xsl:attribute name="align">center</xsl:attribute>
						<xsl:attribute name="class">buttonup</xsl:attribute>
						<xsl:attribute name="style">width:80;</xsl:attribute>
						<xsl:attribute name="onClick">addRow("<xsl:value-of select="@id"/>")</xsl:attribute>
						<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
						<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
						<xsl:attribute name="title">Click here to add a new row</xsl:attribute>
						<xsl:attribute name="id">addRow_<xsl:value-of select="@id"/></xsl:attribute>Add Row</xsl:element>
					<td class="help">
						<xsl:if test="normalize-space(@help)">
							<xsl:element name="img">
								<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
								<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpText(string(@text), string(normalize-space(@help)))"/></xsl:attribute>
								<xsl:attribute name="class">hand</xsl:attribute>
								<xsl:attribute name="title">Click here for help</xsl:attribute>
							</xsl:element>
						</xsl:if>
					</td>
				</tr>
			</table>
			<div align="left" class="dynaTable">		
		<xsl:element name="input">
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@id"/>_rowCount</xsl:attribute>
					<xsl:choose>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) = 0">
							<xsl:attribute name="value">1</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="value"><xsl:value-of select="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row)"/></xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<table cellspacing="2" width="100%" id="{@id}">
					<tr>
						<xsl:element name="th">
						</xsl:element>
						<!-- Note that we do not output a heading caption for table questions -->
						<!-- Output columns - the first and last are blank -->
						<xsl:for-each select="column">
							<xsl:element name="th">
								<xsl:value-of select="@text"/>
								<xsl:element name="input">
									<xsl:attribute name="type">hidden</xsl:attribute>
									<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/>___<xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
									<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
								</xsl:element>
							</xsl:element>
							<xsl:element name="th">
								<xsl:choose>
									<xsl:when test="@spellCheck = 'true'">
										<xsl:if test="$enablespellcheck = 'true'">
											<xsl:element name="img">
												<xsl:attribute name="src"><xsl:value-of select="$spellicon"/></xsl:attribute>
												<xsl:attribute name="class">hand</xsl:attribute>
												<xsl:attribute name="align">right</xsl:attribute>
												<xsl:attribute name="onClick">SpellCheckColumn("<xsl:value-of select="$tableid"/>", "<xsl:value-of select="@id"/>")</xsl:attribute>
											</xsl:element>
										</xsl:if>
									</xsl:when>
								</xsl:choose>
							</xsl:element>
						</xsl:for-each>
						<th>
							<xsl:element name="input">
								<xsl:attribute name="type">hidden</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
							</xsl:element>
						</th>
					</tr>
					<!-- write the rows out.  -->
					<xsl:variable name="orgtableid">
						<xsl:value-of select="@id"/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]) = 0">
							<xsl:call-template name="dynaTableRow">
								<xsl:with-param name="tableid" select="$tableid"/>
								<xsl:with-param name="orgtableid" select="$orgtableid"/>
								<xsl:with-param name="rowid" select="1"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]) &gt; 0">
							<xsl:choose>
								<!-- Create as many rows as there are rows in the data xml-->
								<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) &gt; 0">
									<xsl:for-each select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row">
										<xsl:call-template name="dynaTableRow">
											<xsl:with-param name="tableid" select="$tableid"/>
											<xsl:with-param name="orgtableid" select="$orgtableid"/>
											<xsl:with-param name="rowid" select="@id"/>
										</xsl:call-template>
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) &lt; 1">
									<xsl:call-template name="dynaTableRow">
										<xsl:with-param name="tableid" select="$tableid"/>
										<xsl:with-param name="orgtableid" select="$orgtableid"/>
										<xsl:with-param name="rowid" select="1"/>
									</xsl:call-template>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</table>
				<br/>
			</div>
		</p>
	</xsl:template>
	<!-- =========================================================
	 Name:			dynaTableRow
	 Description:	Outputs a row for a dynatable
	 ========================================================= -->
	<xsl:template name="dynaTableRow">
		<xsl:param name="tableid"/>
		<xsl:param name="orgtableid"/>
		<xsl:param name="rowid"/>
		<tr id="{$tableid}_{$rowid}">
			<!-- writes the delete row button-->
			<xsl:element name="td">
				<xsl:attribute name="align">right</xsl:attribute>
				<xsl:variable name="cell_id">
					<xsl:value-of select="$tableid"/>___<xsl:value-of select="@id"/>_<xsl:value-of select="$rowid"/>
				</xsl:variable>
				<xsl:attribute name="id">delRow_<xsl:value-of select="$cell_id"/></xsl:attribute>
				<xsl:attribute name="onClick">deleteRow(this, <xsl:value-of select="$tableid"/>)</xsl:attribute>
				<xsl:attribute name="title">Click here to delete this row</xsl:attribute>
				<xsl:attribute name="style">width:15px;height:15px;background-color:#C0C0C0;</xsl:attribute>
				<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
				<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
				<xsl:attribute name="class">buttonup</xsl:attribute>
				<xsl:element name="img">
					<xsl:attribute name="style">width:15px;height:15px;</xsl:attribute>
					<xsl:attribute name="src"><xsl:value-of select="$deleteicon"/></xsl:attribute>
				</xsl:element>
			</xsl:element>
			<xsl:for-each select="//question[@id=$orgtableid]/column">
				<xsl:variable name="cell_id">
					<xsl:value-of select="$orgtableid"/>___<xsl:value-of select="@id"/>_<xsl:value-of select="$rowid"/>
				</xsl:variable>
				<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
				<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
				<xsl:variable name="toconvert">
					<xsl:value-of select="@id"/>
				</xsl:variable>
				<xsl:variable name="columnid">
					<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="@type='date' or @type='time'">
						<td nowrap="true" width="113">
							<xsl:element name="input">
								<xsl:attribute name="type">text</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
								<xsl:attribute name="class">normalDate</xsl:attribute>
								<xsl:choose>
									<!-- If we are dealing with a patient DOB then we will need to format the 
										 date and update the document title to reflect the change -->
									<xsl:when test="@id = 'patient_dob'">
										<xsl:attribute name="onblur">DateOfBirthUnambiguousDateEntry(this);</xsl:attribute> 
									</xsl:when>
									<!-- All other dates only have to be formatted -->
									<xsl:otherwise>
										<xsl:attribute name="onblur">UnambiguousDateEntry(this);</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:if test="normalize-space(@mandatory) = 'true'">
									<xsl:attribute name="class">mandDate</xsl:attribute>
									<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
								</xsl:if>
								<xsl:choose>
									<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
										<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="value"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:element>
							<xsl:text/>
							<xsl:element name="img">
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/>_img</xsl:attribute>
								<xsl:attribute name="onclick"><![CDATA[ShowCalendar(]]><xsl:value-of select="$cell_id"/><![CDATA[,]]><xsl:value-of select="$cell_id"/><![CDATA[);]]></xsl:attribute>
								<xsl:attribute name="src"><xsl:value-of select="$dateicon"/></xsl:attribute>
								<xsl:attribute name="class">hand</xsl:attribute>
							</xsl:element>
						</td>
						<td/>
						<!--needed to keep with the table headers extra spaces for spelling-->
					</xsl:when>
					<xsl:when test="@type='select'">
						<td width="*" colspan="2">
							<xsl:element name="select">
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
								<xsl:for-each select="option">
									<xsl:element name="option">
										<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
										<xsl:choose>
											<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
												<xsl:choose>
													<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value = @value">
														<xsl:attribute name="selected">true</xsl:attribute>
													</xsl:when>
													<xsl:otherwise>
														<xsl:if test="normalize-space(@isDefault)">
															<xsl:attribute name="selected">true</xsl:attribute>
														</xsl:if>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:when>
											<xsl:otherwise>
												<xsl:if test="normalize-space(@isDefault)">
													<xsl:attribute name="selected">true</xsl:attribute>
												</xsl:if>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:value-of select="@text"/>
									</xsl:element>
								</xsl:for-each>
							</xsl:element>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<td width="*" colspan="2">
							<!-- colspan to fit spell check icon -->
							<xsl:element name="input">
								<xsl:attribute name="type">text</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
								<xsl:if test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
									<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="@maxlength != ''">
									<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="normalize-space(@mandatory) = 'true'">
									<xsl:attribute name="class">mandText</xsl:attribute>
									<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
								</xsl:if>
							</xsl:element>
						</td>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<td class="help"/>
		</tr>
	</xsl:template>
	<!-- ===========================================================
	Name:			button
	Description:		writes any button specified for a question next to the control
	=========================================================== -->
	<xsl:template name="btnTemplate">
		<xsl:param name="id"/>
		<xsl:param name="name"/>
		<xsl:param name="onclick"/>
		<xsl:param name="imgsrc"/>
		<xsl:param name="value"/>
		<xsl:element name="button">
			<xsl:attribute name="id"><xsl:value-of select="$id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
			<xsl:attribute name="onclick"><xsl:value-of select="$onclick"/></xsl:attribute>
			<xsl:choose>
				<xsl:when test="$imgsrc != ''">
					<xsl:element name="img">
						<xsl:attribute name="src"><xsl:value-of select="$imgsrc"/></xsl:attribute>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<xsl:template match="hdnflds">
		<xsl:element name="form">
			<xsl:attribute name="id">protocolInfo</xsl:attribute>
			<xsl:attribute name="name">protocolInfo</xsl:attribute>
			<xsl:for-each select="hdnfld">
				<xsl:element name="input">
					<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
  <!-- ===============================================================================================
	Name:			control
	Description:		sets up the dropdowns and clientside events for the referrer and regestrar cnotrols
	================================================================================================ -->
	<xsl:template match="control">
		<xsl:choose>
			<xsl:when test="SenderDetails">
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="id"><xsl:value-of select="@name"/>controls</xsl:attribute>
				<xsl:attribute name="name"><xsl:value-of select="@name"/>controls</xsl:attribute>
				<xsl:attribute name="value">xmlsenderdetails<xsl:value-of select="@name"/></xsl:attribute>
			</xsl:element>
			<xsl:element name="table">
        <xsl:attribute name="cellSpacing">0</xsl:attribute>
				<xsl:apply-templates select="SenderDetails"/>
			</xsl:element>
			<!-- Stick the Sender xml onto the page-->
			<xsl:element name="xml">
				<xsl:attribute name="id">xmlsenderdetails<xsl:value-of select="@name"/></xsl:attribute>
				<xsl:attribute name="name">xmlsenderdetails<xsl:value-of select="@name"/></xsl:attribute>
				<xsl:copy-of select="SenderDetails"/>
			</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="input">
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="id"><xsl:value-of select="@name"/>controls</xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@name"/>controls</xsl:attribute>
					<xsl:attribute name="value">xml<xsl:value-of select="@name"/>;<xsl:value-of select="descendant::hces[last()]/@hcetypename"/></xsl:attribute>
				</xsl:element>
				<xsl:element name="table">
					<xsl:apply-templates select="hces"/>
				</xsl:element>
				<xsl:element name="xml">
					<xsl:attribute name="id">xml<xsl:value-of select="@name"/></xsl:attribute>
					<xsl:attribute name="name">xml<xsl:value-of select="xml"/><xsl:value-of select="@name"/></xsl:attribute>
					<xsl:copy-of select="hces"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="SenderDetails">
		<!--Location row-->
		<xsl:element name="tr">
			<xsl:element name="td"><xsl:attribute name="class">question</xsl:attribute>Location</xsl:element>
			<xsl:element name="td">
				<xsl:attribute name="width">*</xsl:attribute>
				<xsl:attribute name="nowrap">true</xsl:attribute>
				<xsl:element name="select">
					<xsl:attribute name="style">width:200px</xsl:attribute>
					<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Location</xsl:attribute>
					<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Location</xsl:attribute>
					<xsl:attribute name="onchange">vbscript:call locationChanged('<xsl:value-of select="ancestor-or-self::control/@name"/>')</xsl:attribute>
					<xsl:element name="option">
						<xsl:attribute name="value">-1</xsl:attribute>
            <xsl:attribute name="selected">true</xsl:attribute>
            -- Please Select --
					</xsl:element>
					<xsl:for-each select="Location">
						<option>
							<xsl:attribute name="value">
								<xsl:value-of select="LocationNationalCode/text()"/>
							</xsl:attribute>
							<!--Select first in the list
							<xsl:if test="position() = 1">
								<xsl:attribute name="selected">true</xsl:attribute>
							</xsl:if>-->
							<xsl:value-of select="LocationName/text()"/>
						</option>
					</xsl:for-each>
				</xsl:element>
			</xsl:element>
		</xsl:element>
		<!-- Specialty Row-->
		<!-- If there are Specialties then display the row otherwise don't!-->
		<xsl:if test="//Specialty">
			<xsl:element name="tr">
				<xsl:element name="td"><xsl:attribute name="class">question</xsl:attribute>Specialty</xsl:element>
				<xsl:element name="td">
					<xsl:attribute name="width">*</xsl:attribute>
					<xsl:attribute name="nowrap">true</xsl:attribute>
					<xsl:element name="select">
						<xsl:attribute name="style">width:200px</xsl:attribute>
						<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Specialty</xsl:attribute>
						<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Specialty</xsl:attribute>
						<xsl:attribute name="onchange">vbscript:call specialtyChanged('<xsl:value-of select="ancestor-or-self::control/@name"/>')</xsl:attribute>
						<xsl:element name="option">
							<xsl:attribute name="value">-1</xsl:attribute>
							<xsl:attribute name="selected">true</xsl:attribute>
							<xsl:attribute name="text"/>
						</xsl:element>
/					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<!-- Hcp row -->
		<!-- Always display this row but only attempt populate it initially if there are no specialties-->
		<xsl:element name="tr">
			<xsl:element name="td"><xsl:attribute name="class">question</xsl:attribute>HCP</xsl:element>
			<xsl:element name="td">
				<xsl:attribute name="width">*</xsl:attribute>
				<xsl:attribute name="nowrap">true</xsl:attribute>
				<xsl:element name="select">
					<xsl:attribute name="style">width:200px</xsl:attribute>
					<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Hcp</xsl:attribute>
					<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Hcp</xsl:attribute>
					<xsl:attribute name="onchange">vbscript:call hcpChanged('<xsl:value-of select="ancestor-or-self::control/@name"/>')</xsl:attribute>
						<xsl:element name="option">
							<xsl:attribute name="value">-1</xsl:attribute>
							<xsl:attribute name="selected">true</xsl:attribute>
							<xsl:attribute name="text"/>
						</xsl:element>
/					</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="hces">
		<xsl:if test="position() = 1">
			<xsl:element name="tr">
			<xsl:element name="td">
				<xsl:attribute name="class">question</xsl:attribute>
				<xsl:value-of select="@hcetypename"/>
			</xsl:element>
			<xsl:element name="td">
				<xsl:attribute name="width">*</xsl:attribute>
				<xsl:attribute name="nowrap">true</xsl:attribute>
				<xsl:element name="select">
				<xsl:attribute name="style">width:200px</xsl:attribute>
				<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/><xsl:value-of select="@hcetypename"/></xsl:attribute>
				<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/><xsl:value-of select="@hcetypename"/></xsl:attribute>
				<!-- Change to clear all fields when Blank entry is selected in GP Practice combo -->
				<xsl:if test="(count(ancestor::hces) = 0) and (contains(ancestor-or-self::control/@name, 'referrer'))">
					<xsl:attribute name="onchange">vbscript:call clearTopLevelDetailsFields('<xsl:value-of select="ancestor-or-self::control/@name"/>',  '<xsl:value-of select="/descendant::hces[position()=1]/@hcetypename"/>', false)</xsl:attribute>
				</xsl:if>
				<!-- End Change -->
				<xsl:if test="count(descendant::hces) = 0">
					<xsl:attribute name="onchange">vbscript:call setFieldValuesFromControl('<xsl:value-of select="ancestor-or-self::control/@name"/>', '<xsl:value-of select="//hces/descendant::hces[last()]/@hcetypename"/>', 'false')</xsl:attribute>
				</xsl:if>
				<xsl:if test="(count(descendant::hces) != 0) and (count(ancestor::hces) != 0)">
					<xsl:attribute name="onchange">vbscript:call loadHces('xml<xsl:value-of select="ancestor-or-self::control/@name"/>', 'cmb<xsl:value-of select="ancestor-or-self::control/@name"/><xsl:value-of select="string(hce/hces/@hcetypename)"/>')</xsl:attribute>
				</xsl:if>
				<xsl:if test="count(ancestor::hces) != 0">
					<xsl:element name="option">
					<xsl:attribute name="value">-1</xsl:attribute>
					<xsl:attribute name="text"/>
					</xsl:element>
				</xsl:if>
				<!-- if there is a default parent hce, or if there is only one parent hce or no parent hce-->
				<xsl:if test="(count(ancestor::hces[position()=1]/hce[@isDefault='true']) = 1) or (count(ancestor::hces[position()=1]/hce) = 1) or (count(ancestor::hces[position()=1]/hce) = 0)">
					<xsl:apply-templates select="hce"/>
				</xsl:if>
				</xsl:element>
			</xsl:element>
			</xsl:element>
		</xsl:if>
		<xsl:apply-templates select="hce/hces"/>
	</xsl:template>
	<xsl:template match="hce">
		<!-- This adds the blank entry for top level HCE -->
		<xsl:if test="(count(ancestor-or-self::hce[@isDefault='true'] )= 1) and (count(ancestor::hces) = 1) and (contains(ancestor-or-self::control/@name, 'referrer'))">
			<xsl:element name="option">
			<xsl:attribute name="value">-1</xsl:attribute>
			<xsl:attribute name="text"/>
			</xsl:element>
		</xsl:if>
		<!-- End of Change -->
		<xsl:element name="option">
			<xsl:attribute name="value">
				<xsl:value-of select="@hceid"/>
			</xsl:attribute>
			<xsl:if test="@isDefault='true'">
				<xsl:attribute name="selected">true</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="@hcename"/>
			<xsl:if test="@type!=''">(<xsl:value-of select="@type"/>)</xsl:if>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
